local RoleLayer = class("RoleLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function RoleLayer.create()
    local layer = RoleLayer.new()
    layer:createLayerMenu()
    return layer
end

function RoleLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.attrScroll = nil
    self.equipScroll = nil
    self.wearTable = {}
	self.newTipTable = {}
    self.wearRegion = wd.WearRegion.NOTHING
    self.regionType = wd.RegionType.ALL

--[[
    self.weaponNode = nil
    self.breastplateNode = nil
    self.helmetNode = nil
    self.shoeNode = nil
    self.necklaceNode = nil
    self.lWristNode = nil
    self.rWristNode = nil
    self.lRingNode = nil
    self.rRingNode = nil
    ]]
end

function RoleLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Wear")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Equip")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Role")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Wash_Pk_Value")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("guidance_strengthen")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("guidance_closeRoleLayer")
	self:removeFromParent()
end

function RoleLayer:createWearNode(wearType)
    local equipNode = tolua.cast(cc.CSLoader:createNode("ui/role/WearNode.csb"),"ccui.Widget")

    local item = wd.GlobalData:getInstance():getWearEquip(wearType)
    if item == nil then
        equipNode:setVisible(false)
    else
        equipNode:setVisible(true)

        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
        
        wd.equipEffect(item, image)

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getColor()))

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))
        
        local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
        if item:getStrengthenLevel() > 0 then
            strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
        else
            strengthenLabel:setString("")
        end

    end
    
    self.wearTable[wearType] = equipNode
    return equipNode
end

function RoleLayer:wear(id)
    
    local equipNode = self.wearTable[self.wearRegion]
    local newSprite = self.newTipTable[self.wearRegion]
    local item = wd.GlobalData:getInstance():getWearEquip(self.wearRegion)
    if item == nil then
        equipNode:setVisible(false)
		if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(self.wearRegion) then
			wd.showNewTipsEffect(newSprite)
		else
			wd.hideNewTipsEffect(newSprite)
		end
    else

        if wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(self.wearRegion) then
            wd.showNewTipsEffect(newSprite)
        else
            wd.hideNewTipsEffect(newSprite)
        end

        equipNode:setVisible(true)

        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
        
        image:removeAllChildren()
        wd.equipEffect(item, image)

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getColor()))

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))
        
        local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
        if item:getStrengthenLevel() > 0 then
            strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
        else
            strengthenLabel:setString("")
        end
    end
    
    self.attrScroll:setVisible(true)
    self.equipScroll:setVisible(false)
end

function RoleLayer:takeoff(tag)
    
    local role = wd.GlobalData:getInstance():getRoleData()
    
    
    if wd.GlobalData:getInstance():getEquipItemCount() < role:getPackageCapacity() then
    
        wd.GlobalData:getInstance():takeoffEquip(tag)
        
        local equipNode = self.wearTable[tag]
		local newSprite = self.newTipTable[self.wearRegion]
        equipNode:setVisible(false)
        if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(self.wearRegion) then
			wd.showNewTipsEffect(newSprite)
		else
			wd.hideNewTipsEffect(newSprite)
		end
        if self.wearRegion == wd.WearRegion.LWRIST or self.wearRegion == wd.WearRegion.RWRIST then
            self:createEquipList(wd.RegionType.WRIST)
        elseif self.wearRegion == wd.WearRegion.LRING or self.wearRegion == wd.WearRegion.RRING then
            self:createEquipList(wd.RegionType.RING)
        elseif self.wearRegion ~= wd.WearRegion.NOTHING then
            self:createEquipList(self.wearRegion)
        end
    end
end

function RoleLayer:refreshWearEquip()
    
    for i=wd.WearRegion.WEAPON,wd.WearRegion.RRING do
        local equipNode = self.wearTable[i]
		local newSprite = self.newTipTable[self.wearRegion]
        local item = wd.GlobalData:getInstance():getWearEquip(i)
        if item == nil then
            equipNode:setVisible(false)
			if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(self.wearRegion) then
				wd.showNewTipsEffect(newSprite)
			else
				wd.hideNewTipsEffect(newSprite)
			end
        else
             if wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(self.wearRegion) then
                wd.showNewTipsEffect(newSprite)
            else
                wd.hideNewTipsEffect(newSprite)
            end

            equipNode:setVisible(true)
    
            local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
            image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
            
            image:removeAllChildren()
            wd.equipEffect(item, image)
    
            local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
            color:setSpriteFrame(string.format("%02d.png",item:getColor()))
    
            local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
    
            local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
            if item:getStrengthenLevel() > 0 then
                strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
            else
                strengthenLabel:setString("")
            end
        end
    end

end


function RoleLayer:refreshEquipList()
    self:createEquipList(self.regionType)
end

function RoleLayer:createEquipList(regionType)

    self.equipScroll:setVisible(true)
    self.attrScroll:setVisible(false)
    
    self.equipScroll:removeAllChildren()
    self.equipScroll:jumpToTop()
    
    if regionType <= wd.RegionType.ALL then
        return
    end
    
    local function attrCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then

            local layerClass = require("src.game.package.EquipTipsLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(sender:getTag(), self.wearRegion,  0, -1)
            self:addChild(layer)
			--local event = cc.EventCustom:new("Handle_NewGuile")
			--cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
            
            if self.clippingLayer then
                self.clippingLayer:removeFromParent()
                self.clippingLayer = nil
            end
        end
    end
    
    --local number = wd.GlobalData:getInstance():filterEquipListForRegion(type)
    local number = wd.GlobalData:getInstance():filterEquipListForOccupationAndRegion(wd.GlobalData:getInstance():getRoleJob(), regionType)

    local btnHeight   = 140
    local innerHeight = number*btnHeight

    self.equipScroll:setInnerContainerSize(cc.size(276.00, innerHeight))

    innerHeight = self.equipScroll:getInnerContainerSize().height
    
    local tag = 0

    for i=0,number-1 do

        tag = wd.GlobalData:getInstance():getFilterEquipListTag(i)

        local item = wd.GlobalData:getInstance():getEquipItem(tag)
        
        local equipNode = tolua.cast(cc.CSLoader:createNode("ui/package/EquipNode.csb"),"ccui.Widget")

        local btn = ccui.Button:create("package_subbox.png", "package_subbox.png", "", ccui.TextureResType.plistType)
        btn:setAnchorPoint(cc.p(0,0))
        btn:setPosition(0, innerHeight - btnHeight - i*btnHeight)
        btn:setTag(tag)
        btn:setScale(0.85)
        btn:addTouchEventListener(attrCallback)

        btn:addChild(equipNode)
        		
        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
        
        wd.equipEffect(item, image)

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getColor()))

        local title = tolua.cast(equipNode:getChildByName("Job_Title"), "cc.Sprite")
        if item:getOccupation() <= 0 then
            title:setVisible(false)
        else
            title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
        end

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))

        local nameLabel = tolua.cast(equipNode:getChildByName("Name_Label"), "ccui.Text")
        --nameLabel:setString(item:getName())
        nameLabel:setColor(wd.colorType(item:getColor()))
        if item:getStrengthenLevel() >0 then
            nameLabel:setString(string.format("%s+%d",item:getName(), item:getStrengthenLevel()))
        else
            nameLabel:setString(item:getName())
        end
        
        local lockCheck = tolua.cast(ccui.Helper:seekWidgetByName(equipNode,"Lock_Check"), "ccui.CheckBox")
        if item:getLocked() ~= 0 then
            lockCheck:setSelected(true)
        end

        lockCheck:addEventListener(
            function(sender,eventType)
                if eventType == ccui.CheckBoxEventType.selected then
                    wd.TranscodingSend:setEquipLocked(item:getServerId(), 1)
                elseif  eventType == ccui.CheckBoxEventType.unselected then
                    wd.TranscodingSend:setEquipLocked(item:getServerId(), 0)
                end
            end
        )
        
        local regionLabel = tolua.cast(equipNode:getChildByName("Region_Label"), "ccui.Text")
        regionLabel:setString(string.format("位置：%s",wd.getRegionString(item:getRegion())))

        self.equipScroll:addChild(btn)
        
		if i == 0 and not self.guidance then
			-- local x,y = btn:getPosition()
			-- x = x+btn:getContentSize().width/2
			-- y = y+btn:getContentSize().height/2
			-- wd.newGuidePos[wd.newGuideStep.EquipSelect] = {}
			-- wd.newGuidePos[wd.newGuideStep.EquipSelect].pos = btn:getParent():convertToWorldSpace(cc.p(x,y))
			-- wd.newGuidePos[wd.newGuideStep.EquipSelect].size = btn:getContentSize()

             ------------------------------新手引导----------------------------
            self.guidance = true
            local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
            if clippingLayer then
                clippingLayer:setGuidance(btn,30,30,115,115)
                local msgTable = {}
                local msg = {}
                table.insert(msg,"请点击")
                table.insert(msg,"{r=[右侧武器]}")
                table.insert(msg,"！")
                table.insert(msgTable,msg)
                clippingLayer:setMsg(msgTable)
                self.clippingLayer = clippingLayer
                self:addChild(clippingLayer)
            end
            ------------------------------------------------------------------
 
		end
    end
	
	
end

function RoleLayer:createLayerMenu()

    local node = tolua.cast(cc.CSLoader:createNode("ui/role/RoleScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local function backCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
			local event = cc.EventCustom:new("Check_New_Tip")
			cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
			self:clear()
        end
    end

    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(backCallback)
    
    
     ------------------------------新手引导关闭角色界面并引导打开挂机地图----------------------------
    local closeLayer = function(EventCustom)
        local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
        if clippingLayer then
            clippingLayer:setGuidance(backBtn,30,50,115,115,nil,true)
            local msgTable = {}
            local msg = {}
            table.insert(msg,"很好，")
            table.insert(msg,"{r=[强化成功]}")
            table.insert(msg,"了，咱们回到主界面！")
            table.insert(msgTable,msg)
            clippingLayer:setMsg(msgTable)
            self:addChild(clippingLayer)
            backBtn:addTouchEventListener(function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local event = cc.EventCustom:new("guidance_battleOpen")
                    cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                    local event = cc.EventCustom:new("Check_New_Tip")
                    cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                    self:clear()
                end
            end)
        end
    end
    local listener = cc.EventListenerCustom:create("guidance_closeRoleLayer", closeLayer)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
    
    
    
    
	local shieldBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Shield_Button"), "ccui.Widget")
    shieldBtn:setPressedActionEnabled(true)
    shieldBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.showRichTips(4,"暂未开放")
            end
        end
    )
    local equipPanel = ccui.Helper:seekWidgetByName(node,"Panel_Equip")
    local jobTitle = tolua.cast(equipPanel:getChildByName("Job_Title"), "cc.Sprite")
    
    jobTitle:setSpriteFrame(wd.getJobTitleName(wd.GlobalData:getInstance():getRoleJob()))
    jobTitle:setVisible(true)
    
    local familyName = tolua.cast(ccui.Helper:seekWidgetByName(node,"family_name"), "ccui.Text")
    local vipLevel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Vip_Level_Label"), "ccui.Text")
    
    local roleSprite = tolua.cast(equipPanel:getChildByName("Role_Sprite"), "cc.Sprite")

    local nameLabel = tolua.cast(equipPanel:getChildByName("Name_Label"), "ccui.Text")
    local powerLabel = tolua.cast(equipPanel:getChildByName("Power_Label"), "ccui.TextAtlas")
    local levelLabel = tolua.cast(equipPanel:getChildByName("Level_Label"), "ccui.Text")
    
    local attrScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Attr_ScrollView"), "ccui.ScrollView")
    local equipScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_ScrollView"), "ccui.ScrollView")
    equipScroll:setVisible(false)

    self.attrScroll = attrScroll
    self.equipScroll = equipScroll
    
    
    local attackTitle = tolua.cast(attrScroll:getChildByName("Attack_Title"), "cc.Sprite")
    local hpLabel = tolua.cast(attrScroll:getChildByName("Hp_Label"), "ccui.Text")
    local mpLabel = tolua.cast(attrScroll:getChildByName("Mp_Label"), "ccui.Text")
    local atkLabel = tolua.cast(attrScroll:getChildByName("Attack_Label"), "ccui.Text")
    local pdefLabel = tolua.cast(attrScroll:getChildByName("PDefence_Label"), "ccui.Text")
    local mdefLabel = tolua.cast(attrScroll:getChildByName("MDefence_Label"), "ccui.Text")
    local tdefLabel = tolua.cast(attrScroll:getChildByName("TDefence_Label"), "ccui.Text")
    local luckLabel = tolua.cast(attrScroll:getChildByName("Luck_Label"), "ccui.Text")
    local accuracyLabel = tolua.cast(attrScroll:getChildByName("Accuracy_Label"), "ccui.Text")
    local dodgeLabel = tolua.cast(attrScroll:getChildByName("Dodge_Label"), "ccui.Text")
    local vertigoLabel = tolua.cast(attrScroll:getChildByName("Vertigo_Label"), "ccui.Text")
    local reincarnateLabel = tolua.cast(attrScroll:getChildByName("Reincarnate_Label"), "ccui.Text")
    local manapreventLabel = tolua.cast(attrScroll:getChildByName("Manaprevent_Label"), "ccui.Text")
    local drainlifeLabel = tolua.cast(attrScroll:getChildByName("Drainlife_Label"), "ccui.Text")
    local critLabel = tolua.cast(attrScroll:getChildByName("Crit_Label"), "ccui.Text")
	local critDamLabel = tolua.cast(attrScroll:getChildByName("CritDam_Label"), "ccui.Text")
    local honorLabel = tolua.cast(attrScroll:getChildByName("Honor_Label"), "ccui.Text")
    local killLabel = tolua.cast(attrScroll:getChildByName("Kill_Label"), "ccui.Text")
    local luckBtn = tolua.cast(attrScroll:getChildByName("Luck_Button"), "ccui.Button")
	luckBtn:setPressedActionEnabled(true)
    luckBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.LuckUseLayer")
				local layer = layerClass.create()
				self:addChild(layer)
            end
        end
    )
	local killBtn = tolua.cast(attrScroll:getChildByName("Kill_Button"), "ccui.Button")
	killBtn:setPressedActionEnabled(true)
    killBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local item = wd.GlobalData:getInstance():getToolsItemInXml(wd.ItemId.KillWashDrug)
				local layerClass = require("src.tips.TipsBoxLayer")
				local msgTable = {}
				local msg = {}
				table.insert(msg,"是否用")
				table.insert(msg,string.format("{y=[%s]}",item:getName()))
				table.insert(msg,"消除")
				table.insert(msg,string.format("{g=[%d点]}",100))
                table.insert(msg,"杀戮值")
				table.insert(msgTable,msg)
				
				msg = {}
				table.insert(msg,"当前背包中有")
				table.insert(msg,string.format("{g=[%d个]}",wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.KillWashDrug)))
				table.insert(msg,string.format("{y=[%s]}",item:getName()))
				table.insert(msg,"可使用")
				table.insert(msgTable,msg)
				local function useKillDrug()
					wd.TranscodingSend:washPkValue()
				end
				self.tipsLayer = layerClass.create("wash_title.png", msgTable,useKillDrug)
				self:addChild(self.tipsLayer)
            end
        end
    )
	
    local function updataData()
    
        local role = wd.GlobalData:getInstance():getRoleData()

        familyName:setString(role:getRoleExtendData("family_name"))
        vipLevel:setString(role:getVip())

        roleSprite:setSpriteFrame(wd.getPlayerImageName(role:getOccupation(), role:getSex()))
        roleSprite:setVisible(true)
        if role:getSex() == 0 then
            roleSprite:setFlippedX(true)
        else
            roleSprite:setFlippedX(false)
        end
        nameLabel:setString(role:getName())
        powerLabel:setString(string.format("%d",role:getPower()))
        levelLabel:setString(string.format("%d级",role:getLevel()))
        
        hpLabel:setString(string.format("%d/%d",role:getHp(),role:getHp()))
        mpLabel:setString(string.format("%d/%d",role:getMp(),role:getMp()))
        
        if role:getOccupation() == 1 then
            attackTitle:setSpriteFrame("role_pattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getPAttack_min(), role:getPAttack_max()))
        elseif role:getOccupation() == 2 then
            attackTitle:setSpriteFrame("role_mattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getMAttack_min(), role:getMAttack_max()))
        elseif role:getOccupation() == 3 then
            attackTitle:setSpriteFrame("role_tattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getTAttack_min(), role:getTAttack_max()))
        end
        
        pdefLabel:setString(string.format("%d-%d", role:getPDefence_min(), role:getPDefence_max()))
        mdefLabel:setString(string.format("%d-%d", role:getMDefence_min(), role:getMDefence_max()))
        tdefLabel:setString(string.format("%d-%d", role:getTDefence_min(), role:getTDefence_max()))
        luckLabel:setString(string.format("%d",role:getLuck()))
        accuracyLabel:setString(string.format("%d",role:getAccuracy()))
        dodgeLabel:setString(string.format("%d",role:getDodge()))
        vertigoLabel:setString(string.format("%0.1f%%",role:getVertigo()/100.0))
        reincarnateLabel:setString(string.format("%0.1f%%",role:getReincarnate()/100.0))
        manapreventLabel:setString(string.format("%0.1f%%",role:getManaprevent()/100.0))
        drainlifeLabel:setString(string.format("%0.1f%%",role:getDrainlife()/100.0))
        critLabel:setString(string.format("%0.1f%%",role:getCrit()/100.0))
		critDamLabel:setString(string.format("%0.01f%%",role:getCritDam()/100))
        honorLabel:setString(string.format("%d",role:getHonor()))
        killLabel:setString(string.format("%d",role:getKill()))
    end

    updataData()
    
    local function showEquipList(regionType)
        
        local item = wd.GlobalData:getInstance():getWearEquip(self.wearRegion)
        if item ~= nil then
            local layerClass = require("src.game.package.EquipTipsLayer")
            local layer = layerClass.create()
            layer:createWithSmeltingVisible(0, self.wearRegion, 1, -1)
            self:addChild(layer)
        end
        
        self.regionType = regionType
        self:createEquipList(regionType)
		--local event = cc.EventCustom:new("Handle_NewGuile")
		--cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
    end
    
    local attrBtn = ccui.Helper:seekWidgetByName(equipPanel,"Role_Button")
    attrBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                equipScroll:setVisible(false)
                attrScroll:setVisible(true)
            end
        end
    )
	
	local soulBtn = ccui.Helper:seekWidgetByName(equipPanel,"Soul_Button")
    soulBtn:setPressedActionEnabled(true)
    soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local isOpen,msg = wd.checkOpen(wd.openKey.Soul)
				if isOpen then
					cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
					cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Wear")
					cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Equip")
					cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Role")
					cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Wash_Pk_Value")
					local layerClass = require("src.game.RoleSoulLayer")
					local layer = layerClass.create()
					self:getParent():addChild(layer)
					self:removeFromParent()
				else
					wd.showRichTips(3,msg)
				end
            end
        end
    )
    
    local helmetBtn = ccui.Helper:seekWidgetByName(equipPanel,"Helmet_Button")
    helmetBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.HELMET
                showEquipList(wd.RegionType.HELMET)
            end
        end
    )
	local helmetNewSprite = tolua.cast(equipPanel:getChildByName("Helmet_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.HELMET) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.HELMET) then
		wd.showNewTipsEffect(helmetNewSprite)
	else
		wd.hideNewTipsEffect(helmetNewSprite)
	end
	self.newTipTable[wd.WearRegion.HELMET] = helmetNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.HELMET)
    helmetBtn:addChild(equipNode)
    
    local necklaceBtn = ccui.Helper:seekWidgetByName(equipPanel,"Necklace_Button")
    necklaceBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.NECKLACE
                showEquipList(wd.RegionType.NECKLACE)
            end
        end
    )
	local necklaceNewSprite = tolua.cast(equipPanel:getChildByName("Necklace_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.NECKLACE) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.NECKLACE) then
		wd.showNewTipsEffect(necklaceNewSprite)
	else
		wd.hideNewTipsEffect(necklaceNewSprite)
	end
	self.newTipTable[wd.WearRegion.NECKLACE] = necklaceNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.NECKLACE)
    necklaceBtn:addChild(equipNode)
    
    local breastplateBtn = ccui.Helper:seekWidgetByName(equipPanel,"Breastplate_Button")
    breastplateBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.BREASTPLATE
                showEquipList(wd.RegionType.BREASTPLATE)
            end
        end
    )
    local breastplateNewSprite = tolua.cast(equipPanel:getChildByName("Breastplate_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.BREASTPLATE) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.BREASTPLATE) then
		wd.showNewTipsEffect(breastplateNewSprite)
	else
		wd.hideNewTipsEffect(breastplateNewSprite)
	end
	self.newTipTable[wd.WearRegion.BREASTPLATE] = breastplateNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.BREASTPLATE)
    breastplateBtn:addChild(equipNode)
    
    local shoeBtn = ccui.Helper:seekWidgetByName(equipPanel,"Shoe_Button")
    shoeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.SHOE
                showEquipList(wd.RegionType.SHOE)
            end
        end
    )
	local shoeNewSprite = tolua.cast(equipPanel:getChildByName("Shoe_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.SHOE) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.SHOE) then
		wd.showNewTipsEffect(shoeNewSprite)
	else
		wd.hideNewTipsEffect(shoeNewSprite)
	end
	self.newTipTable[wd.WearRegion.SHOE] = shoeNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.SHOE)
    shoeBtn:addChild(equipNode)
    
    local weaponBtn = ccui.Helper:seekWidgetByName(equipPanel,"Weapon_Button")
    
     ------------------------------新手引导----------------------------
    local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
    if clippingLayer then
        clippingLayer:setGuidance(weaponBtn,30,30,115,115)
        local msgTable = {}
        local msg = {}
        table.insert(msg,"请点击")
        table.insert(msg,"{r=[武器框]}")
        table.insert(msg,"！")
        table.insert(msgTable,msg)
        clippingLayer:setMsg(msgTable)
        self:addChild(clippingLayer)
    end
    ------------------------------------------------------------------
    
    
    
    ------------------------------新手引导----------------------------
    local strengthenEquip = function(EventCustom)
        local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
        if clippingLayer then
            clippingLayer:setGuidance(weaponBtn,30,30,115,115)
            local msgTable = {}
            local msg = {}
            table.insert(msg,"装备穿戴了，但威力不够强，咱们去")
            table.insert(msg,"{r=[强化一下]}")
            table.insert(msg,"！")
            table.insert(msgTable,msg)
            clippingLayer:setMsg(msgTable)
            self:addChild(clippingLayer)
            weaponBtn:addTouchEventListener(function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    self.wearRegion = wd.WearRegion.WEAPON
                    showEquipList(wd.RegionType.WEAPON)
                    if clippingLayer then
                        clippingLayer:removeFromParent()
                        clippingLayer = nil
                    end
                    
                end
            end)
        end
    end
    local listener = cc.EventListenerCustom:create("guidance_strengthen", strengthenEquip)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
    ------------------------------------------------------------------
    
    
    
    
	local x,y = weaponBtn:getPosition()
	wd.newGuidePos[wd.newGuideStep.EquipBox] = {}
	wd.newGuidePos[wd.newGuideStep.EquipBox].pos = weaponBtn:getParent():convertToWorldSpace(cc.p(x,y))
	wd.newGuidePos[wd.newGuideStep.EquipBox].size = weaponBtn:getContentSize()
	wd.newGuidePos[wd.newGuideStep.WeardEquip] = {}
	wd.newGuidePos[wd.newGuideStep.WeardEquip].pos = weaponBtn:getParent():convertToWorldSpace(cc.p(x,y))
	wd.newGuidePos[wd.newGuideStep.WeardEquip].size = weaponBtn:getContentSize()
    weaponBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.WEAPON
                showEquipList(wd.RegionType.WEAPON)
                if clippingLayer then
                    clippingLayer:removeFromParent()
                    clippingLayer = nil
                end

				--local event = cc.EventCustom:new("Handle_NewGuile")
				--cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
            end
        end
    )
	local weaponNewSprite = tolua.cast(equipPanel:getChildByName("Weapon_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.WEAPON) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.WEAPON) then
		wd.showNewTipsEffect(weaponNewSprite)
	else
		wd.hideNewTipsEffect(weaponNewSprite)
	end
	self.newTipTable[wd.WearRegion.WEAPON] = weaponNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.WEAPON)
    weaponBtn:addChild(equipNode)
    
    local lWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"LWrist_Button")
    lWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.LWRIST
                showEquipList(wd.RegionType.WRIST)
            end
        end
    )
	local lWristNewSprite = tolua.cast(equipPanel:getChildByName("LWirst_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.LWRIST) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.LWRIST) then
		wd.showNewTipsEffect(lWristNewSprite)
	else
		wd.hideNewTipsEffect(lWristNewSprite)
	end
	self.newTipTable[wd.WearRegion.LWRIST] = lWristNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.LWRIST)
    lWristBtn:addChild(equipNode)
    
    local rWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"RWrist_Button")
    rWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.RWRIST
                showEquipList(wd.RegionType.WRIST)
            end
        end
    )
	local rWristNewSprite = tolua.cast(equipPanel:getChildByName("RWrist_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.RWRIST) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.RWRIST) then
		wd.showNewTipsEffect(rWristNewSprite)
	else
		wd.hideNewTipsEffect(rWristNewSprite)
	end
	self.newTipTable[wd.WearRegion.RWRIST] = rWristNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.RWRIST)
    rWristBtn:addChild(equipNode)
    
    local lRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"LRing_Button")
    lRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.LRING
                showEquipList(wd.RegionType.RING)
            end
        end
    )
	local lRingNewSprite = tolua.cast(equipPanel:getChildByName("LRing_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.LRING) or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.LRING) then
		wd.showNewTipsEffect(lRingNewSprite)
	else
		wd.hideNewTipsEffect(lRingNewSprite)
	end
	self.newTipTable[wd.WearRegion.LRING] = lRingNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.LRING)
    lRingBtn:addChild(equipNode)
    
    local rRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"RRing_Button")
    rRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.RRING
                showEquipList(wd.RegionType.RING)
            end
        end
    )
	local rRingNewSprite = tolua.cast(equipPanel:getChildByName("RRing_Tips_Effect"),"cc.Sprite")
	if wd.GlobalData:getInstance():checkHaveCanWearEquipByRegion(wd.WearRegion.RRING)  or wd.GlobalData:getInstance():checkHaveBestWearEquipByRegion(wd.WearRegion.RRING) then
		wd.showNewTipsEffect(rRingNewSprite)
	else
		wd.hideNewTipsEffect(rRingNewSprite)
	end
	self.newTipTable[wd.WearRegion.RRING] = rRingNewSprite
    local equipNode = self:createWearNode(wd.WearRegion.RRING)
    rRingBtn:addChild(equipNode)
    
    local function updataWear()
        self:refreshWearEquip()
    end
    
    local function updataEquip()
        self:refreshEquipList()
    end
	
	local function equipAttributeChangeCallBack()
		--wd.showAttributeChangeTip()
		local oldRole = wd.GlobalData:getInstance():getOldRoleData()
		local newRole = wd.GlobalData:getInstance():getRoleData()
		local roleAttributeClass = require("src.game.RoleAttribute"):getInstance()
		for i,v in pairs(roleAttributeClass.RoleBaseAttribute) do
			local changeValue = v.getFunc(newRole) - v.getFunc(oldRole)
			if changeValue ~= 0 then
				local sign = (changeValue < 0) and "" or "+"
				local color = (changeValue < 0) and cc.c3b(255,0,0) or cc.c3b(0,255,0)
				local x,y = equipPanel:getPosition()
				x = x+equipPanel:getContentSize().width/2
				y = y+equipPanel:getContentSize().height/2
				if i == "CritDam" then
					changeValue = changeValue/100
				end
				changeValue = tostring(changeValue)
				if i == "Vertigo" or i == "Manaprevent" or i == "Reincarnate" or i == "Drainlife" or i == "CritDam" then
					changeValue = changeValue.."%"
				end
				wd.showAttributeTips(string.format("%s %s%s",v.name,sign,changeValue),color,35,cc.p(x,y))
			end
		end
	end

	local listener_AttributeChange = cc.EventListenerCustom:create("Equip_AttributeChange", equipAttributeChangeCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener_AttributeChange, 1); 
    
    local listener = cc.EventListenerCustom:create("Update_Wear", updataWear)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    local listener = cc.EventListenerCustom:create("Update_Equip", updataEquip)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    local listener = cc.EventListenerCustom:create("Update_Role", updataData)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onWashPkValue(EventCustom)
		if self.tipsLayer then
			wd.showRichTips(4,"使用成功")
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Wash_Pk_Value", onWashPkValue)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
end



return RoleLayer