local RoleSoulLayer = class("RoleSoulLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function RoleSoulLayer.create()
    local layer = RoleSoulLayer.new()
    layer:createLayerMenu()
    return layer
end

function RoleSoulLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.attrScroll = nil
    self.equipView = nil
    self.wearTable = {}
    self.wearRegion = wd.WearRegion.NOTHING
    self.regionType = wd.RegionType.ALL

--[[
    self.weaponNode = nil
    self.breastplateNode = nil
    self.helmetNode = nil
    self.shoeNode = nil
    self.necklaceNode = nil
    self.lWristNode = nil
    self.rWristNode = nil
    self.lRingNode = nil
    self.rRingNode = nil
    ]]
end

function RoleSoulLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_WearSoul")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Soul")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Role")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Wash_Pk_Value")
	self:removeFromParent()
end

function RoleSoulLayer:createWearNode(wearType)
    local equipNode = tolua.cast(cc.CSLoader:createNode("ui/role/WearNode.csb"),"ccui.Widget")

    local item = wd.GlobalData:getInstance():getWearSoul(wearType)
    if item == nil then
        equipNode:setVisible(false)
    else
        equipNode:setVisible(true)

        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getSoulId()))
        
        wd.soulEffect(item:getQuality(),image)

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getGrade()))

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))
		
		local gradeTitle = tolua.cast(equipNode:getChildByName("Grade_Title"), "cc.Sprite")
		local gradeLabel = tolua.cast(equipNode:getChildByName("Grade_Label"), "ccui.Text")
        gradeTitle:setVisible(true)
		gradeLabel:setVisible(true)
		gradeLabel:setString(item:getGrade())
		
        local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
        if item:getSoulGrade() > 0 then
            strengthenLabel:setString(string.format("+%d",item:getSoulGrade()))
        else
            strengthenLabel:setString("")
        end

    end
    
    self.wearTable[wearType] = equipNode
    return equipNode
end

function RoleSoulLayer:wear(id)
    
    local equipNode = self.wearTable[self.wearRegion]
    
    local item = wd.GlobalData:getInstance():getWearSoul(self.wearRegion)
    if item == nil then
        equipNode:setVisible(false)
    else
        equipNode:setVisible(true)

        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getSoulId()))
        wd.soulEffect(item:getQuality(),image)
        image:removeAllChildren()

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getGrade()))

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))
		
		local gradeTitle = tolua.cast(equipNode:getChildByName("Grade_Title"), "cc.Sprite")
		local gradeLabel = tolua.cast(equipNode:getChildByName("Grade_Label"), "ccui.Text")
        gradeTitle:setVisible(true)
		gradeLabel:setVisible(true)
		gradeLabel:setString(item:getGrade())
        
        local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
        if item:getSoulGrade() > 0 then
            strengthenLabel:setString(string.format("+%d",item:getSoulGrade()))
        else
            strengthenLabel:setString("")
        end
    end
    
    self.attrScroll:setVisible(true)
    self.equipView:setVisible(false)
end

function RoleSoulLayer:unwear(tag)
    
    local role = wd.GlobalData:getInstance():getRoleData()
    
    
    if wd.GlobalData:getInstance():getSoulItemCount() < role:getSoulCapacity() then
    
        wd.GlobalData:getInstance():takeoffSoul(tag)
        
        local equipNode = self.wearTable[tag]
        equipNode:setVisible(false)
        
        self:createSoulList()
    end
end

function RoleSoulLayer:refreshWearSoul()
    
    for i=wd.WearRegion.WEAPON,wd.WearRegion.RRING do
        local equipNode = self.wearTable[i]
    
        local item = wd.GlobalData:getInstance():getWearSoul(i)
        if item == nil then
            equipNode:setVisible(false)
        else
            equipNode:setVisible(true)
    
            local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",item:getSoulId()))
			
			image:removeAllChildren()

			local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
			color:setSpriteFrame(string.format("%02d.png",item:getGrade()))

			local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
			levelLabel:setString(string.format("Lv%d",item:getLevel()))
			
			local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
			if item:getSoulGrade() > 0 then
				strengthenLabel:setString(string.format("+%d",item:getSoulGrade()))
			else
				strengthenLabel:setString("")
			end
        end
    end

end


function RoleSoulLayer:refreshSoulList()
    self:createSoulList()
end

function RoleSoulLayer:createSoulList()

    self.equipView:setVisible(true)
    self.attrScroll:setVisible(false)
    
    self.equipView:removeAllChildren()
    
    local function tableCellTouched(view, cell)
            local layerClass = require("src.game.soul.SoulTipsLayer")
			local layer = layerClass.create()
			layer:createLayerMenu(wd.soulHandler:setSoulItem(wd.GlobalData:getInstance():getSoulItem(cell:getTag())),2,self.wearRegion)
			self:addChild(layer)
    end
    
    local number = wd.GlobalData:getInstance():getSoulItemCount()
    
    local function numberOfCells(tableview)
        return number
    end
    
    local function cellSizeForTable(table,idx)
        return 140
    end
    local function tableCellAtIndexForce(table,idx)
        local cell = table:dequeueCell()
        if not cell then
            cell = cc.TableViewCell:create()
            local soulNode = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulPackageNode.csb"),"ccui.Widget")
            soulNode:setAnchorPoint(cc.p(0,0))
            soulNode:setScale(0.85)
            soulNode:setName("soul_node")
            cell:addChild(soulNode)
        end  
        cell:setTag(idx)
        local item = wd.GlobalData:getInstance():getSoulItem(idx)
        local soulNode = cell:getChildByName("soul_node")
        local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getSoulId()))

        wd.soulEffect(item:getQuality(),image)
        
        local color = item:getGrade()
        local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
        colorSprite:setSpriteFrame(string.format("%02d.png",color))

        local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
        gradeLabel:setString(string.format("阶位：%d",item:getGrade()))
        
        local topGradeLabel = tolua.cast(soulNode:getChildByName("Top_Grade_Label"), "ccui.Text")
        topGradeLabel:setString(item:getGrade())
            
        local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))

        local nameLabel = tolua.cast(soulNode:getChildByName("Name_Label"), "ccui.Text")
        nameLabel:setColor(wd.colorType(color))
        
        if item:getSoulGrade() >0 then
            nameLabel:setString(string.format("%s+%d",item:getName(), item:getSoulGrade()))
        else
            nameLabel:setString(item:getName())
        end
        return cell
    end
    
    local serverAreaNode = cc.TableView:create(self.equipView:getContentSize())
    self.serverAreaNode = serverAreaNode
    serverAreaNode:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
    serverAreaNode:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    serverAreaNode:setDelegate()
    serverAreaNode:registerScriptHandler(numberOfCells,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    serverAreaNode:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    serverAreaNode:registerScriptHandler(tableCellAtIndexForce,cc.TABLECELL_SIZE_AT_INDEX)
    serverAreaNode:registerScriptHandler(tableCellTouched, cc.TABLECELL_TOUCHED)
    serverAreaNode:reloadData()
    
    self.equipView:addChild(serverAreaNode)
end

function RoleSoulLayer:createLayerMenu()

    local node = tolua.cast(cc.CSLoader:createNode("ui/role/SoulScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local function backCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
			local event = cc.EventCustom:new("Check_New_Tip")
			cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
			self:clear()
        end
    end

    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(backCallback)
    
	
	local shieldBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Shield_Button"), "ccui.Widget")
    shieldBtn:setPressedActionEnabled(true)
    shieldBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.showRichTips(4,"暂未开放")
            end
        end
    )
	
    local equipPanel = ccui.Helper:seekWidgetByName(node,"Panel_Equip")
    local jobTitle = tolua.cast(equipPanel:getChildByName("Job_Title"), "cc.Sprite")
    
    jobTitle:setSpriteFrame(wd.getJobTitleName(wd.GlobalData:getInstance():getRoleJob()))
    jobTitle:setVisible(true)
    
    local familyName = tolua.cast(ccui.Helper:seekWidgetByName(node,"family_name"), "ccui.Text")
    local vipLevel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Vip_Level_Label"), "ccui.Text")
    
    local roleSprite = tolua.cast(equipPanel:getChildByName("Role_Sprite"), "cc.Sprite")

    local nameLabel = tolua.cast(equipPanel:getChildByName("Name_Label"), "ccui.Text")
    local powerLabel = tolua.cast(equipPanel:getChildByName("Power_Label"), "ccui.TextAtlas")
    local levelLabel = tolua.cast(equipPanel:getChildByName("Level_Label"), "ccui.Text")
    
    local attrScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Attr_ScrollView"), "ccui.ScrollView")
    local equipView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_View"), "ccui.Layout")
    equipView:setVisible(false)

    self.attrScroll = attrScroll
    self.equipView = equipView
    
    local attackTitle = tolua.cast(attrScroll:getChildByName("Attack_Title"), "cc.Sprite")
    local hpLabel = tolua.cast(attrScroll:getChildByName("Hp_Label"), "ccui.Text")
    local mpLabel = tolua.cast(attrScroll:getChildByName("Mp_Label"), "ccui.Text")
    local atkLabel = tolua.cast(attrScroll:getChildByName("Attack_Label"), "ccui.Text")
    local pdefLabel = tolua.cast(attrScroll:getChildByName("PDefence_Label"), "ccui.Text")
    local mdefLabel = tolua.cast(attrScroll:getChildByName("MDefence_Label"), "ccui.Text")
    local tdefLabel = tolua.cast(attrScroll:getChildByName("TDefence_Label"), "ccui.Text")
    local luckLabel = tolua.cast(attrScroll:getChildByName("Luck_Label"), "ccui.Text")
    local accuracyLabel = tolua.cast(attrScroll:getChildByName("Accuracy_Label"), "ccui.Text")
    local dodgeLabel = tolua.cast(attrScroll:getChildByName("Dodge_Label"), "ccui.Text")
    local vertigoLabel = tolua.cast(attrScroll:getChildByName("Vertigo_Label"), "ccui.Text")
    local reincarnateLabel = tolua.cast(attrScroll:getChildByName("Reincarnate_Label"), "ccui.Text")
    local manapreventLabel = tolua.cast(attrScroll:getChildByName("Manaprevent_Label"), "ccui.Text")
    local drainlifeLabel = tolua.cast(attrScroll:getChildByName("Drainlife_Label"), "ccui.Text")
    local critLabel = tolua.cast(attrScroll:getChildByName("Crit_Label"), "ccui.Text")
	local critDamLabel = tolua.cast(attrScroll:getChildByName("CritDam_Label"), "ccui.Text")
    local honorLabel = tolua.cast(attrScroll:getChildByName("Honor_Label"), "ccui.Text")
    local killLabel = tolua.cast(attrScroll:getChildByName("Kill_Label"), "ccui.Text")
    local luckBtn = tolua.cast(attrScroll:getChildByName("Luck_Button"), "ccui.Button")
	luckBtn:setPressedActionEnabled(true)
    luckBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.LuckUseLayer")
				local layer = layerClass.create()
				self:addChild(layer)
            end
        end
    )
	local killBtn = tolua.cast(attrScroll:getChildByName("Kill_Button"), "ccui.Button")
	killBtn:setPressedActionEnabled(true)
    killBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local item = wd.GlobalData:getInstance():getToolsItemInXml(wd.ItemId.KillWashDrug)
				local layerClass = require("src.tips.TipsBoxLayer")
				local msgTable = {}
				local msg = {}
				table.insert(msg,"是否用")
				table.insert(msg,string.format("{y=[%s]}",item:getName()))
				table.insert(msg,"消除")
				table.insert(msg,string.format("{g=[%d点]}",100))
                table.insert(msg,"杀戮值")
				table.insert(msgTable,msg)
				
				msg = {}
				table.insert(msg,"当前背包中有")
				table.insert(msg,string.format("{g=[%d个]}",wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.KillWashDrug)))
				table.insert(msg,string.format("{y=[%s]}",item:getName()))
				table.insert(msg,"可使用")
				table.insert(msgTable,msg)
				local function useKillDrug()
					wd.TranscodingSend:washPkValue()
				end
				self.tipsLayer = layerClass.create("wash_title.png", msgTable,useKillDrug)
				self:addChild(self.tipsLayer)
            end
        end
    )
	
    local function updataData()
    
        local role = wd.GlobalData:getInstance():getRoleData()

        familyName:setString(role:getRoleExtendData("family_name"))
        vipLevel:setString(role:getVip())
        
        roleSprite:setSpriteFrame(wd.getPlayerImageName(role:getOccupation(), role:getSex()))
        roleSprite:setVisible(true)
        if role:getSex() == 0 then
            roleSprite:setFlippedX(true)
        else
            roleSprite:setFlippedX(false)
        end
        
        nameLabel:setString(role:getName())
        powerLabel:setString(string.format("%d",role:getPower()))
        levelLabel:setString(string.format("%d级",role:getLevel()))
        
        hpLabel:setString(string.format("%d/%d",role:getHp(),role:getHp()))
        mpLabel:setString(string.format("%d/%d",role:getMp(),role:getMp()))
        
        if role:getOccupation() == 1 then
            attackTitle:setSpriteFrame("role_pattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getPAttack_min(), role:getPAttack_max()))
        elseif role:getOccupation() == 2 then
            attackTitle:setSpriteFrame("role_mattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getMAttack_min(), role:getMAttack_max()))
        elseif role:getOccupation() == 3 then
            attackTitle:setSpriteFrame("role_tattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getTAttack_min(), role:getTAttack_max()))
        end
        
        pdefLabel:setString(string.format("%d-%d", role:getPDefence_min(), role:getPDefence_max()))
        mdefLabel:setString(string.format("%d-%d", role:getMDefence_min(), role:getMDefence_max()))
        tdefLabel:setString(string.format("%d-%d", role:getTDefence_min(), role:getTDefence_max()))
        luckLabel:setString(string.format("%d",role:getLuck()))
        accuracyLabel:setString(string.format("%d",role:getAccuracy()))
        dodgeLabel:setString(string.format("%d",role:getDodge()))
        vertigoLabel:setString(string.format("%0.1f%%",role:getVertigo()/100.0))
        reincarnateLabel:setString(string.format("%0.1f%%",role:getReincarnate()/100.0))
        manapreventLabel:setString(string.format("%0.1f%%",role:getManaprevent()/100.0))
        drainlifeLabel:setString(string.format("%0.1f%%",role:getDrainlife()/100.0))
        critLabel:setString(string.format("%0.1f%%",role:getCrit()/100.0))
		critDamLabel:setString(string.format("%0.01f%%",role:getCritDam()/100))
        honorLabel:setString(string.format("%d",role:getHonor()))
        killLabel:setString(string.format("%d",role:getKill()))
    end

    updataData()
    
    local function showSoulList()
		local item = wd.GlobalData:getInstance():getWearSoul(self.wearRegion)
        if item ~= nil then
            local layerClass = require("src.game.soul.SoulTipsLayer")
			local layer = layerClass.create()
			layer:createLayerMenu(wd.soulHandler:setSoulItem(item),1,self.wearRegion)
			self:addChild(layer)
        end
        self:createSoulList()
    end
    
    local attrBtn = ccui.Helper:seekWidgetByName(equipPanel,"Role_Button")
    attrBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                equipView:setVisible(false)
                attrScroll:setVisible(true)
            end
        end
    )
	
	local soulBtn = ccui.Helper:seekWidgetByName(equipPanel,"Soul_Button")
    soulBtn:setPressedActionEnabled(true)
    soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_WearSoul")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Soul")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Role")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Wash_Pk_Value")
                local layerClass = require("src.game.RoleLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
				self:removeFromParent()
            end
        end
    )
    
    local helmetBtn = ccui.Helper:seekWidgetByName(equipPanel,"Helmet_Button")
    helmetBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.HELMET
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.HELMET)
    helmetBtn:addChild(equipNode)
    
    local necklaceBtn = ccui.Helper:seekWidgetByName(equipPanel,"Necklace_Button")
    necklaceBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.NECKLACE
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.NECKLACE)
    necklaceBtn:addChild(equipNode)
    
    local breastplateBtn = ccui.Helper:seekWidgetByName(equipPanel,"Breastplate_Button")
    breastplateBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.BREASTPLATE
                showSoulList()
            end
        end
    )
    
    local equipNode = self:createWearNode(wd.WearRegion.BREASTPLATE)
    breastplateBtn:addChild(equipNode)
    
    local shoeBtn = ccui.Helper:seekWidgetByName(equipPanel,"Shoe_Button")
    shoeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.SHOE
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.SHOE)
    shoeBtn:addChild(equipNode)
    
    local weaponBtn = ccui.Helper:seekWidgetByName(equipPanel,"Weapon_Button")
    weaponBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.WEAPON
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.WEAPON)
    weaponBtn:addChild(equipNode)
    
    local lWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"LWrist_Button")
    lWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.LWRIST
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.LWRIST)
    lWristBtn:addChild(equipNode)
    
    local rWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"RWrist_Button")
    rWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.RWRIST
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.RWRIST)
    rWristBtn:addChild(equipNode)
    
    local lRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"LRing_Button")
    lRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.LRING
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.LRING)
    lRingBtn:addChild(equipNode)
    
    local rRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"RRing_Button")
    rRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.wearRegion = wd.WearRegion.RRING
                showSoulList()
            end
        end
    )
    local equipNode = self:createWearNode(wd.WearRegion.RRING)
    rRingBtn:addChild(equipNode)
    
    local function updataWear()
        self:refreshWearSoul()
    end
    
    local function updataSoul()
        self:refreshSoulList()
    end
	
	local function equipAttributeChangeCallBack()
		--wd.showAttributeChangeTip()
		local oldRole = wd.GlobalData:getInstance():getOldRoleData()
		local newRole = wd.GlobalData:getInstance():getRoleData()
		local roleAttributeClass = require("src.game.RoleAttribute"):getInstance()
		for i,v in pairs(roleAttributeClass.RoleBaseAttribute) do
			local changeValue = v.getFunc(newRole) - v.getFunc(oldRole)
			if changeValue ~= 0 then
				local sign = (changeValue < 0) and "" or "+"
				local color = (changeValue < 0) and cc.c3b(255,0,0) or cc.c3b(0,255,0)
				local x,y = equipPanel:getPosition()
				x = x+equipPanel:getContentSize().width/2
				y = y+equipPanel:getContentSize().height/2
				if i == "CritDam" then
					changeValue = changeValue/100
				end
				changeValue = tostring(changeValue)
				if i == "Vertigo" or i == "Manaprevent" or i == "Reincarnate" or i == "Drainlife" or i == "CritDam" then
					changeValue = changeValue.."%"
				end
				wd.showAttributeTips(string.format("%s %s%s",v.name,sign,changeValue),color,35,cc.p(x,y))
			end
		end
	end

	local listener_AttributeChange = cc.EventListenerCustom:create("Equip_AttributeChange", equipAttributeChangeCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener_AttributeChange, 1); 
    
    local listener = cc.EventListenerCustom:create("Update_WearSoul", updataWear)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    local listener = cc.EventListenerCustom:create("Update_Soul", updataSoul)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    local listener = cc.EventListenerCustom:create("Update_Role", updataData)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	local function onWashPkValue(EventCustom)
		if self.tipsLayer then
			wd.showRichTips(4,"使用成功")
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Wash_Pk_Value", onWashPkValue)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end



return RoleSoulLayer