local StrengthenLayer = class("StrengthenLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function StrengthenLayer.create()
    local layer = StrengthenLayer.new()
    return layer
end

function StrengthenLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.effectPanel = nil
    self.protect = false
    
end


function StrengthenLayer:setEquipNode(node, nameLabel, item, strengthenLevel)

    local color = item:getColor()
    
    if item:getQuality() >= 2 then
        color = 6
    end
        
    if  item:getQuality() >= 2 and strengthenLevel >= 15 then
        nameLabel:setString(string.format("%s%s+%d",wd.getEquipTitle(item:getOccupation()), item:getName(), strengthenLevel))
    else
        nameLabel:setString(string.format("%s+%d",item:getName(), strengthenLevel))
    end
    
    nameLabel:setColor(wd.colorType(color))

    
    local image = tolua.cast(node:getChildByName("Equip_Sprite"), "cc.Sprite")
    image:setVisible(true)
    image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
    
    image:removeAllChildren()
    wd.equipEffectAction(strengthenLevel, item:getQuality(), image)

    local colorSprite = tolua.cast(node:getChildByName("Color_Sprite"), "cc.Sprite")
    colorSprite:setVisible(true)
    colorSprite:setSpriteFrame(string.format("%02d.png",color))

    local levelLabel = tolua.cast(node:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setVisible(true)
    levelLabel:setString(string.format("Lv %d",item:getLevel()))
        
end

function StrengthenLayer:effect(backBtn)

    self.effectPanel:setVisible(true)

    local effect = tolua.cast(self.effectPanel:getChildByName("Strengthen_Effect"), "cc.Sprite")

    local function delayCallBackFunc(sender)
        self.effectPanel:setVisible(false)
        ------------------------------新手引导关闭强化界面并引导关闭角色界面----------------------------
        local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
        if clippingLayer then
            clippingLayer:setGuidance(backBtn,30,50,115,115,nil,true)
            local msgTable = {}
            local msg = {}
            table.insert(msg,"很好，")
            table.insert(msg,"{r=[强化成功]}")
            table.insert(msg,"了，咱们回到主界面！")
            table.insert(msgTable,msg)
            clippingLayer:setMsg(msgTable)
            self:addChild(clippingLayer)
            backBtn:addTouchEventListener(
                function(sender,eventType)
                    if eventType == ccui.TouchEventType.ended then
                        if clippingLayer then
                            local event = cc.EventCustom:new("guidance_closeRoleLayer")
		                    cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                            clippingLayer:removeFromParent()
                            clippingLayer = nil
                        end
                        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Strengthen_Update")
                        self:removeFromParent()
                    end
                end
            )
        end
        ------------------------------------------------------------------
    end
    
    local delayCallBack = cc.CallFunc:create(delayCallBackFunc)

    local animation = cc.Animation:create()
    for i = 1, 16 do
        animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("strengthen_%02d.png", i)))
    end

    animation:setDelayPerUnit(0.08)
    animation:setLoops(1)
    local action = cc.Animate:create(animation)
    local sequenceAction = cc.Sequence:create(action, delayCallBack)
    
    effect:runAction(sequenceAction)
end

function StrengthenLayer:preview(wearRegion , strengthen_level)
    local layerClass = require("src.game.package.EquipTipsLayer")
    local layer = layerClass.create()
    layer:createLayerMenu(0, wearRegion, 2, strengthen_level)
    self:addChild(layer)
end


function StrengthenLayer:createLayerMenu(wearRegion)
    local node = tolua.cast(cc.CSLoader:createNode("ui/strengthen/StrengthenScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				--cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Strengthen_Update")
                self:removeFromParent()
            end
        end
    )

    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
    local effectPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Effect"), "ccui.Widget")
    effectPanel:setVisible(false)
    self.effectPanel = effectPanel


    local item = wd.GlobalData:getInstance():getWearEquip(wearRegion)
   
    local beforeBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Before_Button"), "ccui.Button")
    beforeBtn:addTouchEventListener(
        function (sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:preview(wearRegion , -1)
            end
        end
    )
    
    local afterBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"After_Button"), "ccui.Button")
    afterBtn:addTouchEventListener(
        function (sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if item:getStrengthenLevel() < wd.GlobalData:getInstance():getStrengthenMaxLevel() then
                    self:preview(wearRegion , item:getStrengthenLevel()+1)
                end
            end
        end
    )
    local ultimateBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Ultimate_Button"), "ccui.Button")
    ultimateBtn:addTouchEventListener(
        function (sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:preview(wearRegion , wd.GlobalData:getInstance():getStrengthenMaxLevel())
            end
        end
    )

    local beforeNode = tolua.cast(mainPanel:getChildByName("Before_Node"), "cc.Node")
    local afterNode = tolua.cast(mainPanel:getChildByName("After_Node"), "cc.Node")
    local ultimateNode = tolua.cast(mainPanel:getChildByName("Ultimate_Node"), "cc.Node")
    
    local beforeName = tolua.cast(mainPanel:getChildByName("Before_Name"), "cc.Node")
    local afterName = tolua.cast(mainPanel:getChildByName("After_Name"), "cc.Node")
    local ultimateName = tolua.cast(mainPanel:getChildByName("Ultimate_Name"), "cc.Node")
    
    

    local underPanel = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Panel_Under"), "ccui.Widget")

    local moneyLabel = tolua.cast(underPanel:getChildByName("Money_Label"), "ccui.Text")
    local moneyCurLabel = tolua.cast(underPanel:getChildByName("MoneyCur_Label"), "ccui.Text")
    local stoneLabel = tolua.cast(underPanel:getChildByName("Stone_Label"), "ccui.Text")
    local stoneCurLabel = tolua.cast(underPanel:getChildByName("StoneCur_Label"), "ccui.Text")
    local protectCurLabel = tolua.cast(underPanel:getChildByName("ProtectCur_Label"), "ccui.Text")
    local gold = tolua.cast(ccui.Helper:seekWidgetByName(node,"gold"), "ccui.Text")
    local stone = tolua.cast(ccui.Helper:seekWidgetByName(node,"stone"), "ccui.Text")
    local tiangong = tolua.cast(ccui.Helper:seekWidgetByName(node,"tian_gong"), "ccui.Text")
    --beforeName:setColor(wd.colorType(item:getColor()))
    --afterName:setColor(wd.colorType(item:getColor()))
    --ultimateName:setColor(wd.colorType(item:getColor()))
    
    local oldLevel = -1
    local oldFightPower = wd.GlobalData:getInstance():getRoleData():makePower()
    local function updataText()
        local maxLevel = wd.GlobalData:getInstance():getStrengthenMaxLevel()
        local level = item:getStrengthenLevel()
        local strengthenXml = wd.GlobalData:getInstance():getStrengthenXml(level)
        
        local addTitle = tolua.cast(ccui.Helper:seekWidgetByName(node,"strengthen_add_title"), "ccui.Text")
        addTitle:setString("本次主属性+"..strengthenXml:getValue().."%")
        
        if strengthenXml then
            moneyLabel:setString(string.format("%d",strengthenXml:getUseMoney()))
            stoneLabel:setString(string.format("%d",strengthenXml:getUseStone()))
        else
            moneyLabel:setString(string.format(""))
            stoneLabel:setString(string.format(""))
        end
        stone:setString((level+2)*item:getLevel().."/"..wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.StrengthenStone))
        gold:setString((level+1)*1000*item:getLevel().."/"..wd.GlobalData:getInstance():getRoleGold())
        tiangong:setString((level+1)*item:getLevel().."/"..wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.ProtectStone))
        
        moneyCurLabel:setString(string.format("(当前拥有:          %d )",wd.GlobalData:getInstance():getRoleGold()))
        stoneCurLabel:setString(string.format("(当前拥有:          %d )",wd.GlobalData:getInstance():useToolsItemForId(wd.ItemId.StrengthenStone, 0)))
        protectCurLabel:setString(string.format("(当前拥有:          %d )",wd.GlobalData:getInstance():useToolsItemForId(wd.ItemId.ProtectStone, 0)))
      
        if oldLevel ~= level then
        	--beforeName:setString(string.format("%s+%d",item:getName(), level))
            self:setEquipNode(beforeNode, beforeName, item, level)
    
        	if (level < maxLevel) then
                self:setEquipNode(afterNode, afterName, item, level+1)
        	   --afterName:setString(string.format("%s+%d",item:getName(), level+1))
        	else
                afterName:setString(string.format(""))
        	end 

            --ultimateName:setString(string.format("%s+%d",item:getName(), maxLevel))
            self:setEquipNode(ultimateNode, ultimateName, item, maxLevel)
        end
        
        oldLevel = level
		--[[local newFightPower = wd.GlobalData:getInstance():getRoleData():makePower()
		if newFightPower - oldFightPower > 0 then
			wd.showRichTips(4,string.format("战斗力 +%d",newFightPower-oldFightPower))
		end--]]
    end
    
    
    local protectCheck = tolua.cast(ccui.Helper:seekWidgetByName(node,"Protect_Check"), "ccui.CheckBox")
    protectCheck:addEventListener(
        function(sender,eventType)
            if eventType == ccui.CheckBoxEventType.selected then
                self.protect = true
            else
                self.protect = false
            end
        end
    )
    
    local strengthenBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Strengthen_Button"), "ccui.Widget")
	local x,y = strengthenBtn:getPosition()
	wd.newGuidePos[wd.newGuideStep.StrengthEnter] = {}
	wd.newGuidePos[wd.newGuideStep.StrengthEnter].pos = strengthenBtn:getParent():convertToWorldSpace(cc.p(x,y))
	wd.newGuidePos[wd.newGuideStep.StrengthEnter].size = strengthenBtn:getContentSize()
    strengthenBtn:setPressedActionEnabled(true)
    
    ------------------------------新手引导----------------------------
    local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
    if clippingLayer then
        clippingLayer:setGuidance(strengthenBtn,10,10,115,115)
        local msgTable = {}
        local msg = {}
        table.insert(msg,"咱们来")
        table.insert(msg,"{r=[强化+1]}")
        table.insert(msg,"试试！")
        table.insert(msgTable,msg)
        clippingLayer:setMsg(msgTable)
        self:addChild(clippingLayer)
    end
    ------------------------------------------------------------------
    
    
    strengthenBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
            
                local level = item:getStrengthenLevel()
				oldFightPower = wd.GlobalData:getInstance():getRoleData():makePower()
        
       
                if wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.ProtectStone) < (level+1)*item:getLevel() then  -- -1 not enough
                    wd.showRichTips(4,"天工神石不足")
                    return
                end

                
                if wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.StrengthenStone) < (level+2)*item:getLevel() then  -- -1 not enough
                    wd.showRichTips(4,"黑铁矿石不足")
                    return
                end
                
                if wd.GlobalData:getInstance():getRoleGold() < (level+1)*1000*item:getLevel() then  -- -1 not enough
                    wd.showRichTips(4,"金币不足")
                    return
                end
                
                self:effect(backBtn)

                if self.protect == true then
                    wd.TranscodingSend:setEquipStrengthen(item:getServerId(), 1)
                else
                    wd.TranscodingSend:setEquipStrengthen(item:getServerId(), 0)
                end
                
                if clippingLayer then
                    clippingLayer:removeFromParent()
                    clippingLayer = nil
                end
                
               
                --local event = cc.EventCustom:new("Handle_NewGuile")
                --cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)

            end
        end
    )
    
    local itemPosition = wd.getRegionString(item:getRegion())
    local beforePosition = tolua.cast(ccui.Helper:seekWidgetByName(node,"Before_Position"), "ccui.Text")
    local afterPosition = tolua.cast(ccui.Helper:seekWidgetByName(node,"After_Position"), "ccui.Text")
    beforePosition:setString(itemPosition)
    afterPosition:setString(itemPosition)
    
    local itemJob = wd.getEquipJobString(item:getOccupation())
    local beforeJob = tolua.cast(ccui.Helper:seekWidgetByName(node,"Before_Job"), "ccui.Text")
    local afterJob = tolua.cast(ccui.Helper:seekWidgetByName(node,"After_Job"), "ccui.Text")
    beforeJob:setString(itemJob)
    afterJob:setString(itemJob)
    
    local function updateCallback(EventCustom)
        updataText()
    end
    
    local listenerChange = cc.EventListenerCustom:create("Strengthen_Update", updateCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerChange, 1);
	
    updataText()

end


return StrengthenLayer