
local ActivityLayer = class("ActivityLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function ActivityLayer.create()
    local layer = ActivityLayer.new()
    layer:createLayerMenu()
    return layer
end

function ActivityLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.activityHandler 
	self.selectTag = 1
	self.monthCartType = {
		[1] = 250,
		[2] = 500,
	}
	self.isShowEffect = false
end

function ActivityLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_MonthCard_View")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Fund_View")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Charge_View")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Consume_View")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Everyday_View")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Vip_View")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Login_View")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_Grow_Gem")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Activity_Award")
	-- cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_MonthCard_Award")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
end

function ActivityLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
    
	local btnListView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Button_ListView"), "ccui.ListView")

	self.contentPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Content_Panel"), "ccui.Widget")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Box"), "ccui.Widget")
	self.getAwardEffect = tolua.cast(mainPanel:getChildByName("Get_Award_Effect"), "cc.Sprite")
	
	local function onBtnTouch(sender,eventType)
		if eventType == ccui.TouchEventType.ended then
			if self.selectTag == sender:getTag() then
				return
			end
			local lastBtn = btnListView:getChildByTag(self.selectTag)
			local curBtn = btnListView:getChildByTag(sender:getTag())
			if lastBtn and curBtn then
				local lastNode = lastBtn:getChildByTag(self.selectTag)
				local curNode = curBtn:getChildByTag(sender:getTag())
				-- local lastSelectBox = tolua.cast(lastNode:getChildByName("Select_Sprite"), "cc.Sprite")
				-- local curSelectBox = tolua.cast(curNode:getChildByName("Select_Sprite"), "cc.Sprite")
				-- if lastSelectBox and curSelectBox then
				-- 	lastSelectBox:setVisible(true)
				-- 	curSelectBox:setVisible(false)
				-- end
                
                local lastSpreeBtn = tolua.cast(lastNode:getChildByName("spree_btn"), "cc.Sprite")
				local curSpreeBtn = tolua.cast(curNode:getChildByName("spree_btn"), "cc.Sprite")
				if lastSpreeBtn and curSpreeBtn then
					lastSpreeBtn:setSpriteFrame("spree_btn_normal.png")
					curSpreeBtn:setSpriteFrame("spree_btn_select.png")
				end    
			end
            
			self.selectTag = sender:getTag()
			self:showSubView(sender:getTag())
		end
	end
	
	
	local function initBtnList(selectTag)
		for i,v in ipairs(wd.activityInfo) do
            local isNew
			if (v.id == 0 or wd.activityHandler:isActivityOpen(v.id)) and v.isShow == true then
				local btn = ccui.Layout:create()
                btn:setContentSize(170,80)
                btn:setTouchEnabled(true)
				local btnNode = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityBtnNode.csb"),"ccui.Widget")
				local titleSprite = tolua.cast(btnNode:getChildByName("Button_Title"),"cc.Sprite")
				titleSprite:setSpriteFrame(v.png)
                
                local title = tolua.cast(btnNode:getChildByName("title"),"ccui.Text")
                title:setString(v.title)
                
                local describe = tolua.cast(btnNode:getChildByName("describe"),"ccui.Text")
                describe:setString(v.describe)
                
				btnNode:setTag(i)
				btn:addChild(btnNode)
				local newActSprite = cc.Sprite:create()
				newActSprite:setSpriteFrame("newTips_01.png")
				local role = wd.GlobalData:getInstance():getRoleData()
				if wd.GlobalData:getInstance():getActivityIsNewById(v.id) and not isNew then
                    isNew = true
					btn:addChild(newActSprite)
					newActSprite:setPosition(cc.p(15,btn:getContentSize().height-5))
					wd.showNewTipsEffect(newActSprite)
				end
				-- local selectBox = tolua.cast(btnNode:getChildByName("Select_Sprite"), "cc.Sprite")
				-- if selectTag then
				-- 	if i == selectTag then
				-- 		selectBox:setVisible(false)
				-- 		self:showSubView(i)
				-- 	else
				-- 		selectBox:setVisible(true)
				-- 	end
				-- end
				local spreeBtn = tolua.cast(btnNode:getChildByName("spree_btn"), "cc.Sprite")
                if selectTag then
					if i == selectTag then
						spreeBtn:setSpriteFrame("spree_btn_select.png")
						self:showSubView(i)
					else
						spreeBtn:setSpriteFrame("spree_btn_normal.png")
					end
				end
                
				btn:setAnchorPoint(cc.p(0,0))
				btn:setTag(i)
				btn:addTouchEventListener(onBtnTouch)
				btnListView:pushBackCustomItem(btn)
			end
		end
	end
	
	local function refreshBtnList()
		btnListView:removeAllItems()
		initBtnList(self.selectTag)
	end
	
	initBtnList(1)
	
        ---------------------------------------monthcard-----------------------------------------------
	
	-- local function onUpdateMonthCardView()
	-- 	self:updateMonthCardView()
	-- end
	-- local listener = cc.EventListenerCustom:create("Update_MonthCard_View", onUpdateMonthCardView)
	-- cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	-- local function onGetMonthCardAward()
	-- 	--wd.showSystemTips("领取成功")
	-- 	wd.activityHandler:requestGetMonthCardState()
	-- end
	-- local listener = cc.EventListenerCustom:create("Get_MonthCard_Award", onGetMonthCardAward)
	-- cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	---------------------------------------fund--------------------------------------------------
	local function onUpdateFundView()
		if self.getAward then
			refreshBtnList()
			self.getAward = false
		end
		self:updateFundView()
	end
	local listener = cc.EventListenerCustom:create("Update_Fund_View", onUpdateFundView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onBuyGrowGem()
		if self.tipsLayer then
			wd.showRichTips(4,"购买成功")
			wd.activityHandler:updataAwardState()
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Buy_Grow_Gem", onBuyGrowGem)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	-------------------------------------------charge----------------------------------------------
	local function onUpdateChargeView()
		if self.getAward then
			refreshBtnList()
			self.getAward = false
		end
		self:updateChargeView()
	end
	local listener = cc.EventListenerCustom:create("Update_Charge_View", onUpdateChargeView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
    -----------------------------------------everyday------------------------------------------------
	
	local listener = cc.EventListenerCustom:create("Update_Everyday_View", onUpdateChargeView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    -----------------------------------------vip------------------------------------------------

	local listener = cc.EventListenerCustom:create("Update_Vip_View", onUpdateChargeView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
	-----------------------------------------consume------------------------------------------------
	local function onUpdateConsumeView()
		if self.getAward then
			refreshBtnList()
			self.getAward = false
		end
		self:updateConsumeView()
	end
	local listener = cc.EventListenerCustom:create("Update_Consume_View", onUpdateConsumeView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	-----------------------------------------login------------------------------------------------
	local function onUpdateLoginView()
		if self.getAward then
			refreshBtnList()
			self.getAward = false
		end
		-- self:updateLoginView()
	end
	local listener = cc.EventListenerCustom:create("Update_Login_View", onUpdateLoginView)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	

	---------------------------------------------------------------------------------------
    
	local function onGetActivityAward()
		--wd.showSystemTips("领取成功")
		wd.activityHandler:updataAwardState()
		self.getAward = true
	end
	local listener = cc.EventListenerCustom:create("Get_Activity_Award", onGetActivityAward)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function getCallback(EventCustom)
		self.isShowEffect = true
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
		--self:effect()
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function ActivityLayer:showSubView(tag)
	self.contentPanel:removeAllChildren()
	wd.activityHandler:requestActivityAwardState(wd.activityInfo[tag].id)
end

function ActivityLayer:handleFundIsShow()
	if wd.activityInfo[wd.activityType.Fund].isShow == true then
		local awardList = wd.activityHandler:getAwardListByActivityId(wd.activityInfo[wd.activityType.Fund].id)
		for i,v in ipairs(awardList) do
			local state = wd.GlobalData:getInstance():getAwardState(v.id)
			if state == wd.awardState.Unreach or state == wd.awardState.CanGet then
				return
			end
		end
		wd.activityInfo[wd.activityType.Fund].isShow = false
	end
end

-- monthcard
function ActivityLayer:updateMonthCardView()
	self.contentPanel:removeAllChildren()
	local node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityMonthCardNode.csb"),"ccui.Widget")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget") 
	mainPanel:setContentSize(self.contentPanel:getContentSize())
	ccui.Helper:doLayout(mainPanel)
	
	for i,v in ipairs(self.monthCartType) do
		local monthCardItem = wd.GlobalData:getInstance():getMonthCardItem(i-1)
		local monthCardNode = tolua.cast(mainPanel:getChildByName(string.format("MonthCard_%d",v)),"ccui.Widget")
		local buyBtn = tolua.cast(monthCardNode:getChildByName("Buy_Button"),"ccui.Button")
		buyBtn:setPressedActionEnabled(true)
		buyBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local item = wd.GlobalData:getInstance():getChargeXmlData("month_card",i-1)
					if item ~= nil then
						if not wd.SdkApi:isTencentSdk() then
							wd.GlobalData:getInstance():setChargeData(item)
							wd.TranscodingSend:createOrder(item:getChargeCode(),item:getMoney())
						else
							wd.GlobalData:getInstance():setChargeData(item)
							wd.TranscodingSend:tencentPay()
						end
					else
						wd.showRichTips(4,"充值数据有误")
					end
				    --[[local item = wd.GlobalData:getInstance():getChargeXmlData("month_card",i-1)
					local payDir = "http://wendingttlx.51vip.biz:"
					-- 购买 
					if item ~= nil then
						local role = wd.GlobalData:getInstance():getRoleData()
						local server = wd.GlobalData:getInstance():getGameServerForId(wd.GlobalData:getInstance():getAreaId())
						if server ~= nil and role ~= nil then
							local port = server:getPort()
							payDir = string.format("%s%d",payDir,port)
							print(payDir)
							wd.SdkApi:pay(item:getMoney(), server:getServerId(), server:getName(), role:getRoleId(), role:getName(), role:getLevel(),payDir, string.format("%d",item:getChargeCode()))
						end
					else
						wd.showRichTips(4,"充值数据有误")
					end--]]
				end
			end
		)
		
		local getBtn = tolua.cast(monthCardNode:getChildByName("Get_Button"),"ccui.Button")
		getBtn:setPressedActionEnabled(true)
		getBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					wd.activityHandler:requestGetMonthCardAward(v)
				end
			end
		)
		
		local leftLabel = tolua.cast(monthCardNode:getChildByName("Left_Label"),"ccui.Text")
		local today = os.date("*t")	
		local secondOfToday = os.time({day=today.day, month=today.month,year=today.year, hour=0, minute=0, second=0})
		local buyTime = monthCardItem:getBuyTime()
		local leftTime = 30 - (secondOfToday-buyTime)/24/3600
		if leftTime < 0 then leftTime = 0 end
		leftLabel:setString(string.format("剩余天数：%d天",leftTime))
			
		local hadGetSprite = tolua.cast(monthCardNode:getChildByName("HadGet_Sprite"),"cc.Sprite")
		
		local hadBuyFlag = false
		local hadGetFlag = false
		if monthCardItem:getActivityState() == wd.awardState.CanGet or monthCardItem:getActivityState() == wd.awardState.HadGet then
			hadBuyFlag = true
			if monthCardItem:getActivityState() == wd.awardState.HadGet then
				hadGetFlag = true
			end
		end
		buyBtn:setVisible(not hadBuyFlag)
		getBtn:setVisible(hadBuyFlag)
		leftLabel:setVisible(hadBuyFlag)
		hadGetSprite:setVisible(hadGetFlag)
	end	
	self.contentPanel:addChild(node)
	node:setTag(wd.activityType.MonthCard)
	node:setPosition(0,0)
	if self.isShowEffect then
		--self:effect()
		self.isShowEffect = false
	end
end

-- fund
function ActivityLayer:updateFundView()
	self.contentPanel:removeAllChildren()
	local node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityFundNode.csb"),"ccui.Widget")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget") 
	mainPanel:setContentSize(self.contentPanel:getContentSize())
	ccui.Helper:doLayout(mainPanel)
	-- local isBuy = wd.GlobalData:getInstance():getRoleData():getRoleExtendData("isBuyFund")
	local chargeButton = tolua.cast(mainPanel:getChildByName("GoCharge_Button"),"ccui.Button")
	chargeButton:setPressedActionEnabled(true)
	chargeButton:addTouchEventListener(
		function(sender,eventType)
			if eventType == ccui.TouchEventType.ended then
                -- if isBuy then
                --     wd.showRichTips(wd.tipsType.System,"已购买")
                --     return
                -- end
				local layerClass = require("src.tips.TipsBoxLayer")
				local msgTable = {}
				local msg = {}
				table.insert(msg,"是否花")
				table.insert(msg,string.format("{y=[%d元宝]}",1000))
				table.insert(msg,"购买成长基金")
				table.insert(msgTable,msg)
				local function buyNumber()
                    if wd.GlobalData:getInstance():getRoleGem() < 1000 then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
                        wd.activityHandler:requestBuyFund()
                    end
				end
				self.tipsLayer = layerClass.create("activity_subtitle_buyfund.png", msgTable,buyNumber)
				self:addChild(self.tipsLayer)
			end
		end
	)

	local contentListView = tolua.cast(mainPanel:getChildByName("Content_ListView"), "ccui.ListView")
	local listViewWidth = contentListView:getContentSize().width
	local awardList = wd.activityHandler:getAwardListByActivityId(100)
	for i,v in ipairs(awardList) do
		local widget = ccui.Widget:create()
		local fundNode =  tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityFundSubNode.csb"),"ccui.Widget")
		local subMainPanel = tolua.cast(fundNode:getChildByName("Main_Panel"), "ccui.Widget")
		local size = subMainPanel:getContentSize()
		size.width = listViewWidth
		widget:setContentSize(size)
		subMainPanel:setContentSize(size)
		subMainPanel:setSwallowTouches(false)
		ccui.Helper:doLayout(subMainPanel)
		
		local levelLabel = tolua.cast(subMainPanel:getChildByName("Level_Label"),"ccui.TextAtlas")
		levelLabel:setString(v.condition)
		local getButton = tolua.cast(subMainPanel:getChildByName("Get_Button"),"ccui.Button")
		local cannotGetBtn = tolua.cast(subMainPanel:getChildByName("CannotGet_Button"),"ccui.Button")
		local hadGetSprite = tolua.cast(subMainPanel:getChildByName("HadGet_Sprite"),"cc.Sprite")
		getButton:removeFromParent()
		widget:addChild(getButton,1)
		getButton:setPressedActionEnabled(true)
		cannotGetBtn:removeFromParent()
		widget:addChild(cannotGetBtn,1)
		cannotGetBtn:setPressedActionEnabled(true)
		
		v.state = wd.GlobalData:getInstance():getAwardState(v.id)
		if v.state == wd.awardState.Unreach then
			cannotGetBtn:setVisible(true)
			getButton:setVisible(false)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.CanGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(true)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.HadGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(false)
			hadGetSprite:setVisible(true)
		end
		getButton:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					--[[if v.state == wd.awardState.Unreach then
						wd.showSystemTips("还未达成，多努力哦")
					elseif v.state == wd.awardState.CanGet then
						wd.activityHandler:requestGetAward(v.activityId,v.id)
					elseif v.state == wd.awardState.HadGet then
						wd.showSystemTips("该奖励已领取")
					end--]]
					wd.activityHandler:requestGetAward(v.activityId,v.id)
				end
			end
		)
		cannotGetBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
                    -- if isBuy then
                    --     local msg = {}
                    --     table.insert(msg,"等级达到")
                    --     table.insert(msg,string.format("{u=[%s],c1=[%d],c2=[%d],c3=[%d],c4=[%d]}",v.condition.."级",0,255,0,255))
                    --     table.insert(msg,"才能领取")
                    --     wd.showRichTips(wd.tipsType.System,msg)
                    -- else
                        wd.showRichTips(wd.tipsType.System,"请先购买基金再来领取")
                    -- end
				end
			end
		)
		
		local contentLabel = tolua.cast(subMainPanel:getChildByName("Content_Label"),"ccui.Text")
		contentLabel:setString(string.format("达到%d级即可领取%d元宝",v.condition,v.awardList[1].itemCount))
		
		local toolSprite = tolua.cast(subMainPanel:getChildByName("Tools_Sprite"),"cc.Sprite")
		toolSprite:setSpriteFrame(string.format("%d.png",v.awardList[1].itemId))
		local colorSprite = tolua.cast(subMainPanel:getChildByName("Color_Sprite"),"cc.Sprite")
		colorSprite:setSpriteFrame(string.format("%02d.png",5))
		local numberLabel = tolua.cast(subMainPanel:getChildByName("Number_Label"),"ccui.Text")
		numberLabel:setString(v.awardList[1].itemCount)
		
		widget:setAnchorPoint(cc.p(0,0))
		widget:setTag(i)
		widget:addChild(fundNode)
		fundNode:setPosition(cc.p(0,0))
		contentListView:pushBackCustomItem(widget)
	end
	
	self.contentPanel:addChild(node)
	node:setTag(wd.activityType.Fund)
	node:setPosition(0,0)
	if self.isShowEffect then
		--self:effect()
		self.isShowEffect = false
	end
end

--Charge
function ActivityLayer:updateChargeView()
	self.contentPanel:removeAllChildren()
	local node 
    if wd.activityInfo[self.selectTag].id == 101 then
        node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityChargeNode.csb"),"ccui.Widget")
        local chargeLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Charge_Label"), "ccui.Text")
	    chargeLabel:setString(string.format("累计充值：%d 元宝",wd.GlobalData:getInstance():getTotalCharge()))
    elseif wd.activityInfo[self.selectTag].id == 104 then
        node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityNode.csb"),"ccui.Widget")
    elseif wd.activityInfo[self.selectTag].id == 105 then
        node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityNode.csb"),"ccui.Widget")
        tolua.cast(node:getChildByName("Main_Panel"):getChildByName("spree_text"), "cc.Sprite"):setSpriteFrame("spree_text_1.png")
        tolua.cast(ccui.Helper:seekWidgetByName(node,"GoCharge_Button"), "cc.Sprite"):getChildByName("btn_title"):setSpriteFrame("spree_vip_title.png")
    end
    
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget") 
	mainPanel:setContentSize(self.contentPanel:getContentSize())
	ccui.Helper:doLayout(mainPanel)
	
	local chargeButton = tolua.cast(mainPanel:getChildByName("GoCharge_Button"),"ccui.Button")
	chargeButton:setPressedActionEnabled(true)
	chargeButton:addTouchEventListener(
		function(sender,eventType)
			if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.charge.ChargeLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:clear()
			end
		end
	)
	
	local contentListView = tolua.cast(mainPanel:getChildByName("Content_ListView"), "ccui.ListView")
	local listViewWidth = contentListView:getContentSize().width
	local awardList = wd.activityHandler:getAwardListByActivityId(wd.activityInfo[self.selectTag].id)
    local todayCharge = wd.GlobalData:getInstance():getRoleData():getRoleExtendData("today_recharge_amount")
    todayCharge = tonumber(todayCharge)
    
	for i,v in ipairs(awardList) do
		local widget = ccui.Widget:create()
		local chargeNode =  tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityChargeSubNode.csb"),"ccui.Widget")
		local subMainPanel = tolua.cast(chargeNode:getChildByName("Main_Panel"), "ccui.Widget")
		local size = subMainPanel:getContentSize()
		size.width = listViewWidth
		widget:setContentSize(size)
		subMainPanel:setContentSize(size)
		subMainPanel:setSwallowTouches(false)
		ccui.Helper:doLayout(subMainPanel)
        
        local title = tolua.cast(subMainPanel:getChildByName("Title_Label"),"ccui.Text")
        local numberLabel = tolua.cast(subMainPanel:getChildByName("Number_Label"),"ccui.Text")
        if self.selectTag == wd.activityType.Charge then
            title:setString("累计充值")
		    numberLabel:setString(string.format("%d元宝",v.condition))
        elseif self.selectTag == wd.activityType.Everyday then
            title:setVisible(false)
            numberLabel:setVisible(false)
            tolua.cast(subMainPanel:getChildByName("Title_Label_1"),"ccui.Text"):setVisible(true)
            numberLabel = tolua.cast(subMainPanel:getChildByName("Number_Label_1"),"ccui.Text")
		    numberLabel:setString(string.format("%d元宝",v.condition))
            numberLabel:setVisible(true)
            
            local numberLabel2 = tolua.cast(subMainPanel:getChildByName("Number_Label_2"),"ccui.Text")
            numberLabel2:setVisible(true)
            if todayCharge >= v.condition then 
                numberLabel2:setString(string.format("【%d/%d】",v.condition,v.condition))
            else
                numberLabel2:setString(string.format("【%d/%d】",todayCharge,v.condition))
            end
        elseif self.selectTag == wd.activityType.Vip then
            title:setVisible(false)
            numberLabel:setVisible(false)
            local vipLabel = tolua.cast(subMainPanel:getChildByName("Title_Label_vip"),"ccui.Text")
            vipLabel:setString("VIP"..v.condition.."奖励")
            vipLabel:setVisible(true)
        end
        
        
        
		local getButton = tolua.cast(subMainPanel:getChildByName("Get_Button"),"ccui.Button")
		local cannotGetBtn = tolua.cast(subMainPanel:getChildByName("CannotGet_Button"),"ccui.Button")
		local hadGetSprite = tolua.cast(subMainPanel:getChildByName("HadGet_Sprite"),"cc.Sprite")
		getButton:removeFromParent()
		widget:addChild(getButton,1)
		getButton:setPressedActionEnabled(true)
		cannotGetBtn:removeFromParent()
		widget:addChild(cannotGetBtn,1)
		cannotGetBtn:setPressedActionEnabled(true)
		
		v.state = wd.GlobalData:getInstance():getAwardState(v.id)
		if v.state == wd.awardState.Unreach then
			cannotGetBtn:setVisible(true)
			getButton:setVisible(false)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.CanGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(true)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.HadGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(false)
			hadGetSprite:setVisible(true)
		end
		getButton:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					--[[if v.state == wd.awardState.Unreach then
						wd.showSystemTips("还未达成，多努力哦")
					elseif v.state == wd.awardState.CanGet then
						wd.activityHandler:requestGetAward(v.activityId,v.id)
					elseif v.state == wd.awardState.HadGet then
						wd.showSystemTips("该奖励已领取")
					end--]]
					wd.activityHandler:requestGetAward(v.activityId,v.id)
				end
			end
		)
		cannotGetBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
                    local msg = {}
                    if self.selectTag == wd.activityType.Everyday then
                        table.insert(msg,"今日还需充值")
                        table.insert(msg,string.format("{u=[%s],c1=[%d],c2=[%d],c3=[%d],c4=[%d]}",(v.condition - todayCharge).."元宝",0,255,0,255))
                        table.insert(msg,"才能领取该奖励")
                    elseif self.selectTag == wd.activityType.Vip then
                        table.insert(msg,"只能领取当前的")
                        table.insert(msg,string.format("{u=[%s],c1=[%d],c2=[%d],c3=[%d],c4=[%d]}","VIP"..wd.GlobalData:getInstance():getRoleVip(),0,255,0,255))
                        table.insert(msg,"的奖励")
                    elseif self.selectTag == wd.activityType.Charge then
                        table.insert(msg,"累积充值不足，还需充值")
                        table.insert(msg,string.format("{u=[%s],c1=[%d],c2=[%d],c3=[%d],c4=[%d]}",v.condition - wd.GlobalData:getInstance():getTotalCharge(),0,255,0,255))
                        table.insert(msg,"元宝")
                    end
                    wd.showRichTips(wd.tipsType.System,msg)
				end
			end
		)
		
		local itemListView = tolua.cast(subMainPanel:getChildByName("Item_ListView"), "ccui.ListView")
		itemListView:setSwallowTouches(false)
		itemListView:removeFromParent()
		widget:addChild(itemListView,1)
		for index,itemInfo in ipairs(v.awardList) do
			local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
			btn:setAnchorPoint(cc.p(0,0))
			local itemNode = tolua.cast(cc.CSLoader:createNode("ui/gift/ItemNode.csb"),"ccui.Widget")
			btn:addChild(itemNode)
			local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
			local colorStr
			local quantityVisible = true
			local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",itemInfo.itemId))
			if itemInfo.itemType == wd.ItemType.Special then 
				colorStr = string.format("%02d.png",5)
			elseif itemInfo.itemType == wd.ItemType.Tools then 
				local item = wd.GlobalData:getInstance():getToolsItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",item:getQuality())
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass =  require("game.package.ToolsTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(itemInfo.itemId,true)
							self:addChild(layer)
						end
					end
				)
				if item:getQuality() == 5 then
					wd.itemEffect(image)
				end
			elseif itemInfo.itemType == wd.ItemType.Equip then 
				local equip = wd.GlobalData:getInstance():getEquipItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",5)
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass = require("src.game.shop.ArtifactTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(equip)
							self:addChild(layer)
						end
					end
				)
				quantityVisible = false
			end
			color:setSpriteFrame(colorStr)
			
			
			local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
			quantityLabel:setVisible(quantityVisible)
			quantityLabel:setString(string.format("%d", itemInfo.itemCount))
			itemListView:pushBackCustomItem(btn)
		end
		
		widget:setAnchorPoint(cc.p(0,0))
		widget:setTag(i)
		widget:addChild(chargeNode)
		chargeNode:setPosition(cc.p(0,0))
		contentListView:pushBackCustomItem(widget)
	end
	self.contentPanel:addChild(node)
	node:setTag(wd.activityType.Charge)
	node:setPosition(0,0)
	if self.isShowEffect then
		--self:effect()
		self.isShowEffect = false
	end
end

-- Consume
function ActivityLayer:updateConsumeView()
	self.contentPanel:removeAllChildren()
	local node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityConsumeNode.csb"),"ccui.Widget")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget") 
	mainPanel:setContentSize(self.contentPanel:getContentSize())
	ccui.Helper:doLayout(mainPanel)
	
	local chargeButton = tolua.cast(mainPanel:getChildByName("GoCharge_Button"),"ccui.Button")
	chargeButton:setPressedActionEnabled(true)
	chargeButton:addTouchEventListener(
		function(sender,eventType)
			if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.charge.ChargeLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:clear()
			end
		end
	)
	
	local timeLabel = tolua.cast(mainPanel:getChildByName("Time_Label"), "ccui.Text")
	local startTime =  wd.GlobalData:getInstance():getActivityStartTime(102)
	local endTime = wd.GlobalData:getInstance():getActivityEndTime(102)
	local year,month,day
	year = os.date("%Y",startTime)
	month = os.date("%m",startTime)
	day = os.date("%d",startTime)
	local startStr = string.format("%04d.%02d.%02d",year,month,day)
	year = os.date("%Y",endTime)
	month = os.date("%m",endTime)
	day = os.date("%d",endTime)
	local endStr = string.format("%04d.%02d.%02d",year,month,day)
	timeLabel:setString(string.format("活动时间：%s - %s",startStr,endStr))
	
	local contentListView = tolua.cast(mainPanel:getChildByName("Content_ListView"), "ccui.ListView")
	local listViewWidth = contentListView:getContentSize().width
	local awardList = wd.activityHandler:getAwardListByActivityId(102)
	for i,v in ipairs(awardList) do
		local widget = ccui.Widget:create()
		local comsumeNode =  tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityComsumeSubNode.csb"),"ccui.Widget")
		local subMainPanel = tolua.cast(comsumeNode:getChildByName("Main_Panel"), "ccui.Widget")
		local size = subMainPanel:getContentSize()
		size.width = listViewWidth
		widget:setContentSize(size)
		subMainPanel:setContentSize(size)
		subMainPanel:setSwallowTouches(false)
		ccui.Helper:doLayout(subMainPanel)
		local numberLabel = tolua.cast(subMainPanel:getChildByName("Number_Label"),"ccui.Text")
		numberLabel:setString(string.format("累计消费%d元宝",v.condition))
		local consumeLabel =  tolua.cast(subMainPanel:getChildByName("CurrentNum_Label"),"ccui.Text")
		local totalCost = wd.GlobalData:getInstance():getTotalCost()
		consumeLabel:setString(string.format("【%d/%d】",totalCost,v.condition))
		local getButton = tolua.cast(subMainPanel:getChildByName("Get_Button"),"ccui.Button")
		local cannotGetBtn = tolua.cast(subMainPanel:getChildByName("CannotGet_Button"),"ccui.Button")
		local hadGetSprite = tolua.cast(subMainPanel:getChildByName("HadGet_Sprite"),"cc.Sprite")
		getButton:removeFromParent()
		widget:addChild(getButton,1)
		getButton:setPressedActionEnabled(true)
		cannotGetBtn:removeFromParent()
		widget:addChild(cannotGetBtn,1)
		cannotGetBtn:setPressedActionEnabled(true)
		
		v.state = wd.GlobalData:getInstance():getAwardState(v.id)
		if v.state == wd.awardState.Unreach then
			cannotGetBtn:setVisible(true)
			getButton:setVisible(false)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.CanGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(true)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.HadGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(false)
			hadGetSprite:setVisible(true)
		end
		getButton:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					--[[if v.state == wd.awardState.Unreach then
						wd.showSystemTips("还未达成，多努力哦")
					elseif v.state == wd.awardState.CanGet then
						wd.activityHandler:requestGetAward(v.activityId,v.id)
					elseif v.state == wd.awardState.HadGet then
						wd.showSystemTips("该奖励已领取")
					end--]]
					wd.activityHandler:requestGetAward(v.activityId,v.id)
				end
			end
		)
		cannotGetBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					-- if v.state == wd.awardState.Unreach then
					-- 	wd.showSystemTips("还未达成，多努力哦")
					-- elseif v.state == wd.awardState.CanGet then
					-- 	wd.activityHandler:requestGetAward(v.activityId,v.id)
					-- elseif v.state == wd.awardState.HadGet then
					-- 	wd.showSystemTips("该奖励已领取")
					-- end
					-- wd.activityHandler:requestGetAward(v.activityId,v.id)
                    local msg = {}
                    table.insert(msg,"累计消费不足，还需消费")
                    table.insert(msg,string.format("{u=[%s],c1=[%d],c2=[%d],c3=[%d],c4=[%d]}",v.condition - totalCost,0,255,0,255))
                    table.insert(msg,"元宝")
                    wd.showRichTips(wd.tipsType.System,msg)
				end
			end
		)
		
		local itemListView = tolua.cast(subMainPanel:getChildByName("Item_ListView"), "ccui.ListView")
		itemListView:setSwallowTouches(false)
		itemListView:removeFromParent()
		widget:addChild(itemListView,1)
		for index,itemInfo in ipairs(v.awardList) do
			local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
			btn:setAnchorPoint(cc.p(0,0))
			local itemNode = tolua.cast(cc.CSLoader:createNode("ui/gift/ItemNode.csb"),"ccui.Widget")
			btn:addChild(itemNode)
			local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
			local colorStr
			local quantityVisible = true
			local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",itemInfo.itemId))
			if itemInfo.itemType == wd.ItemType.Special then 
				colorStr = string.format("%02d.png",5)
			elseif itemInfo.itemType == wd.ItemType.Tools then 
				local item = wd.GlobalData:getInstance():getToolsItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",item:getQuality())
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass =  require("game.package.ToolsTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(itemInfo.itemId,true)
							self:addChild(layer)
						end
					end
				)
				if item:getQuality() == 5 then
					wd.itemEffect(image)
				end
			elseif itemInfo.itemType == wd.ItemType.Equip then 
				local equip = wd.GlobalData:getInstance():getEquipItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",5)
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass = require("src.game.shop.ArtifactTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(equip)
							self:addChild(layer)
						end
					end
				)
				quantityVisible = false
			end
			color:setSpriteFrame(colorStr)
			
			local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
			quantityLabel:setVisible(quantityVisible)
			quantityLabel:setString(string.format("%d", itemInfo.itemCount))
			itemListView:pushBackCustomItem(btn)
		end
		widget:setAnchorPoint(cc.p(0,0))
		widget:setTag(i)
		widget:addChild(comsumeNode)
		comsumeNode:setPosition(cc.p(0,0))
		contentListView:pushBackCustomItem(widget)
	end
	self.contentPanel:addChild(node)
	node:setTag(wd.activityType.Consume)
	node:setPosition(0,0)
	if self.isShowEffect then
		--self:effect()
		self.isShowEffect = false
	end
end


function ActivityLayer:updateLoginView()
	self.contentPanel:removeAllChildren()
	local node = tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityLoginNode.csb"),"ccui.Widget")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget") 
	mainPanel:setContentSize(self.contentPanel:getContentSize())
	ccui.Helper:doLayout(mainPanel)
	
	local contentListView = tolua.cast(mainPanel:getChildByName("Content_ListView"), "ccui.ListView")
	local listViewWidth = contentListView:getContentSize().width
	local awardList = wd.activityHandler:getAwardListByActivityId(103)
	for i,v in ipairs(awardList) do
		local widget = ccui.Widget:create()
		local loginNode =  tolua.cast(cc.CSLoader:createNode("ui/activity/ActivityLoginSubNode.csb"),"ccui.Widget")
		local subMainPanel = tolua.cast(loginNode:getChildByName("Main_Panel"), "ccui.Widget")
		local size = subMainPanel:getContentSize()
		size.width = listViewWidth
		widget:setContentSize(size)
		subMainPanel:setContentSize(size)
		subMainPanel:setSwallowTouches(false)
		ccui.Helper:doLayout(subMainPanel)
		local numberLabel = tolua.cast(subMainPanel:getChildByName("Title_Label"),"ccui.Text")
		numberLabel:setString(string.format("第%d天登录",v.condition))
		local getButton = tolua.cast(subMainPanel:getChildByName("Get_Button"),"ccui.Button")
		local cannotGetBtn = tolua.cast(subMainPanel:getChildByName("CannotGet_Button"),"ccui.Button")
		local hadGetSprite = tolua.cast(subMainPanel:getChildByName("HadGet_Sprite"),"cc.Sprite")
		getButton:removeFromParent()
		widget:addChild(getButton,1)
		getButton:setPressedActionEnabled(true)
		cannotGetBtn:removeFromParent()
		widget:addChild(cannotGetBtn,1)
		cannotGetBtn:setPressedActionEnabled(true)
		
		v.state = wd.GlobalData:getInstance():getAwardState(v.id)
		if v.state == wd.awardState.Unreach then
			cannotGetBtn:setVisible(true)
			getButton:setVisible(false)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.CanGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(true)
			hadGetSprite:setVisible(false)
		elseif v.state == wd.awardState.HadGet then
			cannotGetBtn:setVisible(false)
			getButton:setVisible(false)
			hadGetSprite:setVisible(true)
		end
		getButton:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					--[[if v.state == wd.awardState.Unreach then
						wd.showSystemTips("还未达成，多努力哦")
					elseif v.state == wd.awardState.CanGet then
						wd.activityHandler:requestGetAward(v.activityId,v.id)
					elseif v.state == wd.awardState.HadGet then
						wd.showSystemTips("该奖励已领取")
					end--]]
					wd.activityHandler:requestGetAward(v.activityId,v.id)
				end
			end
		)
		cannotGetBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					--[[if v.state == wd.awardState.Unreach then
						wd.showSystemTips("还未达成，多努力哦")
					elseif v.state == wd.awardState.CanGet then
						wd.activityHandler:requestGetAward(v.activityId,v.id)
					elseif v.state == wd.awardState.HadGet then
						wd.showSystemTips("该奖励已领取")
					end--]]
					wd.activityHandler:requestGetAward(v.activityId,v.id)
				end
			end
		)
		
		local itemListView = tolua.cast(subMainPanel:getChildByName("Item_ListView"), "ccui.ListView")
		itemListView:setSwallowTouches(false)
		itemListView:removeFromParent()
		widget:addChild(itemListView,1)
		for index,itemInfo in ipairs(v.awardList) do
			local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
			btn:setAnchorPoint(cc.p(0,0))
			local itemNode = tolua.cast(cc.CSLoader:createNode("ui/gift/ItemNode.csb"),"ccui.Widget")
			btn:addChild(itemNode)
			local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
			local colorStr
			local quantityVisible = true
			local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",itemInfo.itemId))
			if itemInfo.itemType == wd.ItemType.Special then 
				colorStr = string.format("%02d.png",5)
			elseif itemInfo.itemType == wd.ItemType.Tools then 
				local item = wd.GlobalData:getInstance():getToolsItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",item:getQuality())
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass =  require("game.package.ToolsTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(itemInfo.itemId,true)
							self:addChild(layer)
						end
					end
				)
				if item:getQuality() == 5 then
					wd.itemEffect(image)
				end
			elseif itemInfo.itemType == wd.ItemType.Equip then 
				local equip = wd.GlobalData:getInstance():getEquipItemInXml(tonumber(itemInfo.itemId))
				colorStr = string.format("%02d.png",5)
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass = require("src.game.shop.ArtifactTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(equip)
							self:addChild(layer)
						end
					end
				)
				quantityVisible = false
			elseif itemInfo.itemType == wd.ItemType.Soul then 
				local soul = wd.soulHandler:getSoulInXmlForId(itemInfo.itemId)
				colorStr = string.format("%02d.png",soul.grade)
				btn:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass = require("src.game.soul.SoulTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(soul,0)
							self:addChild(layer)
						end
					end
				)
			end
			color:setSpriteFrame(colorStr)
			local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
			quantityLabel:setVisible(quantityVisible)
			quantityLabel:setString(string.format("%d", itemInfo.itemCount))
			itemListView:pushBackCustomItem(btn)
		end
		widget:setAnchorPoint(cc.p(0,0))
		widget:setTag(i)
		widget:addChild(loginNode)
		loginNode:setPosition(cc.p(0,0))
		contentListView:pushBackCustomItem(widget)
	end
	self.contentPanel:addChild(node)
	node:setTag(wd.activityType.Login)
	node:setPosition(0,0)
	--[[if self.isShowEffect then
		self:effect()
		self.isShowEffect = false
	end--]]
end

function ActivityLayer:effect()
    self.getAwardEffect:setVisible(true)
    
    local function delayCallBackFunc(sender)
        self.getAwardEffect:setVisible(false)
    end

    local delayCallBack = cc.CallFunc:create(delayCallBackFunc)

    local animation = cc.Animation:create()
    for i = 1, 8 do
        animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("getAward_%02d.png", i)))
    end

    animation:setDelayPerUnit(0.1)
    animation:setLoops(1)
    local action = cc.Animate:create(animation)
    local sequenceAction = cc.Sequence:create(action, delayCallBack)

    self.getAwardEffect:runAction(sequenceAction)
   
end

return ActivityLayer
