
local SevenDayLayer = class("SevenDayLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function SevenDayLayer.create()
    local layer = SevenDayLayer.new()
    layer:createLayerMenu()
    return layer
end

function SevenDayLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.tickSchedule = nil
	self.awardState = {
		CanGet = 0,
		HadGet = 1,
		NoPlace = 2,
	}
end


function SevenDayLayer:clear()
	if self.tickSchedule ~= nil then
		cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickSchedule)
		self.tickSchedule = nil
	end
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_SevenDayList")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Start_Award")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
end

function SevenDayLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/activity/SevenDayLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
	
	
	local contentListView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Content_ListView"), "ccui.ListView")
	local listViewWidth = contentListView:getContentSize().width

	local timeLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Time_Label"), "ccui.Text")
	local desTime = (os.time()-wd.GlobalData:getInstance():getLoginTimeDifference()) - wd.GlobalData:getInstance():getServerOpenTime()
	if desTime < 0 then
		desTime = 0
	else
		desTime = 6*24*3600 - desTime
		if desTime < 0 then
			desTime = 0
		end
	end
	if self.tickSchedule ~= nil then
		cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickSchedule)
		self.tickSchedule = nil
	end
	if desTime ~= 0 then
		local d,h,m,s
		local function setTime()
			if desTime ~= 0 then
				d = os.date("%d",desTime)
				h = os.date("%H",desTime)
				m = os.date("%M",desTime)
				s = os.date("%S",desTime)
				if tonumber(d) > 0 then
					timeLabel:setString(string.format("倒计时：%d天",d))
				else
					timeLabel:setString(string.format("倒计时：%02d:%02d:%02d",h,m,s))
				end
			else
				if self.tickSchedule ~= nil then
					cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickSchedule)
					self.tickSchedule = nil
				end
				timeLabel:setString("活动时间结束")
			end
		end
		setTime()
		local function timeTick()
			setTime()
			desTime = desTime - 1
			if desTime < 0  then
				desTime = 0
			end
		end
		self.tickSchedule = cc.Director:getInstance():getScheduler():scheduleScriptFunc(timeTick, 1, false)
	else
		timeLabel:setString("活动时间结束")
	end
	
	local function onUpdateSevenDayList()
		contentListView:removeAllItems()
		local sevenDayList = wd.activityHandler:getSevenDayList()
			
		for index,awardItem in ipairs(sevenDayList) do
			local widget = ccui.Widget:create()
			local awardItemNode =  tolua.cast(cc.CSLoader:createNode("ui/activity/SevenDayNode.csb"),"ccui.Widget")
			local mainPanel = tolua.cast(awardItemNode:getChildByName("Main_Panel"), "ccui.Widget")
			local size = mainPanel:getContentSize()
			size.width = listViewWidth
			widget:setContentSize(size)
			mainPanel:setContentSize(size)
			mainPanel:setSwallowTouches(false)
			
			local conditionLabel = tolua.cast(mainPanel:getChildByName("Condition_Label"), "ccui.Text")
			conditionLabel:setString(awardItem.condition)
			local placeLabel = tolua.cast(mainPanel:getChildByName("Left_Label"), "ccui.Text")
			local leftNum = awardItem.place - awardItem.curPlace
			if leftNum < 0 then
				leftNum = 0
			end
			placeLabel:setString(string.format("剩余:%d",leftNum))
			
			local getBtn = tolua.cast(mainPanel:getChildByName("Get_Button"),"ccui.Button")
			getBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if awardItem.type == 1 then
							wd.activityHandler:requestStartActivityAward(awardItem.id,0)
						else
							local layerClass = require("src.game.activity.SelectAwardLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(awardItem.id,awardItem.awardList)
							self:addChild(layer)
						end
					end
				end
			)
			
			local hadGetSprite = tolua.cast(mainPanel:getChildByName("HadGet_Sprite"), "cc.Sprite")
			local fullSprite = tolua.cast(mainPanel:getChildByName("Full_Sprite"), "cc.Sprite")
			
			
			if awardItem.state == self.awardState.CanGet then
				getBtn:setVisible(true)
				hadGetSprite:setVisible(false)
				fullSprite:setVisible(false)
			elseif awardItem.state == self.awardState.HadGet then
				getBtn:setVisible(false)
				hadGetSprite:setVisible(true)
				fullSprite:setVisible(false)
			elseif awardItem.state == self.awardState.NoPlace then
				getBtn:setVisible(false)
				hadGetSprite:setVisible(false)
				fullSprite:setVisible(true)
			end
			
			local itemListView = tolua.cast(mainPanel:getChildByName("Item_ListView"), "ccui.ListView")
			itemListView:setSwallowTouches(false)
			itemListView:removeFromParent()
			widget:addChild(itemListView,1)
			for index,itemInfo in ipairs(awardItem.awardList) do
				local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
				btn:setAnchorPoint(cc.p(0,0))
				local itemNode = tolua.cast(cc.CSLoader:createNode("ui/gift/ItemNode.csb"),"ccui.Widget")
				btn:addChild(itemNode)
				local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
				local colorStr
				local quantityVisible = true
				local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
				image:setSpriteFrame(string.format("%d.png",itemInfo.itemId))
				if itemInfo.itemType == wd.ItemType.Special then 
					colorStr = string.format("%02d.png",5)
				elseif itemInfo.itemType == wd.ItemType.Tools then 
					local item = wd.GlobalData:getInstance():getToolsItemInXml(tonumber(itemInfo.itemId))
					colorStr = string.format("%02d.png",item:getQuality())
					btn:addTouchEventListener(
						function(sender,eventType)
							if eventType == ccui.TouchEventType.ended then
								local layerClass =  require("game.package.ToolsTipsLayer")
								local layer = layerClass.create()
								layer:createLayerMenu(itemInfo.itemId,true)
								self:addChild(layer)
							end
						end
					)
					if item:getQuality() == 5 then
						wd.itemEffect(image)
					end
				elseif itemInfo.itemType == wd.ItemType.Equip then 
					local equip = wd.GlobalData:getInstance():getEquipItemInXml(tonumber(itemInfo.itemId))
					colorStr = string.format("%02d.png",5)
					btn:addTouchEventListener(
						function(sender,eventType)
							if eventType == ccui.TouchEventType.ended then
								local layerClass = require("src.game.shop.ArtifactTipsLayer")
								local layer = layerClass.create()
								layer:createLayerMenu(equip)
								self:addChild(layer)
							end
						end
					)
					wd.equipEffect(equip, image)
					quantityVisible = false
				end
				color:setSpriteFrame(colorStr)
				
				local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
				quantityLabel:setVisible(quantityVisible)
				quantityLabel:setString(string.format("%d", itemInfo.itemCount))
				itemListView:pushBackCustomItem(btn)
			end
			
			widget:setAnchorPoint(cc.p(0,0))
			widget:setTag(index)
			widget:addChild(awardItemNode)
			awardItemNode:setPosition(cc.p(0,0))
			awardItemNode:setTag(index)
			contentListView:pushBackCustomItem(widget)
		end
	end
	local listener = cc.EventListenerCustom:create("Update_SevenDayList", onUpdateSevenDayList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onGetStartAward()
		--wd.showSystemTips("领取成功")
		wd.activityHandler:requestStartActivityState()
	end
	local listener = cc.EventListenerCustom:create("Get_Start_Award", onGetStartAward)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

return SevenDayLayer

