local PlayerLayer = class("PlayerLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PlayerLayer.create()
    local layer = PlayerLayer.new()
    return layer
end

function PlayerLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.wearTable = {}
end


function PlayerLayer:createWearNode(wearType, isSelf)
    local equipNode = tolua.cast(cc.CSLoader:createNode("ui/role/WearNode.csb"),"ccui.Widget")
    local item = nil
    if isSelf == wd.PlayerType.ENEMY then
        item = wd.GlobalData:getInstance():getOtherWearEquip(wearType)
    else
        item = wd.GlobalData:getInstance():getWearEquip(wearType)
    end
    
    if item == nil then
        equipNode:setVisible(false)
    else
        equipNode:setVisible(true)

        local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
        image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
        
        wd.equipEffect(item, image)

        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
        color:setSpriteFrame(string.format("%02d.png",item:getColor()))

        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
        levelLabel:setString(string.format("Lv%d",item:getLevel()))
        
        local strengthenLabel = tolua.cast(equipNode:getChildByName("Strengthen_Label"), "ccui.Text")
        if item:getStrengthenLevel() > 0 then
            strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
        else
            strengthenLabel:setString("")
        end

    end

    self.wearTable[wearType] = equipNode
    return equipNode
end


function PlayerLayer:createLayerMenu(isSelf,isFromSoul)

    local node = tolua.cast(cc.CSLoader:createNode("ui/role/RoleScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local function backCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Player_Data")
            self:removeFromParent()
        end
    end

    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(backCallback)

	
	
    local equipPanel = ccui.Helper:seekWidgetByName(node,"Panel_Equip")
    local jobTitle = tolua.cast(equipPanel:getChildByName("Job_Title"), "cc.Sprite")
    local roleSprite = tolua.cast(equipPanel:getChildByName("Role_Sprite"), "cc.Sprite")

    local nameLabel = tolua.cast(equipPanel:getChildByName("Name_Label"), "ccui.Text")
    local powerLabel = tolua.cast(equipPanel:getChildByName("Power_Label"), "ccui.TextAtlas")
    local levelLabel = tolua.cast(equipPanel:getChildByName("Level_Label"), "ccui.Text")
	
	local soulBtn = ccui.Helper:seekWidgetByName(equipPanel,"Soul_Button")
    soulBtn:setPressedActionEnabled(true)
    soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Player_Data")
                local layerClass = require("src.game.arena.PlayerSoulLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(isSelf)
                self:getParent():addChild(layer)
				self:removeFromParent()
            end
        end
    )
	
    local attrScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Attr_ScrollView"), "ccui.ScrollView")

    local attackTitle = tolua.cast(attrScroll:getChildByName("Attack_Title"), "cc.Sprite")
    local hpLabel = tolua.cast(attrScroll:getChildByName("Hp_Label"), "ccui.Text")
    local mpLabel = tolua.cast(attrScroll:getChildByName("Mp_Label"), "ccui.Text")
    local atkLabel = tolua.cast(attrScroll:getChildByName("Attack_Label"), "ccui.Text")
    local pdefLabel = tolua.cast(attrScroll:getChildByName("PDefence_Label"), "ccui.Text")
    local mdefLabel = tolua.cast(attrScroll:getChildByName("MDefence_Label"), "ccui.Text")
    local tdefLabel = tolua.cast(attrScroll:getChildByName("TDefence_Label"), "ccui.Text")
    local luckLabel = tolua.cast(attrScroll:getChildByName("Luck_Label"), "ccui.Text")
    local accuracyLabel = tolua.cast(attrScroll:getChildByName("Accuracy_Label"), "ccui.Text")
    local dodgeLabel = tolua.cast(attrScroll:getChildByName("Dodge_Label"), "ccui.Text")
    local vertigoLabel = tolua.cast(attrScroll:getChildByName("Vertigo_Label"), "ccui.Text")
    local reincarnateLabel = tolua.cast(attrScroll:getChildByName("Reincarnate_Label"), "ccui.Text")
    local manapreventLabel = tolua.cast(attrScroll:getChildByName("Manaprevent_Label"), "ccui.Text")
    local drainlifeLabel = tolua.cast(attrScroll:getChildByName("Drainlife_Label"), "ccui.Text")
    local critLabel = tolua.cast(attrScroll:getChildByName("Crit_Label"), "ccui.Text")
	local critDamLabel = tolua.cast(attrScroll:getChildByName("CritDam_Label"), "ccui.Text")
    local honorLabel = tolua.cast(attrScroll:getChildByName("Honor_Label"), "ccui.Text")
    local killLabel = tolua.cast(attrScroll:getChildByName("Kill_Label"), "ccui.Text")
    local familyName = ccui.Helper:seekWidgetByName(node,"family_name");
	local vipLevel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Vip_Level_Label"), "ccui.Text")
	
    local function updataAttr()
        local role
        if isSelf == wd.PlayerType.ENEMY then
            role = wd.GlobalData:getInstance():getPlayerData()
        else
            role = wd.GlobalData:getInstance():getRoleData()
        end
        
        jobTitle:setSpriteFrame(wd.getJobTitleName(role:getOccupation()))
        jobTitle:setVisible(true)

        roleSprite:setSpriteFrame(wd.getPlayerImageName(role:getOccupation(), role:getSex()))
        roleSprite:setVisible(true)
        if role:getSex() == 0 then
            roleSprite:setFlippedX(true)
        else
            roleSprite:setFlippedX(false)
        end
        
        nameLabel:setString(role:getName())
        powerLabel:setString(string.format("%d",role:getPower()))
        levelLabel:setString(string.format("%d级",role:getLevel()))

        hpLabel:setString(string.format("%d/%d",role:getHp(),role:getHp()))
        mpLabel:setString(string.format("%d/%d",role:getMp(),role:getMp()))

        if role:getOccupation() == 1 then
            attackTitle:setSpriteFrame("role_pattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getPAttack_min(), role:getPAttack_max()))
        elseif role:getOccupation() == 2 then
            attackTitle:setSpriteFrame("role_mattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getMAttack_min(), role:getMAttack_max()))
        elseif role:getOccupation() == 3 then
            attackTitle:setSpriteFrame("role_tattack_title.png")
            atkLabel:setString(string.format("%d-%d", role:getTAttack_min(), role:getTAttack_max()))
        end

        pdefLabel:setString(string.format("%d-%d", role:getPDefence_min(), role:getPDefence_max()))
        mdefLabel:setString(string.format("%d-%d", role:getMDefence_min(), role:getMDefence_max()))
        tdefLabel:setString(string.format("%d-%d", role:getTDefence_min(), role:getTDefence_max()))
        luckLabel:setString(string.format("%d",role:getLuck()))
        accuracyLabel:setString(string.format("%d",role:getAccuracy()))
        dodgeLabel:setString(string.format("%d",role:getDodge()))
        vertigoLabel:setString(string.format("%0.1f%%",role:getVertigo()/100.0))
        reincarnateLabel:setString(string.format("%0.1f%%",role:getReincarnate()/100.0))
        manapreventLabel:setString(string.format("%0.1f%%",role:getManaprevent()/100.0))
        drainlifeLabel:setString(string.format("%0.1f%%",role:getDrainlife()/100.0))
        critLabel:setString(string.format("%0.1f%%",role:getCrit()/100.0))
		critDamLabel:setString(string.format("%0.01f%%",role:getCritDam()/100))
        honorLabel:setString(string.format("%d",role:getHonor()))
        killLabel:setString(string.format("%d",role:getKill()))
        familyName:setString(role:getRoleExtendData("family_name"));
        vipLevel:setString(role:getVip())
    end

    --updataAttr()
    
    local function showEquipTips(regionType)
        local item = wd.GlobalData:getInstance():getOtherWearEquip(regionType)
        if item ~= nil then
            local layerClass = require("src.game.package.EquipTipsLayer")
            local layer = layerClass.create()
            if isSelf == wd.PlayerType.ENEMY then
                layer:createLayerMenu(0, regionType, 3, -1)
            else
                layer:createLayerMenu(0, regionType, 2, -1)
            end
            self:addChild(layer)
        end
    end
    
    local helmetBtn = ccui.Helper:seekWidgetByName(equipPanel,"Helmet_Button")
    helmetBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.HELMET)
            end
        end
    )

    local necklaceBtn = ccui.Helper:seekWidgetByName(equipPanel,"Necklace_Button")
    necklaceBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.NECKLACE)
            end
        end
    )


    local breastplateBtn = ccui.Helper:seekWidgetByName(equipPanel,"Breastplate_Button")
    breastplateBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.BREASTPLATE)
            end
        end
    )



    local shoeBtn = ccui.Helper:seekWidgetByName(equipPanel,"Shoe_Button")
    shoeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.SHOE)
            end
        end
    )


    local weaponBtn = ccui.Helper:seekWidgetByName(equipPanel,"Weapon_Button")
    weaponBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.WEAPON)
            end
        end
    )


    local lWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"LWrist_Button")
    lWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.LWRIST)
            end
        end
    )


    local rWristBtn = ccui.Helper:seekWidgetByName(equipPanel,"RWrist_Button")
    rWristBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.RWRIST)
            end
        end
    )


    local lRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"LRing_Button")
    lRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.LRING)
            end
        end
    )

    local rRingBtn = ccui.Helper:seekWidgetByName(equipPanel,"RRing_Button")
    rRingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                showEquipTips(wd.WearRegion.RRING)
            end
        end
    )

    local function updataData() 
        updataAttr()
        
        local equipNode = self:createWearNode(wd.WearRegion.HELMET, isSelf)
        helmetBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.NECKLACE, isSelf)
        necklaceBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.BREASTPLATE, isSelf)
        breastplateBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.SHOE, isSelf)
        shoeBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.WEAPON, isSelf)
        weaponBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.LWRIST, isSelf)
        lWristBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.RWRIST, isSelf)
        rWristBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.LRING, isSelf)
        lRingBtn:addChild(equipNode)
        
        local equipNode = self:createWearNode(wd.WearRegion.RRING, isSelf)
        rRingBtn:addChild(equipNode)
    end
    
    if isFromSoul then
		updataData()
	else
		if isSelf == wd.PlayerType.ENEMY then
			local listener = cc.EventListenerCustom:create("Player_Data", updataData)
			cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
		else
			updataData()
		end
	end
end



return PlayerLayer