
local ChatDataHandler = class("ChatDataHandler")

local cclog = function(...)
    print(string.format(...))
end

local serialize_compact2 = function(o)
	local obj_type = type(o)
	if obj_type == "number" then
		return (tostring(o))
	elseif obj_type == "string" then
		return (string_format("%q", o))
	elseif obj_type == "boolean" then	
		if(o) then
			return "true"
		else
			return "false"
		end
	elseif obj_type == "table" then
		local str = "{"
		local k,v;
		local nIndex = 1;
		for k,v in pairs(o) do
			if(type(k) == "string") then
				str = str..k.."="..(serialize_compact2(v) or "nil")..",";
			elseif(nIndex == k) then
				str = str..(serialize_compact2(v) or "nil")..",";
				nIndex = nIndex + 1;
			else
				str = str.."["..tostring(k).."]="..(serialize_compact2(v) or "nil")..",";
			end
		end
		str = str.."}";
		return str
	elseif obj_type == "nil" then
		return ("nil")
	end
end

local saveTableToFile = function(s_table,filename)
    local buf = "local a="..serialize_compact2(s_table).."; return a;";
    
    
    local path = cc.FileUtils:getInstance():getWritablePath()..filename
    --local arrTemp =string.split(filename, "/")
    --if #arrTemp > 1 then
    --    local p_path = string.sub(path, 1, -string.len(arrTemp[#arrTemp])-1)
    --    local oldpath = lfs.currentdir()
    --    if lfs.chdir(p_path) then
    --        lfs.chdir(oldpath)
    --    else
    --        lfs.mkdir(p_path)
    --    end
    --end

    local file = io.open(path, "w+b")
    if file then
        if file:write(buf) == nil then return false end
        io.close(file)
    end
end

local readTableFromFile = function(filename)
    local path = cc.FileUtils:getInstance():getWritablePath()..filename
    local file = io.open(path, "r")
    if file then
        io.close();
        return dofile(path)
    else
        return {};
    end
    return false
end




function ChatDataHandler:ctor()
	self:initData()
	self:registerEventListener()
end

function ChatDataHandler:getInstance()
	if not self.instance then
		self.instance = ChatDataHandler.new()
	end
	return self.instance
end

function ChatDataHandler:destroyInstance()
    if self.instance then
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Chat_Msg")
        self.instance = nil
    end
end

function ChatDataHandler:initData()
	self.fontSize = 22
	self.chatWholeList = {}
	self.chatSystemList = {}
	self.chatType = {
		PUBLIC_NOTICE = 1,
		WORLD_NOTICE = 2,
		SYSTEM_NOTICE = 3,
	}
	self.chatTypeName = {
		[1] = "【公告】 ",
		[2] = "【世界】 ",
		[3] = "【系统】 ",
	}
	self.chatTypeColor = {
		[1] = cc.c4b(0x83,0,0,0xff),
		[2] = cc.c4b(0xff,0x87,0x3e,0xff),
		[3] = cc.c4b(0x83,0,0,0xff),
	}
	self.nameColor = {
		myself = cc.c4b(0x54, 0x2d, 0xbe,0xff),
		other = cc.c4b(0,0x68,0xc0,0xff),
		vip = cc.c4b(0xff,0xe1,0x3d,0xff),
	}
	self.itemColor = cc.c4b(0x83,0,0,0xff)
	self.outLineColor = cc.c4b(0,0,0,0xff)
	self.commonColor = cc.c4b(0xff,0xff,0xff,0xff)
	self.systemCommonColor = cc.c4b(0xff,0xff,0xff,0xff)
	self.systemNameColor = cc.c4b(0x57,0xbe,0x86,0xff)
	self.systemValueColor = cc.c4b(0xf5,0x02,0x02,0xff)
	self.systemSpecialColor = cc.c4b(0xff,0xe1,0x3d,0xff)
end

function ChatDataHandler:startTickSchedule()
	local function getMsgFunc()
		self:requestGetChatMsg()
	end
	self.tickSchedule = cc.Director:getInstance():getScheduler():scheduleScriptFunc(getMsgFunc, 5, false)
end

function ChatDataHandler:stopTickSchedule()
	if self.tickSchedule ~= nil then
		cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickSchedule)
		self.tickSchedule = nil
	end
end

function ChatDataHandler:requestSendChatMsg(msg)
	wd.TranscodingSend:sendChatMsg(msg)
end

function ChatDataHandler:requestGetChatMsg()
	wd.TranscodingSend:getChatWorldMsg()
end

function ChatDataHandler:getChatWorldElementList()
	return self.chatWholeList
end

function ChatDataHandler:getChatSystemElementList()
	return self.chatSystemList
end

function ChatDataHandler:getLastMsgWord()
	local lastChatItem = wd.GlobalData:getInstance():getLastChatItem()
	if lastChatItem and lastChatItem:getMsgType() ~= 0 then
		return lastChatItem:getName(),lastChatItem:getMsg()
	else
		return nil
	end
end

function ChatDataHandler:clearChatMsgList()
	for index,elementTabel in ipairs(self.chatWholeList) do
		for i,v in ipairs(elementTabel) do
			if v then
				v:release()
			end
		end
	end
	for index,elementTabel in ipairs(self.chatSystemList) do
		for i,v in ipairs(elementTabel) do
			if v then
				v:release()
			end
		end
	end
	self.chatWholeList = {}
	self.chatSystemList = {}
end

function ChatDataHandler:registerEventListener()
	--从服务器接收技能列表回调

	local function getMsgCallBack(EventCustom)
		self:clearChatMsgList()
		
        local chatWholeListSize = wd.GlobalData:getInstance():getChatWholeListSize()
        local chatSystemListSize = wd.GlobalData:getInstance():getChatSystemListSize()

        local need_read = 50 - chatWholeListSize;
        local save_msg_list = {};
        local index = 0;
        if (need_read > 0) then
            local msg_list = readTableFromFile("msg");
            local start_index = 50 - #msg_list - need_read;
            if start_index < 0 then
                start_index = 0;
            end
            for k,v in ipairs(msg_list) do
                
                if( v.id > start_index ) then
                    local msgType = v.getMsgType()
				    local senderName = v.getName()
				    local senderRoleId = v.getSenderRoleId()
				    local senderVipLv = v.getSenderVipLevel()
				    local message = v.getMsg()
                    self:addChatWorldMsg(msgType,senderRoleId,senderName,senderVipLv,message)

                    v.id = index;
                    index = index + 1; 

                    table.insert(save_msg_list,v);
                end
			end
        end


		for i = 0,chatWholeListSize-1 do
			local chatItem = wd.GlobalData:getInstance():getChatWholeListItem(i)
			if chatItem then
				local msgType = chatItem:getMsgType()
				local senderName = chatItem:getName()
				local senderRoleId = chatItem:getSenderRoleId()
				local senderVipLv = chatItem:getSenderVipLevel()
				local message = chatItem:getMsg()

                local data = {};
                data.msgType = msgType;
                data.senderName = senderName;
                data.senderRoleId = senderRoleId;
                data.senderVipLv = senderVipLv;
                data.message = message;
                data.id = index;
                index = index + 1; 		
                table.insert(save_msg_list,data);

				self:addChatWorldMsg(msgType,senderRoleId,senderName,senderVipLv,message)
			end
		end

        -- 保存文件
        -- saveTableToFile(save_msg_list,"msg");
        
		
		for i = 0,chatSystemListSize-1 do
			local chatItem = wd.GlobalData:getInstance():getChatSystemListItem(i)
			if chatItem then
				local msgType = chatItem:getMsgType()
				local message = chatItem:getMsg()
				local senderRoleId = chatItem:getSenderRoleId()
				self:addChatSystemMsg(msgType,message,senderRoleId)
			end
		end



		local event = cc.EventCustom:new("Update_Chat_Whole")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local listenerGetMsg = cc.EventListenerCustom:create("Get_Chat_Msg", getMsgCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerGetMsg, 1)
	
	
end


function ChatDataHandler:addChatWorldMsg(msgType,roleId,name,vipLevel,msg)
	local elementTabel = {}
	if self.chatTypeName[msgType] then
		local titleElement = wdui.RichItemText:create(msgType, self.chatTypeColor[msgType], 255, self.chatTypeName[msgType], "Helvetica", self.fontSize)    
		titleElement:enableOutLine(self.outLineColor, 2)
		titleElement:retain()
		table.insert(elementTabel,titleElement)
	end
	if msgType == self.chatType.WORLD_NOTICE then 
		local nameElement,vipStr,nameStr
		if vipLevel > 0 then
			vipStr = string.format("(vip%d)：",vipLevel)
		end
		if roleId == wd.GlobalData:getInstance():getRoleId() then
			if vipStr then
				nameStr = string.format("我对大家说 ")
			else
				nameStr = string.format("我对大家说: ")
			end
			nameElement = wdui.RichItemText:create(roleId, self.nameColor.myself, 255, nameStr, "Helvetica", self.fontSize)
			--nameElement:enableLinkLine(self.nameColor.other, 2) -- todo
			
		else
			if vipStr then
				nameStr = string.format("%s ",name)
			else
				nameStr = string.format("%s: ",name)
			end
			nameElement = wdui.RichItemText:create(roleId, self.nameColor.other, 255,nameStr , "Helvetica", self.fontSize)  
			nameElement:enableLinkLine(self.nameColor.other, 2)
		end
		nameElement:enableOutLine(self.outLineColor, 2)  
		nameElement:retain()
		table.insert(elementTabel,nameElement)
		
		if vipStr then
			local vipElement = wdui.RichItemText:create(vipLevel, self.nameColor.vip, 255,vipStr , "Helvetica", self.fontSize)  
			vipElement:retain()
			table.insert(elementTabel,vipElement)
		end
		local msgElement = wdui.RichItemText:create(msgType, self.commonColor, 255,msg , "Helvetica", self.fontSize)  
		msgElement:retain()
		table.insert(elementTabel,msgElement)
	elseif msgType == self.chatType.SYSTEM_NOTICE then
		elementTabel = self:handleSystemMsg(elementTabel,msg,roleId)
	end
	if elementTabel ~= {} then
		table.insert(self.chatWholeList,elementTabel)
	end
end

function ChatDataHandler:addChatSystemMsg(msgType,message,senderRoleId)
	local elementTabel = {}
	if self.chatTypeName[msgType] then
		local titleElement = wdui.RichItemText:create(msgType, self.chatTypeColor[msgType], 255, self.chatTypeName[msgType], "Helvetica", self.fontSize)    
		titleElement:enableOutLine(self.outLineColor, 2)
		titleElement:retain()
		table.insert(elementTabel,titleElement)
	end
	elementTabel = self:handleSystemMsg(elementTabel,message,senderRoleId)
	if elementTabel ~= {} then
		table.insert(self.chatSystemList,elementTabel)
	end
end

function ChatDataHandler:handleSystemMsg(elementTabel,msg,roleId)
	local parseStr,startIndex,endIndex,str
	parseStr = msg
	local msgArgList = {}
	while(parseStr~="")
	do
		startIndex,endIndex = string.find(parseStr,"|")
		if startIndex and endIndex then
			str = string.sub(parseStr,1,startIndex-1)
			table.insert(msgArgList,str)
			parseStr = string.sub(parseStr,startIndex+1,-1)
		else
			str = string.sub(parseStr,1,-1)
			table.insert(msgArgList,str)
			parseStr = ""
		end
	end
	local element 
	if msgArgList[1] == "1" then
		str = "天降鸿运，"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "在签到抽奖中获得绝世装备："
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getEquipNameById(tonumber(msgArgList[3]))
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "2" then
		str = "恭喜"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "领取"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "首充礼包"
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "，实力直线上升，世间无敌"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "3" then
		str = "祝贺"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "将至尊VIP提升到"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[3]
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "级，拥有更多的尊贵特权"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "4" then
		str = "恭喜"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "将"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getEquipNameById(tonumber(msgArgList[3]))
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "强化至"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "+"..msgArgList[4]
		element = wdui.RichItemText:create(1, self.systemSpecialColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "，称霸江湖指日可待"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "5" then
		str = "好运连连，"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "在"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getMapNameById(tonumber(msgArgList[3]))
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "地图中获得绝世装备："
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getEquipNameById(tonumber(msgArgList[4]))
		element = wdui.RichItemText:create(1, self.systemSpecialColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "6" then
		str = "天降鸿运，"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(roleId, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:enableLinkLine(self.systemNameColor, 2)
		element:retain()
		table.insert(elementTabel,element)
		str = "在打开"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "超级宝箱"
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "中获得特殊神戒："
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getEquipNameById(tonumber(msgArgList[3]))
		element = wdui.RichItemText:create(1, self.systemSpecialColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
	elseif msgArgList[1] == "7" then
		elementTabel = {}
		--[[str = "天降鸿运，"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = msgArgList[2]
		element = wdui.RichItemText:create(1, self.systemNameColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "在打开"
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "白银宝箱"
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = "中获得绝世神器："
		element = wdui.RichItemText:create(1, self.systemCommonColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)
		str = self:getEquipNameById(tonumber(msgArgList[3]))
		element = wdui.RichItemText:create(1, self.systemValueColor, 255,str , "Helvetica", self.fontSize)  
		element:retain()
		table.insert(elementTabel,element)--]]
	end
	return elementTabel
	
	--[[
	1. 天降鸿运，{p=[我是大土豪]}在寻宝中获得绝世装备：{t=[轮回•麻痹]}

2. 恭喜{p=[我是大土豪]}领取{t=[首冲礼包]}，实力直线上升，世间无敌

3.祝贺{p=[我是大土豪]}将至尊VIP提升到{t=[5级]}，拥有更多的尊贵特权。

4.恭喜{p=[我是大土豪]}将{t=[轮回•麻痹]}强化至{t=[+12]}，称霸江湖指日可待。

5.好运连连，{p=[我是大土豪]}在{t=[石墓猪洞]}地图中获得绝世装备：{t=[天罡日月剑]}。
	]]
end

function ChatDataHandler:getEquipNameById(equipId)
	local equip = wd.GlobalData:getInstance():getEquipItemInXml(equipId)
	if equip then
		return equip:getName()
	else
		return ""
	end
end

function ChatDataHandler:getItemNameById(itemId)
	local item = wd.GlobalData:getInstance():getToolsItemInXml(itemId)
	if item then
		return item:getName()
	else
		return ""
	end
end

function ChatDataHandler:getMapNameById(mapId)
	local mapName
	if mapId-1 < 100 then
		mapName =  wd.GlobalData:getInstance():getMapName(mapId-1)
	else
		mapName = wd.GlobalData:getInstance():getPKMapName(mapId-1-101)
	end
	return mapName or ""
end

return ChatDataHandler
