
local ChatWholeLayer = class("ChatWholeLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function ChatWholeLayer.create()
    local layer = ChatWholeLayer.new()
    layer:createLayerMenu()
    return layer
end

function ChatWholeLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.lastSentTime = 0
	self._richChat = nil
	self.dataHandler = wd.chatHandler 
end

function ChatWholeLayer:clear()
	--self.dataHandler:stopTickSchedule()
    self:setVisible(false)
	self:setPosition(-10000,0)
end

function ChatWholeLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/chat/ChatWholeScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	local inputTextBox = tolua.cast(ccui.Helper:seekWidgetByName(node,"Input_TextBox"), "ccui.TextField")
	
	self.chatPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Chat_Panel"), "ccui.Layout")
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
	
	local systemBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"System_Button"), "ccui.Button")
    systemBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if self:getParent().chatSystemLayer == nil then
					local layerClass = require("src.game.chat.ChatSystemLayer")
					local layer = layerClass.create()
					self:getParent():addChild(layer)
					self:getParent().chatSystemLayer = layer
				else
					self:getParent().chatSystemLayer:setVisible(true)
				end
				self:getParent().chatSystemLayer:setPosition(0,0)
				self:getParent().chatSystemLayer:onEnter()
				self:clear()
            end
        end
    )
	
	local sendBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Send_Button"), "ccui.Button")
	sendBtn:setPressedActionEnabled(true)
	sendBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local text = inputTextBox:getString()
				if text ~= "" then
					if os.time() - self.lastSentTime > 5 then
						-- 发送
						self.dataHandler:requestSendChatMsg(text)
						self.lastSentTime = os.time()
					else
						wd.showRichTips(4,"话唠了吧，歇歇吧")
					end
				end
            end
        end
    )
	
	self.dataHandler:startTickSchedule()
	
	
	local function sendMsgCallBack()
		if self:isVisible() then
			wd.showRichTips(4,"发送成功")
			inputTextBox:setString("")
			self.dataHandler:requestGetChatMsg()
		end
	end
	
	local function updateCallBack()
		self:onEnter()
	end
	
	local listener = cc.EventListenerCustom:create("Send_Chat_Msg", sendMsgCallBack)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("Update_Chat_Whole", updateCallBack)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function ChatWholeLayer:onEnter()
	if self._richChat == nil then
		self._richChat = wdui.RichTextUI:create()
		--self._richChat:setBounceable(true)
		self._richChat:setContentSize(cc.size(804,368))--(self.chatPanel:getContentSize())
		self._richChat:setAnchorPoint(cc.p(0, 0))
		self.chatPanel:addChild(self._richChat)
		self._richChat:setPosition(cc.p(0,0))  
		
		local function callback(sender, eventType)
			if self:isVisible() then
				local tag = sender:getLabelTag()
				--print(tag)
				local layerClass = require("game.arena.PlayerLayer")
				local layer = layerClass.create()
				layer:createLayerMenu(wd.PlayerType.ENEMY)
				self:addChild(layer)
				
				wd.TranscodingSend:getPlayerData(tag)
			end
		end
		self._richChat:addEventListener(callback)
	else
		self._richChat:clearAll()
	end
	local elementList = self.dataHandler:getChatWorldElementList()
	for index,elementTabel in ipairs(elementList) do
		for i,v in ipairs(elementTabel) do
			self._richChat:insertElement(v)
		end
		self._richChat:insertNewLine()
	end
end

return ChatWholeLayer
