
local RingUpgradeLayer = class("RingUpgradeLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function RingUpgradeLayer.create()
    local layer = RingUpgradeLayer.new()
    return layer
end

function RingUpgradeLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
end

function RingUpgradeLayer:getRingUpgrade(serverId)

    local ringUpgrade = nil
    local number = wd.GlobalData:getInstance():getRingUpgradeCount()
    for i=0,number-1 do
        ringUpgrade = wd.GlobalData:getInstance():getRingUpgrade(i)
        local contents = ringUpgrade:getContents()
        
        local startIndex
        local lastIndex
        local id
        
        while(contents:len()>=2) do
            startIndex,lastIndex,id  = string.find(contents,"(%d+)")

            if id == nil then
                break
            end

            id = tonumber(id)
            
            cclog(" id %d  ", id)

            if id == serverId then
                return ringUpgrade
            end
            contents = string.sub(contents,lastIndex+1,-1)
        end
    
    end
    
    return nil
end

function RingUpgradeLayer:createLayerMenu(serverId)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/RingUpgradeLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)


    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )

    local cancelBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Cancel_Button"), "ccui.Widget")
    cancelBtn:setPressedActionEnabled(true)
    cancelBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )
    
    local item = wd.GlobalData:getInstance():getEquipItemForId(serverId)
    
    local tools = wd.GlobalData:getInstance():getToolsItemForId(1019)
	if tools == nil then
		wd.showRichTips(4,"特戒碎片不足")
		self:removeFromParent()
	end
    
    local ringUpgrade = self:getRingUpgrade(item:getEquipId())

    local needLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Need_Label"), "ccui.Text")
    local haveLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Have_Label"), "ccui.Text")
    local text1 = tolua.cast(ccui.Helper:seekWidgetByName(node,"Text1"), "ccui.Text")
    local text2 = tolua.cast(ccui.Helper:seekWidgetByName(node,"Text2"), "ccui.Text")
    
    if ringUpgrade == nil or ringUpgrade:getCount() == 0 then
        text2:setVisible(false)
        needLabel:setVisible(false)
        haveLabel:setVisible(false)
        text1:setString("已经达到最高阶级")
    else
        needLabel:setString(string.format("%s%d个",tools:getName(),ringUpgrade:getCount()))
        haveLabel:setString(string.format("%s%d个",tools:getName(),tools:getQuantity()))
    end

    local sureBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Sure_Button"), "ccui.Widget")
    sureBtn:setPressedActionEnabled(true)
    sureBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if ringUpgrade ~= nil and ringUpgrade:getCount() ~= 0 then
                    wd.TranscodingSend:setRingUpgrade(serverId)
                else
                    wd.showRichTips(4,"已经达到最高阶级")
                end
                self:removeFromParent()
            end
        end
    )
end


return RingUpgradeLayer