
local Family_Apply_ListLayer = class("Family_Apply_ListLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function Family_Apply_ListLayer.create()
    local layer = Family_Apply_ListLayer.new()
    layer:createLayerMenu()
    return layer
end

function Family_Apply_ListLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.familyHandler 
end


function Family_Apply_ListLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_ApplyerList")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Operate_Family")
end

function Family_Apply_ListLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/family/Family_Apply_Layer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
	
	
	local applyListView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Apply_ListView"), "ccui.ListView")
	local listViewWidth = applyListView:getContentSize().width
	
	local function onUpdateApplyerList()
		applyListView:removeAllItems()
		local applyList = self.dataHandler:getFamilyApplyerList()
			
		for index,member in ipairs(applyList) do
			local widget = ccui.Widget:create()
			local memberNode =  tolua.cast(cc.CSLoader:createNode("ui/family/Family_Applyer_Node.csb"),"ccui.Widget")
			local mainPanel = tolua.cast(memberNode:getChildByName("Main_Panel"), "ccui.Widget")
			local size = mainPanel:getContentSize()
			size.width = listViewWidth
			widget:setContentSize(size)
			mainPanel:setContentSize(size)
			mainPanel:setSwallowTouches(false)
			
			local headButton = tolua.cast(mainPanel:getChildByName("Head_Button"),"ccui.Button")
			headButton:setEnabled(true)
			headButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if member.id ~= wd.GlobalData:getInstance():getRoleId() then
							local layerClass = require("src.game.arena.PlayerLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(wd.PlayerType.ENEMY)
							self:addChild(layer)
							wd.TranscodingSend:getPlayerData(member.id)
						end
					end
				end
			)
			local headSprite =  tolua.cast(mainPanel:getChildByName("Head_Sprite"), "cc.Sprite")
			headSprite:setSpriteFrame(wd.getHeadImageName(member.occupation, member.sex))
			
			local job = tolua.cast(mainPanel:getChildByName("Job_Title"), "cc.Sprite")
			job:setSpriteFrame(wd.getEquipTitleName(member.occupation))
			
			local nameLabel = tolua.cast(mainPanel:getChildByName("Name_Label"), "ccui.Text")
			nameLabel:setString(member.name)
			local levelLabel = tolua.cast(mainPanel:getChildByName("Level_Label"), "ccui.Text")
			levelLabel:setString(string.format("Lv:%d",member.level))
			local vipLabel = tolua.cast(mainPanel:getChildByName("Vip_Label"), "ccui.Text")
			vipLabel:setString(string.format("Vip:%d",member.vipLevel))
			local fightPowerLabel = tolua.cast(mainPanel:getChildByName("FightPower_Label"), "ccui.Text")
			fightPowerLabel:setString(member.fightPower)
			
			
			local onlineLabel = tolua.cast(mainPanel:getChildByName("Online_Label"), "ccui.Text")
			onlineLabel:setString(member.offlineTime)
			
			local agreeBtn = tolua.cast(mainPanel:getChildByName("Agree_Button"),"ccui.Button")
			agreeBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						-- 同意
						self.dataHandler:requestHandleApply(member.id,wd.familyOperateType.AGREE_APPLY)
					end
				end
			)
			local disagreeBtn = tolua.cast(mainPanel:getChildByName("Disagree_Button"),"ccui.Button")
			disagreeBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						-- 拒绝
						self.dataHandler:requestHandleApply(member.id,wd.familyOperateType.CONFUSE_APPLY)
					end
				end
			)
			
			widget:setAnchorPoint(cc.p(0,0))
			widget:setTag(index)
			widget:addChild(memberNode)
			memberNode:setPosition(cc.p(0,0))
			memberNode:setTag(index)
			applyListView:pushBackCustomItem(widget)
		end
	end
	local listener = cc.EventListenerCustom:create("Update_ApplyerList", onUpdateApplyerList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	
	local function onOperateFamily()
		wd.showRichTips(4,"操作成功")
		self.dataHandler:requestApplyerList()
	end
	local listener = cc.EventListenerCustom:create("Operate_Family", onOperateFamily)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
end

return Family_Apply_ListLayer

