
local Family_Member_InfoLayer = class("Family_Member_InfoLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function Family_Member_InfoLayer.create()
    local layer = Family_Member_InfoLayer.new()
    layer:createLayerMenu()
    return layer
end

function Family_Member_InfoLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.familyHandler 
	self.upgradeLayer = nil
	self.declarationLayer = nil
	self.announceLayer = nil
end

function Family_Member_InfoLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Upgrade_Family")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Announcement_Change")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Declaration_Change")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Dissolve_Family")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Upgrade_FamilyInfo")
end

function Family_Member_InfoLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/family/Family_Mine_InfoScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("RemoveFamilyMineLayer")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				self:clear()
            end
        end
    )
	
	local memberBtn = ccui.Helper:seekWidgetByName(node,"Member_Button")
	memberBtn:setPressedActionEnabled(true)
    memberBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self.dataHandler:requestGetFamilyMemberList()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Operate_Family")
				local layerClass = require("src.game.family.Family_Member_ListLayer")
                self:getParent().familyMineLayer = layerClass.create()
                self:getParent():addChild(self:getParent().familyMineLayer)
				self:clear()
            end
        end
    )
	
	local templeBtn = ccui.Helper:seekWidgetByName(node,"Temple_Button")
	templeBtn:setPressedActionEnabled(true)
    templeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.family.Family_Member_TempleLayer")
                self:getParent().familyMineLayer = layerClass.create()
                self:getParent():addChild(self:getParent().familyMineLayer)
				self:clear()
				--wd.showSystemTips("暂未开放")
            end
        end
    )
    local device = require("cocos.framework.device")
    if device.platform == "ios" and wd.GlobalData:getInstance():getSdk() == 8 then
		templeBtn:setVisible(false)
		local Panel_Button = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Button"), "ccui.Widget")
		local templeTtile = tolua.cast(Panel_Button:getChildByName("family_request_disable_11"), "cc.Sprite")
		-- local templeTtile = ccui.Helper:seekWidgetByName(node,"family_request_disable_11")
		templeTtile:setVisible(false)
    end
	
	local otherBtn = ccui.Helper:seekWidgetByName(node,"Other_Button")
	otherBtn:setPressedActionEnabled(true)
    otherBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				wd.familyHandler:requestGetAllFamilyInfo()
				local layerClass = require("game.family.Family_List_AllLayer")
				local layer = layerClass.create()
				layer:setFamilyListType(wd.familyListType.Joined)
				layer:createLayerMenu()
				self:addChild(layer)
            end
        end
    )
	
	
	local function updateFamilyInfo()
		local myFamily = wd.GlobalData:getInstance():getMyFamilyItem()
		self.dataHandler:setMyJob(myFamily:getMyJob())
		
		local familyNameLabel =  tolua.cast(ccui.Helper:seekWidgetByName(node,"FamilyName_Label"), "ccui.Text")
		familyNameLabel:setString(myFamily:getName())
		
		local declarationBtn = ccui.Helper:seekWidgetByName(node,"Declaration_Button")
		declarationBtn:setPressedActionEnabled(true)
		declarationBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local layerClass = require("src.game.family.Family_Declaration_Layer")
					self.declarationLayer = layerClass.create()
					self:addChild(self.declarationLayer)
				end
			end
		)
		
		local infoPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Info_Panel"), "ccui.Widget")
		local chairmanLabel = tolua.cast(infoPanel:getChildByName("Chairman_Label"), "ccui.Text")
		chairmanLabel:setString(myFamily:getChaimanName()) 
		local levelLabel = tolua.cast(infoPanel:getChildByName("Level_Label"), "ccui.Text")
		levelLabel:setString(myFamily:getLevel())
		self.dataHandler:setMyFamilyLevel(myFamily:getLevel())
		local rankLabel = tolua.cast(infoPanel:getChildByName("Rank_Label"), "ccui.Text")
		rankLabel:setString(myFamily:getRank())	
		local countLabel = tolua.cast(infoPanel:getChildByName("Number_Label"), "ccui.Text")
		countLabel:setString(string.format("%d/%d",myFamily:getCurrentCount(),myFamily:getLimitCount()))
		local contributeLabel = tolua.cast(infoPanel:getChildByName("Contribute_Label"), "ccui.Text")
		contributeLabel:setString(myFamily:getContribute())
		self.dataHandler:setMyContribute(myFamily:getContribute())
		
		local applyBtn = tolua.cast(infoPanel:getChildByName("Apply_Button"), "ccui.Widget")
		applyBtn:setPressedActionEnabled(true)
		applyBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					if myFamily:getMyJob() == wd.familyJobType.Family_Father or myFamily:getMyJob() == wd.familyJobType.Family_Mother then
						-- 申请审核
						self.dataHandler:requestApplyerList()
						cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Operate_Family")
						local layerClass = require("src.game.family.Family_Apply_ListLayer")
						local layer = layerClass.create()
						self:addChild(layer)
					else
						-- 弹劾
						local function impeachChairman()
							self.dataHandler:requestImpeachChairman(myFamily:getChairmanId())
						end
						cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Operate_Family")
						local layerClass = require("src.game.family.Family_MessageBox_Layer")
						self.tipsLayer = layerClass.create("family_btntitle_impeach.png","族长七天内没登陆即可进行弹劾(弹劾成功您将成为族长)，是否弹劾族长",impeachChairman)
						self.tipType = wd.familyOperateType.IMPEACH_FATH
						self:addChild(self.tipsLayer)
					end
				end
			end
		)
		local applyBtnTitle = tolua.cast(applyBtn:getChildByName("Apply_Button_Title"), "cc.Sprite")
		
		local disbandBtn = tolua.cast(infoPanel:getChildByName("Disband_Button"), "ccui.Widget")
		disbandBtn:setPressedActionEnabled(true)
		disbandBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					if myFamily:getMyJob() == wd.familyJobType.Family_Father or myFamily:getMyJob() == wd.familyJobType.Family_Mother then
						--解散
						local function dissolveFamily()
							self.dataHandler:requestDissolveFamily()
						end
						local layerClass = require("src.game.family.Family_MessageBox_Layer")
						self.tipsLayer = layerClass.create("family_subtitle_disband.png","是否确定解散家族(一旦解散将无法恢复)？",dissolveFamily)
						self:addChild(self.tipsLayer)
					else
						--退出
						local function exitFamily()
							self.dataHandler:requestExitFamily()
						end
						local layerClass = require("src.game.family.Family_MessageBox_Layer")
						self.tipsLayer = layerClass.create("family_subtitle_exit.png","请问是否退出家族？",exitFamily)
						self.tipType = wd.familyOperateType.FAM_NO
						self:addChild(self.tipsLayer)
					end
				end
			end
		)
		local disbandBtnTitle = tolua.cast(disbandBtn:getChildByName("Disband_Button_Title"), "cc.Sprite")
		
		local announcePanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Announce_Panel"), "ccui.Widget")
		local announceLabel = tolua.cast(announcePanel:getChildByName("Announcement_Text"), "ccui.Text")
		announceLabel:setString(myFamily:getAnnouncement())
		self.dataHandler:setNoticeChangeMsg(wd.familyNoticeType.Announcement,myFamily:getAnnouncement())
		
		local changeAnnounceBtn = tolua.cast(announcePanel:getChildByName("Announce_Button"), "ccui.Widget")
		changeAnnounceBtn:setPressedActionEnabled(true)
		changeAnnounceBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local layerClass = require("src.game.family.Family_AnnounceLayer")
					self.announceLayer = layerClass.create()
					self:addChild(self.announceLayer)
				end
			end
		)
		
		local levelBtnPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"LevelBtn_Panel"), "ccui.Widget")
		for i = 1,7 do
			local flag,bar,barSprite
			local btn = tolua.cast(levelBtnPanel:getChildByName(string.format("Level_Button_%d",i)), "ccui.Widget")
			local contributeBox = tolua.cast(levelBtnPanel:getChildByName(string.format("Contribute_Box_%d",i)), "cc.Sprite")
			local contributeLabel = tolua.cast(contributeBox:getChildByName("Contribute_Label"),"ccui.Text")
			if i ~= 7 then
				bar = tolua.cast(levelBtnPanel:getChildByName(string.format("Level_Bar_%d",i+1)), "ccui.ImageView")
				barSprite = tolua.cast(bar:getChildByName("Level_Bar"),"ccui.ImageView")
			end
			if i <= myFamily:getLevel() then
				if barSprite then
					barSprite:setVisible(true)
				end
				btn:setBright(true)
				btn:setEnabled(true)
				if i == myFamily:getLevel() then
					btn:setPressedActionEnabled(true)
					btn:addTouchEventListener(
						function(sender,eventType)
							if eventType == ccui.TouchEventType.ended then
								if myFamily:getMyJob() == wd.familyJobType.Family_Father or myFamily:getMyJob() == wd.familyJobType.Family_Mother then
									if i == 7 then
										wd.showRichTips(4,"已满级")
									else
										local layerClass = require("src.game.family.Family_Upgrade_Layer")
										self.upgradeLayer = layerClass.create(myFamily)
										self:addChild(self.upgradeLayer)
									end
								else
									wd.showRichTips(4,"只有族长和副族长可升级家族")
								end
							end
						end
					)
					contributeBox:setVisible(true)
					if myFamily:getFullExperience() == 0 then
						contributeLabel:setString(string.format("%d/已满级",myFamily:getCurExperience()))
					else
						contributeLabel:setString(string.format("%d/%d",myFamily:getCurExperience(),myFamily:getFullExperience()))
					end
				else
					contributeBox:setVisible(false)
				end
			else
				btn:setBright(false)
				btn:setEnabled(false)
				if barSprite then
					barSprite:setVisible(false)
				end
			end
			
			
		end
		
		if myFamily:getMyJob() == wd.familyJobType.Family_Father or myFamily:getMyJob() == wd.familyJobType.Family_Mother then
			applyBtnTitle:setSpriteFrame("family_btntitle_apply.png")
			disbandBtnTitle:setSpriteFrame("family_btntitle_disband.png")
			declarationBtn:setVisible(true)
			changeAnnounceBtn:setVisible(true)
		else
			applyBtnTitle:setSpriteFrame("family_btntitle_impeach.png")
			disbandBtnTitle:setSpriteFrame("family_btntitle_exit.png")
			declarationBtn:setVisible(false)
			changeAnnounceBtn:setVisible(false)
		end
	
	end
	
	local listener = cc.EventListenerCustom:create("Upgrade_FamilyInfo", updateFamilyInfo)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	updateFamilyInfo()
	
	local function onUpgrdeSuccess()
		wd.showRichTips(4,"升级成功")
		if self.upgradeLayer then
			self.upgradeLayer:removeFromParent()
		end
		self.dataHandler:requestOpenFamily()
	end
	local listener = cc.EventListenerCustom:create("Upgrade_Family", onUpgrdeSuccess)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onAnnounceChange()
		wd.showRichTips(4,"修改成功")
		if self.announceLayer then
			self.announceLayer:removeFromParent()
		end
		announceLabel:setString(self.dataHandler:getChangeNoticeMsgByType(wd.familyNoticeType.Announcement))
	end
	local listener = cc.EventListenerCustom:create("Announcement_Change", onAnnounceChange)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onDeclarationChange()
		wd.showRichTips(4,"修改成功")
		if self.declarationLayer then
			self.declarationLayer:removeFromParent()
		end
	end
	local listener = cc.EventListenerCustom:create("Declaration_Change", onDeclarationChange)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onDissolve()
		wd.showRichTips(4,"家族已解散")
		local event = cc.EventCustom:new("RemoveFamilyMineLayer")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
		self:clear()
	end
	local listener = cc.EventListenerCustom:create("Dissolve_Family", onDissolve)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onOperateFamily()
		if self.tipType == wd.familyOperateType.IMPEACH_FATH then
			wd.showRichTips(4,"弹劾成功")
			if self.tipsLayer then
				self.tipsLayer:removeFromParent()
				self.tipsLayer = nil
			end
			self.dataHandler:requestOpenFamily()
		elseif self.tipType == wd.familyOperateType.FAM_NO then
			wd.showRichTips(4,"已退出家族")
			local event = cc.EventCustom:new("RemoveFamilyMineLayer")
			cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
			self:clear()
		end
		
	end
	local listener = cc.EventListenerCustom:create("Operate_Family", onOperateFamily)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onRemoveTips()
		if self.tipsLayer then
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Remove_Tips", onRemoveTips)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

return Family_Member_InfoLayer
