
local GiftPurchaseLayer = class("GiftPurchaseLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function GiftPurchaseLayer.create()
    local layer = GiftPurchaseLayer.new()
    layer:createLayerMenu()
    return layer
end

function GiftPurchaseLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.giftHandler 
end

function GiftPurchaseLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_DiscountList")
end

function GiftPurchaseLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/gift/PurchaseScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				self:clear()
            end
        end
    )
	
	local achieveBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Achieve_Button"), "ccui.Button")
    achieveBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self.dataHandler:requestFinishAwardState()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				local layerClass = require("src.game.gift.GiftAchieveLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
				self:clear()
            end
        end
    )
	
	local leftPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Left_Panel"), "ccui.Layout")
	local rightPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Right_Panel"), "ccui.Layout")
	local panelList = {
		[1] = leftPanel,
		[2] = rightPanel,
	}
	
	local function onUpdateDiscountList()
		local discountItemList = self.dataHandler:getDiscountItemList()
		for i,v in ipairs(discountItemList) do
			local purchaseNode = tolua.cast(cc.CSLoader:createNode("ui/gift/PurchaseNode.csb"),"ccui.Widget")
			local discountNode = tolua.cast(ccui.Helper:seekWidgetByName(purchaseNode,"Panel_Main"), "ccui.Widget")
			local nameLabel =  tolua.cast(discountNode:getChildByName("Name_Label"), "ccui.Text")
			nameLabel:setString(v.title)
			local numberLabel = tolua.cast(discountNode:getChildByName("Number_Label"), "ccui.Text")
			numberLabel:setString(string.format("限购数量 X%d",v.number))
			local priceLabel = tolua.cast(discountNode:getChildByName("Original_Price"), "ccui.Text")
			priceLabel:setString(string.format("%d",v.price))
			local discountPriceLabel = tolua.cast(discountNode:getChildByName("Current_Price"), "ccui.Text")
			discountPriceLabel:setString(string.format("%d",v.discountPrice))
			local itemButton = tolua.cast(discountNode:getChildByName("Item_Button"),"ccui.Button")
			itemButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						-- 物品图标点击
						local layerClass =  require("game.package.ToolsTipsLayer")
						local layer = layerClass.create()
						layer:createLayerMenu(v.item:getToolsId(),true)
						self:addChild(layer)
					end
				end
			)
			local itemNode =  tolua.cast(discountNode:getChildByName("Item_Node"),"ccui.Widget")
			local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
			color:setSpriteFrame(string.format("%02d.png",v.item:getQuality()))
			local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",v.item:getToolsId()))
			if v.item:getQuality() == 5 then
				wd.itemEffect(image)
			end
			local buyButton = tolua.cast(discountNode:getChildByName("Buy_Button"),"ccui.Button")
			buyButton:setPressedActionEnabled(true)
			buyButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if v.number ~= 0 then
							self.dataHandler:requestBuyDiscountItem(v.id)
						else
							wd.showRichTips(4,"已售罄，期待0点刷新")
						end
					end
				end
			)
			panelList[i]:addChild(purchaseNode)
			purchaseNode:setPosition(cc.p(0,0))
		end
	end
	
	local function onBuyDiscountItem()
		self.dataHandler:requestOpenDiscountShop()
		--wd.showSystemTips("购买成功")
	end
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"购买成功，获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Buy,msg)
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("Update_DiscountList", onUpdateDiscountList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("Buy_DiscountItem", onBuyDiscountItem)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end


return GiftPurchaseLayer

