
local MapLayer = class("MapLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function MapLayer.create(guidanceIndex)
    local layer = MapLayer.new()
    layer:createLayerMenu(guidanceIndex)
    return layer
end

function MapLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
end

function MapLayer:createSwallowLayer()

    local listener = cc.EventListenerTouchOneByOne:create()
    listener:setSwallowTouches(true)

    listener:registerScriptHandler(
        function()
            return true
        end
        ,cc.Handler.EVENT_TOUCH_BEGAN)

    self:getEventDispatcher():addEventListenerWithSceneGraphPriority(listener,self)
    
end

function MapLayer:createLayerMenu(guidanceIndex)
    local node = tolua.cast(cc.CSLoader:createNode("ui/map/MapScene.csb"), "ccui.Widget")
    self:addChild(node)

    local challengeNum = tolua.cast(ccui.Helper:seekWidgetByName(node,"boss_challenge_num"), "ccui.Text")
    local bossChallengeNum = wd.GlobalData:getInstance():getRoleData():getBossChallengeNum()
    challengeNum:setString(bossChallengeNum.."次")
    
    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)

    local function backCallback(sender,eventType)

        if eventType == ccui.TouchEventType.ended then
            self:removeFromParent()
        end
    end
    
    backBtn:addTouchEventListener(backCallback)

	-- local pkBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"PK_Button"), "ccui.Widget")
    -- pkBtn:setPressedActionEnabled(true)
    -- pkBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
	-- 			local isOpen,msg = wd.checkOpen(wd.openKey.PkMap)
	-- 			if isOpen then
	-- 				local layerClass = require("src.game.map.PKMapLayer")
	-- 				local layer = layerClass.create()
	-- 				self:getParent():addChild(layer)
	-- 				self:removeFromParent()
	-- 				if cc.UserDefault:getInstance():getBoolForKey("FirstPK") then
	-- 					local newLayerClass = require("src.game.NewWelcomeLayer")
	-- 					local newLayer = newLayerClass.create()
	-- 					newLayer:createLayerMenu(wd.newWelcomeKey.PK)
	-- 					layer:addChild(newLayer)
	-- 				end
	-- 			else
	-- 				wd.showRichTips(3,msg)
	-- 			end
                
    --         end
    --     end
    -- )
	
    local function mapCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            local hadFightBossId = wd.GlobalData:getInstance():getRoleData():getBossId() --bossId从1开始
            if guidanceIndex == 1 then
                local event = cc.EventCustom:new("guidance_quickBattle")
                cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
            end
			if sender:getTag() <= hadFightBossId - 1 then
				self:getParent():showBattleLayer(sender:getTag())
				self:removeFromParent()
			else
				wd.showRichTips(4,string.format("请先战胜第%d个Boss",hadFightBossId))
			end
        end
    end

    
    local function mapNodeCallback(sender,eventType) --ljg
        if eventType == ccui.TouchEventType.ended then		
            local bossChallengeNum = wd.GlobalData:getInstance():getRoleData():getBossChallengeNum()
            if self.clippingLayer then
                self.clippingLayer:removeFromParent()
                self.clippingLayer = nil
                local event = cc.EventCustom:new("guidance_waitBoss")
                cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
            end
            
            
            if bossChallengeNum > 0 then
                self:getParent():showBattleLayer(sender:getTag(),true)
                local name  = wd.GlobalData:getInstance():getMapName(sender:getTag())
                local level = wd.GlobalData:getInstance():getMapLevel(sender:getTag())
                self:getParent().battleLayer:setBossFight(true,0,name,level)
                self:removeFromParent()
            else
                local layer = require("src.game.map.MapBossTips"):create(function()
                    self:getParent():showBattleLayer(sender:getTag(),true)
                    local name  = wd.GlobalData:getInstance():getMapName(sender:getTag())
                    local level = wd.GlobalData:getInstance():getMapLevel(sender:getTag())
                    self:getParent().battleLayer:setBossFight(true,1,name,level)
                    self:removeFromParent()
                end)
                self:addChild(layer)
                -- wd.showRichTips(4,string.format("今天的Boss挑战次数已经用完"))
            end
        end
    end

    local mapList = tolua.cast(ccui.Helper:seekWidgetByName(node,"Map_List"), "ccui.ListView")

    -- local number = wd.GlobalData:getInstance():getMapShowCount()
    local count =wd.GlobalData:getInstance():getRoleData():getBossId() --bossId从1开始
    --mapList:setInnerContainerSize(cc.size(909, 140*number))
    --mapList:setContentSize(cc.size(909, self.visibleSize.height - 88));
    
    -- for i=0,number-1 do
    for i=0,count do
		if i >= wd.GlobalData:getInstance():getMapCount() then
			return
		end
        local btn = ccui.Button:create("map_button.png", "map_button.png", "map_button.png", ccui.TextureResType.plistType)
        btn:setAnchorPoint(cc.p(0,0))
        btn:setTag(i)
        btn:addTouchEventListener(mapCallback)

        local mapNode = tolua.cast(cc.CSLoader:createNode("ui/map/MapNode.csb"),"ccui.Widget")
        btn:addChild(mapNode)
        
        local title = tolua.cast(mapNode:getChildByName("mode_title"), "cc.Sprite")
        title:setSpriteFrame(string.format("map_name_lv%d.png",i))
        
        local submap = tolua.cast(mapNode:getChildByName("map_submap"), "cc.Sprite")
        submap:setSpriteFrame(string.format("map_lv%d.png",i))
        
        local levelLabel = mapNode:getChildByName("monster_lever")
        levelLabel:setString(string.format("lv%d",wd.GlobalData:getInstance():getMapLevel(i)))
        
        local  infoLabel = tolua.cast(mapNode:getChildByName("info_label"), "ccui.Text")
        infoLabel:setString(wd.GlobalData:getInstance():getMapDescription(i))

        mapList:pushBackCustomItem(btn)

        if i == count then
            mapNode:getChildByName("lock"):setVisible(true)
            mapNode:getChildByName("mask"):setVisible(true)
        else
            local bossBtn = tolua.cast(mapNode:getChildByName("boss"), "ccui.Button")
            bossBtn:setPressedActionEnabled(true)
            bossBtn:setTag(i)
            bossBtn:addTouchEventListener(mapNodeCallback)
            ------------------------------新手引导----------------------------
            if guidanceIndex and guidanceIndex == 0 then
                local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
                if clippingLayer then
                    ---------特殊处理position坐标---------
                    local position = mapNode:convertToWorldSpace(cc.p(bossBtn:getPositionX(),bossBtn:getPositionX()))
                    
                    local visibleSize = cc.Director:getInstance():getVisibleSize()
                    local origin = cc.Director:getInstance():getVisibleOrigin()
                    position.y = origin.y + visibleSize.height - 174
                    
                    clippingLayer:setGuidance(bossBtn,30,50,115,115,position)
                    local msgTable = {}
                    local msg = {}
                    table.insert(msg,"战胜这个地图的")
                    table.insert(msg,"{r=[守关BOSS]}")
                    table.insert(msg,"后才能更换地图哟，看你的了！")
                    table.insert(msgTable,msg)
                    clippingLayer:setMsg(msgTable)
                    self:addChild(clippingLayer)
                    self.clippingLayer = clippingLayer
                end    
            elseif guidanceIndex and guidanceIndex == 1 then
                local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
                if clippingLayer then
                    ---------特殊处理position坐标---------
                    local position = mapNode:convertToWorldSpace(cc.p(btn:getPositionX(),btn:getPositionX()))
                    position.x = position.x + 150
                    local visibleSize = cc.Director:getInstance():getVisibleSize()
                    local origin = cc.Director:getInstance():getVisibleOrigin()
                    position.y = origin.y + visibleSize.height - 356
                    
                    clippingLayer:setGuidance(bossBtn,30,20,300,115,position)
                    local msgTable = {}
                    local msg = {}
                    table.insert(msg,"{r=[第二关地图]}")
                    table.insert(msg,"听说也很弱，咱们进入试试瞧瞧！")
                    table.insert(msgTable,msg)
                    clippingLayer:setMsg(msgTable)
                    self:addChild(clippingLayer)
                    self.clippingLayer = clippingLayer
                end    
            end   
            ---------------------------------------------------------------------
        end
         
        if wd.GlobalData:getInstance():getLastLoginMapId() == i then
            local hangingTitle = cc.Sprite:createWithSpriteFrameName("map_hanging_title.png")
            hangingTitle:setPosition(600,100)
            btn:addChild(hangingTitle)
        end
    end

end


return MapLayer