local PKMapFightInfoLayer = class("PKMapFightInfoLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PKMapFightInfoLayer.create()
    local layer = PKMapFightInfoLayer.new()
	layer:createLayerMenu()
    return layer
end

function PKMapFightInfoLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.fontSize = 20
	self.gap = 20
	self.msgList = {
		[1] = "%s，你在%s地图中被%s恶意攻击，你战败了，无损失。",
		[2] = "%s，你在%s地图中被%s恶意攻击，你战败了，损失了%s。",
		[3] = "%s，你在%s地图中被%s恶意攻击，你战胜了他。",
		[4] = "%s，你在%s地图中恶意攻击%s，你战败了。",
		[5] = "%s，你在%s地图中恶意攻击%s，你战胜了他，一无所获。",
		[6] = "%s，你在%s地图中恶意攻击%s，你战胜了他，获得了%s。",
	}
end

function PKMapFightInfoLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_PKRecord")
end

function PKMapFightInfoLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/map/PKInfoScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
   
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:clear()
            end
        end
    )
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	local contentScroll = tolua.cast(mainPanel:getChildByName("Info_ScrollView"), "ccui.ScrollView")
	local function updateScroll()
		contentScroll:removeAllChildren()
		
		self.totalHeight = 0
		
		local richLabelList = self:getRichlabelList(contentScroll)
		local size = contentScroll:getContentSize()
		
		local layer = ccui.Widget:create()
		
		local lastHeight,lastPosX,lastPosY = 0,0,0
		if richLabelList then
			for i,v in ipairs(richLabelList) do
				layer:addChild(v)
				if i == 1 then
					v:setPosition(v:getContentSize().width/2+10,-v:getContentSize().height/2-self.gap)
				else
					v:setPosition(v:getContentSize().width/2+10,lastPosY-lastHeight/2-v:getContentSize().height/2-self.gap)
				end
				lastHeight = v:getContentSize().height
				lastPosX,lastPosY = v:getPosition()
				self.totalHeight = self.totalHeight + lastHeight + self.gap
			end
		end
		
		contentScroll:setInnerContainerSize(cc.size(contentScroll:getContentSize().width,self.totalHeight+self.fontSize*2))
		contentScroll:addChild(layer)
		layer:setPosition(0,contentScroll:getInnerContainerSize().height)
		contentScroll:jumpToTop()
	end
	local listener = cc.EventListenerCustom:create("Update_PKRecord", updateScroll)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
end

function PKMapFightInfoLayer:getRichlabelList(contentScroll)
	local recordList = wd.pkHandler:getRecordList()
	local richLabelList = {}
	for i,v in ipairs(recordList) do
		local richTextLabel = ccui.RichText:create()
		local timeStr = ""
		if math.abs(v.currentTime - v.dropTime) <= 3600 then
			timeStr = "刚刚"
		elseif math.abs(v.currentTime - v.dropTime) > 3600 and math.abs(v.currentTime - v.dropTime) <= 24*3600 then
			timeStr = "一小时前"
		elseif math.abs(v.currentTime - v.dropTime) > 24*3600 and math.abs(v.currentTime - v.dropTime) <= 48*3600 then
			timeStr = "一天前"
		elseif math.abs(v.currentTime - v.dropTime) > 48*3600 then
			timeStr = "两天前"
		end
		if timeStr ~= "" then
			timeStr = string.format("{t=[%s]}",timeStr)
		end
		local mapName
		
		local pkMapInfoList = wd.pkHandler:getPKMapInfoList()
		for key,value in ipairs(pkMapInfoList) do
			if value.id == v.mapId then
				mapName = string.format("{m=[%s]}",value.name)
				break
			end
		end
		
		local enemyName = string.format("{d=[%s]}",v.name)
		local equipName = ""
		if v.equipId ~= 0 then
			equipName = wd.GlobalData:getInstance():getEquipItemInXml(v.equipId):getName()
		end
		local totalStr
		if equipName ~= "" then
			equipName = string.format("{e=[%s],c=[%d]}",equipName,v.equipColor)
			totalStr = string.format(self.msgList[v.pkType],timeStr,mapName,enemyName,equipName)
		else
			totalStr = string.format(self.msgList[v.pkType],timeStr,mapName,enemyName)
		end
		local richElementList = self:parseWord(totalStr)
		if richElementList then
			for i,v in ipairs(richElementList) do
				richTextLabel:pushBackElement(v)
			end
		end
		richTextLabel:formatText()
		local labelSize = richTextLabel:getContentSize()
		if labelSize.width > contentScroll:getContentSize().width - self.fontSize then
			self.upHeight = math.ceil(labelSize.width / (contentScroll:getContentSize().width- self.fontSize))* labelSize.height
		else
			self.upHeight = labelSize.height
		end
		richTextLabel:ignoreContentAdaptWithSize(false)
		richTextLabel:setContentSize(contentScroll:getContentSize().width- self.fontSize,self.upHeight)
		table.insert(richLabelList,richTextLabel)
	end
	return richLabelList
end

function PKMapFightInfoLayer:parseWord(msg)
	local richElementList = {}
	local startIndex,lastIndex,str,color,index,colorStr
	local parsedStr = msg
	self.tag = 1
	if type(parsedStr) == "string" then	
		local circleTime = 0
		while (string.find(parsedStr,"{") ~= nil)	
		do
			if circleTime > 30 then
				break
			end
			
			index= string.find(parsedStr,"{")
			local strType = string.sub(parsedStr,index+1,index+1)
			if strType == "t" then
				startIndex,lastIndex,str = string.find(parsedStr,"{t=%[(.-)%]}")  
				color = wd.battleColorTable["type"]
			elseif strType == "m" then
				startIndex,lastIndex,str = string.find(parsedStr,"{m=%[(.-)%]}")  
				color = wd.announcementColor["PURPLE"]
			elseif strType == "d" then
				startIndex,lastIndex,str = string.find(parsedStr,"{d=%[(.-)%]}")  
				color = wd.battleColorTable["enemy"]
			elseif strType == "e" then
				--todo
				startIndex,lastIndex,str,colorStr = string.find(parsedStr,"{e=%[(.-)%],c=%[(.-)%]}")  
				color = wd.colorTable[tonumber(colorStr)]
			end
			if startIndex and lastIndex and str then
				richElementList = self:parseStrAndSetRichElement(richElementList,parsedStr,startIndex,lastIndex,str,color)
				parsedStr = string.sub(parsedStr,lastIndex+1,-1)
			end
			circleTime = circleTime + 1
		end
		parsedStr = string.sub(parsedStr,1,-1) 
		local richElement = ccui.RichElementText:create(self.tag,cc.c3b(255,255,255),255,parsedStr,"Helvetica",self.fontSize)
		self.tag = self.tag+1
		table.insert(richElementList,richElement)
		
		return richElementList
	end
end

function PKMapFightInfoLayer:parseStrAndSetRichElement(richElementList,parsedStr,startIndex,lastIndex,str,color)
	if not color then
		color = cc.c3b(255,0,0)
	end
	parsedStr = string.sub(parsedStr,1,startIndex-1)
	local richElement = ccui.RichElementText:create(self.tag,cc.c3b(255,255,255),255,parsedStr,"Helvetica",self.fontSize)
	self.tag = self.tag+1
	table.insert(richElementList,richElement)
	richElement = ccui.RichElementText:create(self.tag,color,255,str,"Helvetica",self.fontSize)
	self.tag = self.tag+1
	table.insert(richElementList,richElement)
	return richElementList
end

return PKMapFightInfoLayer