
local PKMapLayer = class("PKMapLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PKMapLayer.create()
    local layer = PKMapLayer.new()
    layer:createLayerMenu()
    return layer
end

function PKMapLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.handingId = 0
end

function PKMapLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_PlayerList")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_PK_Count")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("exploration_change")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Exploration")
end

function PKMapLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/map/PkMapScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Box"), "ccui.Widget")
	local currentMapSprite =  tolua.cast(mainPanel:getChildByName("Current_Map"), "cc.Sprite")
	
	local killValue = tolua.cast(mainPanel:getChildByName("kill_value"), "ccui.Text")
	local kill = wd.GlobalData:getInstance():getRoleData():getKill()
	killValue:setString(kill)
	local red = 255*(kill < 500 and kill/500 or 1)
	local green = 255*(500 - (kill > 500 and 500 or kill))/500
	killValue:setColor(cc.c3b(red,green,0))
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)

    local function backCallback(sender,eventType)

        if eventType == ccui.TouchEventType.ended then
            self:clear()
        end
    end
    
    backBtn:addTouchEventListener(backCallback)

	-- local safeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Safe_Button"), "ccui.Widget")
    -- safeBtn:setPressedActionEnabled(true)
    -- safeBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
    --             local layerClass = require("src.game.map.MapLayer")
    --             local layer = layerClass.create()
    --             self:getParent():addChild(layer)
	-- 			self:clear()
    --         end
    --     end
    -- )

	local mapPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Map_Panel"), "ccui.Widget")
	
	local countLabel = tolua.cast(mapPanel:getChildByName("Number_Label"), "ccui.Text")
	countLabel:setString(wd.GlobalData:getInstance():getRolePkNumber())
	
	local helpBtn = tolua.cast(mapPanel:getChildByName("Help_Button"), "ccui.Button")
	helpBtn:setPressedActionEnabled(true)
    helpBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.setting.HelpLayer")
				local layer = layerClass.create(wd.helpType.Sub,wd.helpTag.PkMap)
				self:addChild(layer)
            end
        end
    )
	
	local infoBtn = tolua.cast(mapPanel:getChildByName("Review_Button"), "ccui.Button")
	infoBtn:setPressedActionEnabled(true)
    infoBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.map.PKMapFightInfoLayer")
				local layer = layerClass.create()
				self:addChild(layer)
				wd.pkHandler:requestFightInfo()
            end
        end
    )
	
	local addBtn = tolua.cast(mapPanel:getChildByName("Add_Button"), "ccui.Button")
	addBtn:setPressedActionEnabled(true)
    addBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.tips.TipsBoxLayer")
				local msgTable = {}
				local msg = {}
				local num = wd.GlobalData:getInstance():getRoleData():getRoleExtendData("buyed_pk_number")
				table.insert(msg,"是否花")
				table.insert(msg,string.format("{y=[%d元宝]}",20*(num + 1)))
				table.insert(msg,"购买")
				table.insert(msg,string.format("{g=[%d次]}",1))
				table.insert(msg,"pk挑战次数?")
				table.insert(msgTable,msg)
				local function buyNumber()
                    if wd.GlobalData:getInstance():getRoleGem() < 20*(num + 1) then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
                        wd.pkHandler:requestBuyPKCount() 
                    end
				end
				self.tipsLayer = layerClass.create("buy_count_title.png", msgTable,buyNumber)
				self:addChild(self.tipsLayer)
            end
        end
    )
	
	local pkMapInfoList = wd.pkHandler:getPKMapInfoList()
	for i,v in ipairs(pkMapInfoList) do
			local openFlag = "disable.png"
			if wd.GlobalData:getInstance():getRoleLevel() >= v.level and wd.GlobalData:getInstance():getRolePower() >= v.fight then
				openFlag = "normal.png"
			end

			local mapNode = tolua.cast(mapPanel:getChildByName(string.format("City_Node_%d",i)), "ccui.Widget")
			
			local normalBtn = tolua.cast(mapNode:getChildByName("City_Normal"), "ccui.Button")
			local normalSprite = string.format("map_%d_"..openFlag,v.id)
			normalBtn:loadTextures(normalSprite,normalSprite,normalSprite,1)
			normalBtn:setContentSize(normalBtn:getVirtualRendererSize())
			normalBtn:setPressedActionEnabled(true)
			normalBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						local endTime = tonumber(wd.GlobalData:getInstance():getRoleData():getRoleExtendData("end_time"))
						if endTime > os.time() then
							if v.id == self.handingId then
								local layer = require("src.game.map.PKSpeedUpTips"):create()
								layer:setup(math.ceil((endTime - os.time())/120))
								self:addChild(layer)
								return
							end
							wd.showRichTips(4,"正在"..pkMapInfoList[self.mapIndex].name.."探索中")
							return
						end
						if endTime > 0 and endTime < os.time() and tonumber(wd.GlobalData:getInstance():getRoleData():getRoleExtendData("finish")) == 0 then 
							wd.showRichTips(4,"请先领取奖励")
							return
						end
						
						local layerClass = require("src.game.map.PKMapTipLayer")
						local layer = layerClass.create()
						layer:createLayerMenu(v)
						self:addChild(layer)
					end
				end
			)
		local nameTitle = tolua.cast(mapNode:getChildByName("Name_Title"), "cc.Sprite")
		nameTitle:setSpriteFrame(string.format("maptitle_%d.png",v.id))
	end
	
	local function setPkMap()
		self.handingId = tonumber(wd.GlobalData:getInstance():getRoleData():getRoleExtendData("map"))
		if tonumber(wd.GlobalData:getInstance():getRoleData():getRoleExtendData("finish")) == 1 then
			self.handingId = 0
		end
		self.mapIndex = nil
		for i,v in ipairs(pkMapInfoList) do
			if v.id == self.handingId then
				self.mapIndex = i
			end
		end
		if self.handingId ~= 0 then
			currentMapSprite:setVisible(true)
			currentMapSprite:setSpriteFrame(string.format("maptitle_%d.png",self.handingId))
		else
			currentMapSprite:setVisible(false)
		end
		
		if self.reward then 
			self.reward:setVisible(false)
			self.mapNode:stopAllActions()
		end
		
		if self.mapIndex then
			local mapNode = tolua.cast(mapPanel:getChildByName(string.format("City_Node_%d",self.mapIndex)), "ccui.Widget")
			local effect = tolua.cast(mapNode:getChildByName("pk_effect"), "cc.Sprite")
			effect:setVisible(true)
			self.effect = effect
			local action = cc.CSLoader:createTimeline("ui/map/PkCityNode.csb")
			mapNode:runAction(action)
			action:play("effect",true)
			local leftTime = mapNode:getChildByName("count_down")
			local endTime = tonumber(wd.GlobalData:getInstance():getRoleData():getRoleExtendData("end_time"))
			local hour,minute,second,nowTime

			local function countDown()
				nowTime = endTime - os.time()
				if nowTime > 0 then
					hour = math.floor(nowTime/3600)
					minute = math.floor((nowTime - hour * 3600)/60)
					second = nowTime%60
					leftTime:setString(string.format("%02d:%02d:%02d",hour,minute,second))
				else
					mapNode:stopAllActions()
					effect:setVisible(false)
					leftTime:setString("")
					local reward = tolua.cast(mapNode:getChildByName("reward_btn"), "ccui.Button")
					local action = cc.CSLoader:createTimeline("ui/map/PkCityNode.csb")
					mapNode:runAction(action)
					action:play("reward",true)
					reward:setVisible(true)
					reward:addTouchEventListener(function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local packge = NetPackage:create()
							packge:add("role_id",wd.GlobalData:getInstance():getRoleData():getRoleId())
							packge = packge:encode()
							wd.TranscodingSend:luaSend(packge,ePCGetGiftExploration)
						end
					end)
					self.mapNode = mapNode
					self.reward = reward
				end
			end 
			local delay = cc.DelayTime:create(1.0)
			local sequence = cc.Sequence:create(cc.CallFunc:create(countDown),delay)
			mapNode:runAction(cc.RepeatForever:create(sequence))
		end
	end
	
	setPkMap()

	self.playerScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Player_ScrollView"), "ccui.ScrollView")
	local function onUpdatePlayerList(EventCustom)
		self.playerList = wd.pkHandler:getPlayerList()
		if self.playerList ~= {} then
			self:showPlayerList()
		end
	end
		
	local listener = cc.EventListenerCustom:create("Update_PlayerList", onUpdatePlayerList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onBuyPKCount(EventCustom)
		if self.tipsLayer then
			wd.showRichTips(4,"购买成功")
			countLabel:setString(wd.GlobalData:getInstance():getRolePkNumber())
			local num = wd.GlobalData:getInstance():getRoleData():getRoleExtendData("buyed_pk_number")
			wd.GlobalData:getInstance():getRoleData():setRoleExtendData("buyed_pk_number",num + 1)
			self.tipsLayer = nil
		end
	end
	listener = cc.EventListenerCustom:create("Buy_PK_Count", onBuyPKCount)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);

	listener = cc.EventListenerCustom:create("exploration_change", setPkMap)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function updateExploration()
		local data = wd.GlobalData:getInstance():getMessage("Get_Item")
		local layerClass = require("src.game.package.ToolsGetLayer")
		local layer = layerClass.create()
		layer:createLayerMenu(data)
		layer:setRewardBtn(function()
			wd.showRichTips(4,"领取成功")
		end)
		self:addChild(layer)
	end
	listener = cc.EventListenerCustom:create("Update_Exploration", updateExploration)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	wd.pkHandler:requestPKPlayerList()
	
end

function PKMapLayer:showPlayerList()
	local number = wd.pkHandler:getPlayerListSize()

    local innerHeight = number*106
    local innerWidth = 304

    self.playerScroll:setInnerContainerSize(cc.size(innerWidth, innerHeight))
	
    self:dynamicLoading(self.playerScroll)

    local function scrollCallback(sender,eventType)
        self:dynamicLoading(sender)
    end

    self.playerScroll:addEventListener(scrollCallback)
end

function PKMapLayer:dynamicLoading(list)
	local count = 1-- 1
    local curCount = list:getChildrenCount()
    local layout = list:getInnerContainer()
    local y = layout:getPositionY()

    if curCount == 0 then
        count = 9 --  9 + 1
    end 

    local number = wd.pkHandler:getPlayerListSize()

    if curCount >= number then 
        return
    end

    local innerHeight = list:getInnerContainerSize().height
    local innerWidth = list:getInnerContainerSize().width

    local height = curCount*106

    if (height - y) < innerHeight + 106 then
        for i=curCount, curCount+count do
            local player = self.playerList[i+1]
            if player == nil then
                break
            end

            local btn = ccui.Button:create("arena_player_box.png", "arena_player_box.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setTag(i)
            btn:setPosition( (innerWidth - btn:getContentSize().width)/2, innerHeight - (i+1)*106)
            list:addChild(btn)

            local playerNode = tolua.cast(cc.CSLoader:createNode("ui/map/PkPlayerNode.csb"),"ccui.Widget")
            btn:addChild(playerNode,1)
            playerNode:setTag(i)
				
			local headButton = tolua.cast(playerNode:getChildByName("Head_Button"),"ccui.Button")
			headButton:removeFromParent()
			btn:addChild(headButton)
			headButton:setEnabled(true)
			headButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if player.id ~= wd.GlobalData:getInstance():getRoleId() then
							local layerClass = require("src.game.arena.PlayerLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(wd.PlayerType.ENEMY)
							self:addChild(layer)
							wd.TranscodingSend:getPlayerData(player.id)
						end
					end
				end
			)
			
            local image = tolua.cast(playerNode:getChildByName("Head_Sprite"), "cc.Sprite")
            image:setSpriteFrame(wd.getHeadImageName(player.occupation, player.sex))

            local job = tolua.cast(playerNode:getChildByName("Job_Title"), "cc.Sprite")
            job:setSpriteFrame(wd.getEquipTitleName(player.occupation))

            local nameLabel = tolua.cast(playerNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setString(player.name)
            
            local familyLabel = tolua.cast(playerNode:getChildByName("family_name"), "ccui.Text")
            familyLabel:setString(player.familyName)
            
			if player.pkValue >= 500 then
				nameLabel:setColor(cc.c3b(255,0,0))
			else
				nameLabel:setColor(cc.c3b(255,255,255))
			end

            local powerLabel = tolua.cast(playerNode:getChildByName("Power_Label"), "ccui.Text")
            powerLabel:setString(string.format("%d",player.power))

            local levelLabel = tolua.cast(playerNode:getChildByName("Level_Label"), "ccui.TextBMFont")
            levelLabel:setString(string.format("%d",player.level))
			
			
			local inProtectSprite = tolua.cast(playerNode:getChildByName("InProtect_Sprite"),"cc.Sprite")
			local protectFlag = false
			if player.isInProtect == 1 then
				protectFlag = true
			end
			inProtectSprite:setVisible(protectFlag)
			
			local atkButton = tolua.cast(playerNode:getChildByName("Attack_Button"),"ccui.Button")
			atkButton:removeFromParent()
			btn:addChild(atkButton)
			atkButton:setSwallowTouches(false)
			atkButton:setPressedActionEnabled(true)
			atkButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if not protectFlag then
							if wd.GlobalData:getInstance():getRolePkNumber() > 0 then
								wd.pkHandler:setFightPlayerId(player.id)
								self:getParent():setPKFight(true,player.name,player.level)
								self:clear()
							else
								wd.showRichTips(4,"PK次数不足")
							end
						else
							wd.showRichTips(4,"对方处于PK掉装保护中")
						end
					end
				end
			)
        end
    end
end

function PKMapLayer:showBattleLayer(mapId)
	self:getParent():showBattleLayer(mapId)
	self:clear()
end

return PKMapLayer