local PKMapTipLayer = class("PKMapTipLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PKMapTipLayer.create()
    local layer = PKMapTipLayer.new()
    return layer
end

function PKMapTipLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
end

function PKMapTipLayer:createLayerMenu(map)
    local node = tolua.cast(cc.CSLoader:createNode("ui/map/PKTipsLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	local titleSprite = tolua.cast(mainPanel:getChildByName("Title_Sprite"), "cc.Sprite")
	titleSprite:setSpriteFrame(string.format("maptitle_%d.png",map.id))
	
    local backBtn = tolua.cast(mainPanel:getChildByName("Close_Button"), "ccui.Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )
    
    local rewardView = tolua.cast(ccui.Helper:seekWidgetByName(node,"reward_view"), "ccui.ListView")
	require("src.game.package.SetupTools"):create(rewardView,map.reward)
	
	local levelLabel = tolua.cast(mainPanel:getChildByName("Level_Label"), "ccui.Text")
    levelLabel:setString(string.format("1.等级>=%d",map.level))
    local fightLabel = tolua.cast(mainPanel:getChildByName("Fight_Label"), "ccui.Text")
    fightLabel:setString(string.format("2.战斗力>=%d",map.fight))
    
    local gold = require("res.config.exploration_cost")
    local useGold = tolua.cast(mainPanel:getChildByName("use_gold"), "ccui.Text")
    useGold:setString(gold[1].cost)
    
    local checkBox1 = tolua.cast(mainPanel:getChildByName("CheckBox_1"), "ccui.CheckBox")
    local checkBox2 = tolua.cast(mainPanel:getChildByName("CheckBox_2"), "ccui.CheckBox")
    local checkBox3 = tolua.cast(mainPanel:getChildByName("CheckBox_3"), "ccui.CheckBox")

    local lastIndex = 1
    checkBox1:setTag(1)
    checkBox2:setTag(2)
    checkBox3:setTag(3)
    
    local function callBack(sender,eventType)
        tolua.cast(mainPanel:getChildByTag(lastIndex),"ccui.CheckBox"):setSelected(false)
        sender:setSelected(true)
        lastIndex = sender:getTag()
        useGold:setString(gold[lastIndex].cost)
    end  
    checkBox1:addEventListener(callBack)
    checkBox2:addEventListener(callBack)
    checkBox3:addEventListener(callBack)
 
	local enterBtn = tolua.cast(mainPanel:getChildByName("Enter_Button"), "ccui.Button")
    enterBtn:setPressedActionEnabled(true)
    enterBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if wd.GlobalData:getInstance():getRoleLevel() < map.level then
                    wd.showRichTips(4,"需要等级"..map.level.."或以上才能进入")
                elseif wd.GlobalData:getInstance():getRolePower() < map.fight then
                    wd.showRichTips(4,"需要"..map.fight.."战斗力或以上才能进入")
                else
                    if wd.GlobalData:getInstance():getRoleGem() < gold[lastIndex].cost then
                        -- wd.showRichTips(4,"元宝不足")
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                        self:removeFromParent()
                    else
                        local packge = NetPackage:create()
                        packge:add("role_id",wd.GlobalData:getInstance():getRoleData():getRoleId())
                        packge:add("map_id",map.id)
                        packge:add("type",lastIndex)
                        packge = packge:encode()
                        wd.TranscodingSend:luaSend(packge,ePCStartExploration)   
                        self:removeFromParent()
                    end    
                end

				-- self:getParent():showBattleLayer(map.id)
				
            end
        end
    )
	
end


return PKMapTipLayer