local MonthCardScene = class("MonthCardScene",function()
    return cc.Layer:create()
end)

function MonthCardScene.create()
    local layer = MonthCardScene.new()
    layer:createLayerMenu()
    return layer
end

function MonthCardScene:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.monthCartType = {
		[1] = 250,
		[2] = 500,
	}
end

function MonthCardScene:createLayerMenu()
	local node = tolua.cast(cc.CSLoader:createNode("ui/activity/MonthCardScene.csb"),"ccui.Widget")
    self:addChild(node)
    
    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
    
    self.node = node
    
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
    if not wd.GlobalData:getInstance():getMonthCardItem(0) then
        wd.TranscodingSend:getMonthCardAwardState()
    end
    self:updateScene()
    local listener = cc.EventListenerCustom:create("Get_MonthCard_Award_State", function()self:updateScene()end)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
    
    listener = cc.EventListenerCustom:create("Get_MonthCard_Award", function() wd.TranscodingSend:getMonthCardAwardState() end)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
    
end

function MonthCardScene:clear()
    self:removeFromParent()
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_MonthCard_Award_State")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_MonthCard_Award")
end

function MonthCardScene:updateScene()
    for i,v in ipairs(self.monthCartType) do
		local monthCardItem = wd.GlobalData:getInstance():getMonthCardItem(i-1)
		local monthCardNode = tolua.cast(self.node:getChildByName("Panel_Swallow"):getChildByName(string.format("MonthCard_%d",v)),"ccui.Widget")
		local buyBtn = tolua.cast(monthCardNode:getChildByName("Buy_Button"),"ccui.Button")
		buyBtn:setPressedActionEnabled(true)
		buyBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local item = wd.GlobalData:getInstance():getChargeXmlData("month_card",i-1)
					if item ~= nil then
						if not wd.SdkApi:isTencentSdk() then
							wd.GlobalData:getInstance():setChargeData(item)
							wd.TranscodingSend:createOrder(item:getChargeCode(),item:getMoney())
						else
							wd.GlobalData:getInstance():setChargeData(item)
							wd.TranscodingSend:tencentPay()
						end
					else
						wd.showRichTips(4,"充值数据有误")
					end
				    --[[local item = wd.GlobalData:getInstance():getChargeXmlData("month_card",i-1)
					local payDir = "http://wendingttlx.51vip.biz:"
					-- 购买 
					if item ~= nil then
						local role = wd.GlobalData:getInstance():getRoleData()
						local server = wd.GlobalData:getInstance():getGameServerForId(wd.GlobalData:getInstance():getAreaId())
						if server ~= nil and role ~= nil then
							local port = server:getPort()
							payDir = string.format("%s%d",payDir,port)
							print(payDir)
							wd.SdkApi:pay(item:getMoney(), server:getServerId(), server:getName(), role:getRoleId(), role:getName(), role:getLevel(),payDir, string.format("%d",item:getChargeCode()))
						end
					else
						wd.showRichTips(4,"充值数据有误")
					end--]]
				end
			end
		)
		
		local getBtn = tolua.cast(monthCardNode:getChildByName("Get_Button"),"ccui.Button")
		getBtn:setPressedActionEnabled(true)
		getBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					-- wd.activityHandler:requestGetMonthCardAward(v)
                    wd.TranscodingSend:getMonthCardAward(v)
				end
			end
		)
		
		local leftLabel = tolua.cast(monthCardNode:getChildByName("Left_Label"),"ccui.Text")
		local today = os.date("*t")	
		local secondOfToday = os.time({day=today.day, month=today.month,year=today.year, hour=0, minute=0, second=0})
		local buyTime = monthCardItem:getBuyTime()
		local leftTime = 30 - (secondOfToday-buyTime)/24/3600
		if leftTime < 0 then leftTime = 0 end
		leftLabel:setString(string.format("剩余天数：%d天",leftTime))
			
		local hadGetSprite = tolua.cast(monthCardNode:getChildByName("HadGet_Sprite"),"cc.Sprite")
		
		local hadBuyFlag = false
		local hadGetFlag = false
		if monthCardItem:getActivityState() == wd.awardState.CanGet or monthCardItem:getActivityState() == wd.awardState.HadGet then
			hadBuyFlag = true
			if monthCardItem:getActivityState() == wd.awardState.HadGet then
				hadGetFlag = true
			end
		end
		buyBtn:setVisible(not hadBuyFlag)
		getBtn:setVisible(hadBuyFlag)
        getBtn:setTouchEnabled(not hadGetFlag)
		leftLabel:setVisible(hadBuyFlag)
		hadGetSprite:setVisible(hadGetFlag)
	end	
    
end


return MonthCardScene