
local PackageToolsLayer = class("PackageToolsLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PackageToolsLayer.create()
    local layer = PackageToolsLayer.new()
    layer:createLayerMenu()
    return layer
end

function PackageToolsLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.toolsScroll = nil
end

function PackageToolsLayer:showToolsList()

    self.toolsScroll:removeAllChildren()
    
    local function attrCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then

            local layerClass = require("src.game.package.ToolsTipsLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(sender:getTag())
            self:addChild(layer)
        end
    end

    local number = wd.GlobalData:getInstance():getToolsItemCount()

    local innerHeight = math.floor((number+2)/3)*180
    local innerWidth = 1000

    self.toolsScroll:setInnerContainerSize(cc.size(innerWidth, innerHeight))

    innerHeight = self.toolsScroll:getInnerContainerSize().height

    local count = 0
    for i=0,number-1 do

        --local id = wd.GlobalData:getInstance():getToolsItemId(i)
        --local name = wd.GlobalData:getInstance():getToolsItemName(i)
        --local quantity = wd.GlobalData:getInstance():getToolsItemQuantity(i)
        local item = wd.GlobalData:getInstance():getToolsItem(i)
        if item:getDisplay() == 1 and item:getQuantity() > 0 then
            local btn = ccui.Button:create("package_subbox.png", "package_subbox.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setPosition( (innerWidth - btn:getContentSize().width)/2 * (count%3), innerHeight - 160 - math.floor(count/3)*180)
            btn:setTag(item:getToolsId())
            btn:addTouchEventListener(attrCallback)

            local equipNode = tolua.cast(cc.CSLoader:createNode("ui/package/ToolsNode.csb"),"ccui.Widget")
            btn:addChild(equipNode)

            local image = tolua.cast(equipNode:getChildByName("Tools_Sprite"), "cc.Sprite")
            image:setSpriteFrame(string.format("%d.png",item:getToolsId()))
            --image:setSpriteFrame(string.format("%d.png",id))
			if item:getQuality() == 5 then
				wd.itemEffect(image)
			end

            local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
            color:setSpriteFrame(string.format("%02d.png",item:getQuality()))

            local nameLabel = tolua.cast(equipNode:getChildByName("Name_Label"), "ccui.Text")
            --nameLabel:setString(name)
            nameLabel:setString(item:getName())
			nameLabel:setColor(wd.colorTable[item:getQuality()])
			
            local quantityLabel = tolua.cast(equipNode:getChildByName("Number_Label"), "ccui.Text")
            --quantityLabel:setString(string.format("数量：%d", quantity)) 
            quantityLabel:setString(string.format("数量：%d", item:getQuantity())) 

            self.toolsScroll:addChild(btn)

            count = count+1
        end
    end
end

function PackageToolsLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/PackageToolsScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Tools")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				--cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_Compound")
                self:removeFromParent()
            end
        end
    )
    
    local equipBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_Button"), "ccui.Button")
    equipBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Tools")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				--cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_Compound")
                local layerClass = require("src.game.package.PackageEquipLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
	
	local soulBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Button"), "ccui.Button")
    soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Tools")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
                local layerClass = require("src.game.package.PackageSoulLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
    self.toolsScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Tools_Scroll"), "ccui.ScrollView")
    self:showToolsList()
    
    local function updateCallback(EventCustom)
        self:showToolsList()
    end
    
    local listener = cc.EventListenerCustom:create("Update_Tools", updateCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	--[[local function onSoulCompound(EventCustom)
		wd.showRichTips(4,"合成成功")
	end
	
	local listener = cc.EventListenerCustom:create("Soul_Compound", onSoulCompound)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);--]]
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"合成成功，获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end


return PackageToolsLayer