local SetupTools = {}

function SetupTools:create(getList,getData)
    self.getList = getList
    self:parse(getData)
end

function SetupTools:parse(getData)
    local startIndex
    local lastIndex
    local type, id, count

    local i = 0

    if self.getList ~= nil then

        while(string.len(getData)>=5) do
            startIndex,lastIndex,type,id,count  = string.find(getData,"(%d+)#(%d+)|(%d+)")

            if type == nil or id == nil or count == nil then
                break
            end

            type = tonumber(type)
            id = tonumber(id)
            count = tonumber(count)
            if count > 0 then
                if type == wd.ItemType.Tools then
                    self:tools(id, count)
                elseif type == wd.ItemType.Equip then
                    self:equip(id, count)
                elseif type == wd.ItemType.EquipList then
                    self:equipList(id, count)
                elseif type == wd.ItemType.Special then
                    self:special(id, count)
				elseif type == wd.ItemType.Soul then
					self:soul(id,count)
                elseif type == wd.ItemType.ServerEquip then
					self:equip(id,count,true)
                end
                
                i = i + 1
            end
            getData = string.sub(getData,lastIndex+1,-1)
        end
    end
    
    local listSize = i*94 + (i-1)*19
    
    if listSize > self.getList:getContentSize().width then
        self.getList:setStartMargin(10)
    else
        self.getList:setStartMargin((self.getList:getContentSize().width-listSize)/2)
    end
end

function SetupTools:tools(toolsId, count)
    local btn = self:getTools(toolsId, count)
    if btn then
        self.getList:pushBackCustomItem(btn)
    end
end

function SetupTools:getTools(toolsId, count)
    local item = wd.GlobalData:getInstance():getToolsItemInXml(toolsId)

    if item == nil then
        return nil
    end

    local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
    btn:setAnchorPoint(cc.p(0,0))

    if self.getList then 
        btn:setSwallowTouches(false)
        btn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.package.ToolsTipsLayer")
                    local layer = layerClass.create()
                    layer:createLayerMenu(toolsId,true)
                    cc.Director:getInstance():getRunningScene():addChild(layer)
                end
            end
        )
    end


    local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
    btn:addChild(itemNode)

    local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",item:getToolsId()))
	if item:getQuality() == 5 then
		wd.itemEffect(image)
	end
    local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
    color:setSpriteFrame(string.format("%02d.png",item:getQuality()))

    local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(item:getName())

    local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
    quantityLabel:setString(string.format("%d", count))
    return btn
end

function SetupTools:equip(equipId, count, isServer)
    local btn = self:getEquip(equipId, count, isServer)
    if btn then
        self.getList:pushBackCustomItem(btn)
    end
end

function SetupTools:getEquip(equipId, count, isServer)
    local item
    if isServer then
        item = wd.GlobalData:getInstance():getEquipItemForId(equipId)
    else
        item = wd.GlobalData:getInstance():getEquipItemInXml(equipId)
    end
    
    if item == nil then
        return nil
    end

    local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
    btn:setAnchorPoint(cc.p(0,0))
    
    if self.getList then
        btn:setSwallowTouches(false)
        btn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.shop.ArtifactTipsLayer")
                    local layer = layerClass.create()
                    layer:createLayerMenu(item)
                    cc.Director:getInstance():getRunningScene():addChild(layer)
                end
            end
        )
    end  
                    
    local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
    btn:addChild(itemNode)

    local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))

    wd.equipEffect(item, image)

    local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
    color:setSpriteFrame(string.format("%02d.png",item:getColor()))

    local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(item:getName())

    local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
    quantityLabel:setString(string.format("%d", count))
    return btn
end

function SetupTools:equipList(equipList, count)

end



function SetupTools:special(specialId, count)
    local btn = self:getSpecial(specialId, count)
    if btn then
        self.getList:pushBackCustomItem(btn)
    end
end

function SetupTools:getSpecial(specialId, count)
    if specialId == wd.ItemId.Gem or specialId == wd.ItemId.Gold or specialId == wd.ItemId.ArtifactPoints  then
        local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
        btn:setAnchorPoint(cc.p(0,0))

        local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
        btn:addChild(itemNode)

        local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
        local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
        local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
        local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")

        if specialId == wd.ItemId.Gem then

            color:setSpriteFrame(string.format("%02d.png",5))

            nameLabel:setString("元宝")
            
        elseif specialId == wd.ItemId.Gold then

            color:setSpriteFrame(string.format("%02d.png",4))

            nameLabel:setString("金币")

        elseif specialId == wd.ItemId.ArtifactPoints then

            color:setSpriteFrame(string.format("%02d.png",3))

            nameLabel:setString("神器积分")

        end

        image:setSpriteFrame(string.format("%d.png",specialId))

        quantityLabel:setString(string.format("%d", count))
        
        
        
        
        return btn
    end
    return nil
end

function SetupTools:soul(soulId, count)
   local btn = self:getSoul(soulId, count)
   if btn then
       self.getList:pushBackCustomItem(btn)
   end
end

function SetupTools:getSoul(soulId, count)
    local soulItem = wd.soulHandler:getSoulInXmlForId(soulId)

    if soulItem == nil then
        return nil
    end
    
    local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
    btn:setAnchorPoint(cc.p(0,0))
    
    local soulNode = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulNode.csb"),"ccui.Widget")
    btn:addChild(soulNode)
    
	local soulBtn = tolua.cast(soulNode:getChildByName("Soul_Button"), "ccui.Button")
    if self.getList then
        soulBtn:setSwallowTouches(false)
        soulBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.soul.SoulTipsLayer")
                    local layer = layerClass.create()
                    layer:createLayerMenu(soulItem,0)
                    cc.Director:getInstance():getRunningScene():addChild(layer)
                end
            end
        )
    end
    
    local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
	image:setSpriteFrame(string.format("%d.png",soulItem.id))
	wd.soulEffect(soulItem.quality,image)
	
	local color = soulItem.grade
	local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
	colorSprite:setSpriteFrame(string.format("%02d.png",color))

	local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
	gradeLabel:setString(soulItem.grade)
	
	local nameLabel = tolua.cast(soulNode:getChildByName("Name_Label"), "ccui.Text")
	nameLabel:setColor(wd.colorType(color))
	
	if soulItem.soulGrade >0 then
		nameLabel:setString(string.format("%s+%d",soulItem.name, soulItem.soulGrade))
	else
		nameLabel:setString(soulItem.name)
	end
	local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
	local levelBox = tolua.cast(soulNode:getChildByName("Level_Box"), "cc.Sprite")
	levelLabel:setVisible(false)
	levelBox:setVisible(false)
    return btn
end

return SetupTools