local ToolsGetPreviewLayer = class("ToolsGetPreviewLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function ToolsGetPreviewLayer.create()
    local layer = ToolsGetPreviewLayer.new()
    return layer
end

function ToolsGetPreviewLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.getList = nil
end

function ToolsGetPreviewLayer:parse(toolsId)
    local item = wd.GlobalData:getInstance():getToolsItemInXml(toolsId)
    local getData = item:getContents()
    local startIndex
    local lastIndex
    local type, id, count
    local i = 0

    if item:getDetail() == 1 and self.getList ~= nil then
        
        while(getData:len()>=5) do
            startIndex,lastIndex,type,id,count  = string.find(getData,"(%d+)#(%d+)|(%d+)")
            
            if type == nil or id == nil or count == nil then
               break
            end
            
            type = tonumber(type)
            id = tonumber(id)
            count = tonumber(count)
            
            if type == wd.ItemType.Tools then
                self:tools(id, count)
            elseif type == wd.ItemType.Equip then
                self:equip(id, count)
            elseif type == wd.ItemType.EquipList then
                self:equipList(id, count)
            elseif type == wd.ItemType.Special then
                self:special(id, count)
            end
                    
            getData = string.sub(getData,lastIndex+1,-1)
            i = i + 1
        end
    end
    
    if i >= 5 then
        self.getList:setStartMargin(10)
    else
        --self.getList:getInnerContainerSize().height
        self.getList:setStartMargin((455-i*86-(i-1)*19)/2)
    end
end


function ToolsGetPreviewLayer:tools(toolsId, count)

    local item = wd.GlobalData:getInstance():getToolsItemInXml(toolsId)
    
    if item == nil then
        return
    end
    
    local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
    btn:setAnchorPoint(cc.p(0,0))
        
    local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
    btn:addChild(itemNode)
    
    local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",item:getToolsId()))
	if item:getQuality() == 5 then
		wd.itemEffect(image)
	end
    local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
    color:setSpriteFrame(string.format("%02d.png",item:getQuality()))

    local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(item:getName())

    local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
    quantityLabel:setString(string.format("%d", count))
    
    self.getList:pushBackCustomItem(btn)
end

function ToolsGetPreviewLayer:equip(equipId, count)
    local item = wd.GlobalData:getInstance():getEquipItemInXml(equipId)

    if item == nil then
        return
    end

    local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
    btn:setAnchorPoint(cc.p(0,0))

    local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
    btn:addChild(itemNode)

    local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",item:getEquipId()))
    
    wd.equipEffect(item, image)

    local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
    color:setSpriteFrame(string.format("%02d.png",5))

    local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(item:getName())

    local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
    quantityLabel:setString(string.format("%d", count))
    
    self.getList:pushBackCustomItem(btn)

end

function ToolsGetPreviewLayer:equipList(equipList, count)

end

function ToolsGetPreviewLayer:special(specialId, count)

    if specialId == wd.ItemId.Gem or specialId == wd.ItemId.Gold or specialId == wd.ItemId.ArtifactPoints then
    
        local btn = ccui.Button:create("item_button.png", "item_button.png", "", ccui.TextureResType.plistType)
        btn:setAnchorPoint(cc.p(0,0))
    
        local itemNode = tolua.cast(cc.CSLoader:createNode("ui/package/ItemNode.csb"),"ccui.Widget")
        btn:addChild(itemNode)

        local image = tolua.cast(itemNode:getChildByName("Item_Sprite"), "cc.Sprite")
        local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
        local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
        local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
       
        if specialId == wd.ItemId.Gem then
        
            color:setSpriteFrame(string.format("%02d.png",5))

            nameLabel:setString("元宝")
    
        elseif specialId == wd.ItemId.Gold then
                    
            color:setSpriteFrame(string.format("%02d.png",4))

            nameLabel:setString("金币")
            
        elseif specialId == wd.ItemId.ArtifactPoints then
                
            color:setSpriteFrame(string.format("%02d.png",3))

            nameLabel:setString("神器积分")
    
        end
        
        image:setSpriteFrame(string.format("%d.png",specialId))

        quantityLabel:setString(string.format("%d", count))
        
        self.getList:pushBackCustomItem(btn)
    end
    
end


function ToolsGetPreviewLayer:createLayerMenu(toolsId)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/ToolsGetLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )

    local closeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    closeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )

    closeBtn:setPressedActionEnabled(true)
    closeBtn:setVisible(true)

        
    local getList = tolua.cast(ccui.Helper:seekWidgetByName(node,"Get_ListView"), "ccui.ListView")
    self.getList = getList
    self:parse(toolsId)
end


return ToolsGetPreviewLayer