
local LevelRankingLayer = class("LevelRankingLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function LevelRankingLayer.create()
    local layer = LevelRankingLayer.new()
    layer:createLayerMenu()
    return layer
end

function LevelRankingLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.mainNode = nil
	self.selectTag = 1
    self.roleId = wd.GlobalData:getInstance():getRoleId()
    
    self.rankingList = nil
end

function LevelRankingLayer:showSelfSprite()
    local gladiator = wd.GlobalData:getInstance():getRoleData()

    local playerPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Panel_Player"), "ccui.Widget")

    local playerSprite = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Player_Sprite"), "cc.Sprite")
    playerSprite:setSpriteFrame(wd.getPlayerImageName(gladiator:getOccupation(), gladiator:getSex()))
    playerSprite:setVisible(true)
    if gladiator:getSex() == 1 then
        playerSprite:setFlippedX(true)
    else
        playerSprite:setFlippedX(false)
    end
    
    local playerBtn = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Player_Button"), "ccui.Button")
    playerBtn:setEnabled(true)
    playerBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.PlayerLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(wd.PlayerType.SELF)
                self:addChild(layer)
            end
        end
    )

    local playerNode = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Player_Node"), "cc.Node")
    playerNode:setVisible(true)

    local nameLabel = tolua.cast(playerNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(gladiator:getName())

    local levelLabel = tolua.cast(playerNode:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setString(string.format("Lv%d", gladiator:getLevel()))

    local powerLabel = tolua.cast(playerNode:getChildByName("Power_Label"), "ccui.TextBMFont")
    powerLabel:setString(string.format("%d",gladiator:getPower()))

end

function LevelRankingLayer:showEnemySprite(tag)

    local gladiator = wd.GlobalData:getInstance():getGladiatorData(tag)

    self.ranking = gladiator:getRanking()

    local playerPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Panel_Player"), "ccui.Widget")

    local enemySprite = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Enemy_Sprite"), "cc.Sprite")
    enemySprite:setSpriteFrame(wd.getPlayerImageName(gladiator:getOccupation(), gladiator:getSex()))
    enemySprite:setVisible(true)
    if gladiator:getSex() == 0 then
        enemySprite:setFlippedX(true)
    else
        enemySprite:setFlippedX(false)
    end
    
    local enemyBtn = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Enemy_Button"), "ccui.Button")
    enemyBtn:setEnabled(true)
    enemyBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.PlayerLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(wd.PlayerType.ENEMY)
                self:addChild(layer)
                wd.TranscodingSend:getPlayerData(gladiator:getRoleId())
            end
        end
    )

    local enemyNode = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Enemy_Node"), "cc.Node")
    enemyNode:setVisible(true)

    local nameLabel = tolua.cast(enemyNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(gladiator:getName())

    local levelLabel = tolua.cast(enemyNode:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setString(string.format("Lv%d", gladiator:getLevel()))

    local powerLabel = tolua.cast(enemyNode:getChildByName("Power_Label"), "ccui.TextBMFont")
    powerLabel:setString(string.format("%d",gladiator:getPower()))

end


function LevelRankingLayer:dynamicLoading(rankingList)

    local count = 1-- 1
    local curCount = rankingList:getChildrenCount()
    local layout = rankingList:getInnerContainer()
    local y = layout:getPositionY()
    
    if curCount == 0 then
        count = 9 --  9 + 1
    end 
    
    local number = wd.GlobalData:getInstance():getGladiatorCount()

    if curCount >= number then 
        return
    end

    local innerHeight = rankingList:getInnerContainerSize().height
    local innerWidth = rankingList:getInnerContainerSize().width

    local height = curCount*106
    
    if (height - y) < innerHeight + 106 then

        local function attrCallback(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:showEnemySprite(sender:getTag())
    			wd.setSelectBox(rankingList,self.selectTag,sender:getTag())
                self.selectTag = sender:getTag()
            end
        end
        
        for i=curCount, curCount+count do
            local ranking = i+1

            if ranking > wd.RANKINGMAX then
                break
            end
            
            local gladiator = wd.GlobalData:getInstance():getGladiatorData(i)
            
            if gladiator == nil then
                break
            end
    
            local btn = ccui.Button:create("arena_player_box.png", "arena_player_box.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setTag(i)
            btn:setPosition( (innerWidth - btn:getContentSize().width)/2, innerHeight - (i+1)*106)
            btn:addTouchEventListener(attrCallback)
            rankingList:addChild(btn)
    
            local gladiatorNode = tolua.cast(cc.CSLoader:createNode("ui/ranking/LevelRankingNode.csb"),"ccui.Widget")
            btn:addChild(gladiatorNode)
    		gladiatorNode:setTag(i)
    		
            local image = tolua.cast(gladiatorNode:getChildByName("Head_Sprite"), "cc.Sprite")
            image:setSpriteFrame(wd.getHeadImageName(gladiator:getOccupation(), gladiator:getSex()))
    
            local job = tolua.cast(gladiatorNode:getChildByName("Job_Title"), "cc.Sprite")
            job:setSpriteFrame(wd.getEquipTitleName(gladiator:getOccupation()))
    
            local nameLabel = tolua.cast(gladiatorNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setString(gladiator:getName())
    
            local expLabel = tolua.cast(gladiatorNode:getChildByName("Exp_Label"), "ccui.Text")
            expLabel:setString(string.format("%d",gladiator:getExp()))
    
            local levelLabel = tolua.cast(gladiatorNode:getChildByName("Level_Label"), "ccui.Text")
            levelLabel:setString(string.format("%d",gladiator:getLevel()))
    
            local rankingLabel = tolua.cast(gladiatorNode:getChildByName("Number_Label"), "ccui.TextAtlas")
            --rankingLabel:setString(string.format("%d",gladiator:getRanking()))
            rankingLabel:setString(string.format("%d",i+1))
    
            if ranking > 0 and ranking <= 3 then
                local rankingSprite = tolua.cast(gladiatorNode:getChildByName("Ranking_Sprite"), "cc.Sprite")
                rankingSprite:setVisible(true)
                rankingSprite:setSpriteFrame(string.format("main_ranking_No%d.png",ranking))
            end            
        end
    end
end

function LevelRankingLayer:showRankingList()

    local rankingLabel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Ranking_Label"), "ccui.Text")

    local number = wd.GlobalData:getInstance():getGladiatorCount()

    if number > wd.RANKINGMAX then
        number = wd.RANKINGMAX
    end

    local roleRanking = 0
    for i=0,number-1 do
        local ranking = i+1

        local gladiator = wd.GlobalData:getInstance():getGladiatorData(i)
        if gladiator~= nil then
            if self.roleId == gladiator:getRoleId() then
                roleRanking = ranking
                break;
            end
        end
    end

    if roleRanking > 0 then
        rankingLabel:setString(string.format("%d",roleRanking))
    else 
        rankingLabel:setString("未上榜")
    end

    local innerHeight = number*106
    local innerWidth = 304

    self.rankingList:setInnerContainerSize(cc.size(innerWidth, innerHeight))

    self:dynamicLoading(self.rankingList)

    local function scrollCallback(sender,eventType)
        self:dynamicLoading(sender)
    end

    self.rankingList:addEventListener(scrollCallback)

end



function LevelRankingLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/ranking/LevelRankingScene.csb"), "ccui.Widget")
    self:addChild(node)

    self.mainNode = node

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Ranking_List")
                self:removeFromParent()
            end
        end
    )
    
    local powerBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Power_Button"), "ccui.Button")
    powerBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Ranking_List")
                local layerClass = require("src.game.ranking.PowerRankingLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )

    local arenaBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Ranking_Button"), "ccui.Button")
    arenaBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Ranking_List")
                local layerClass = require("src.game.ranking.ArenaRankingLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )

    local rankingList = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Ranking_Scroll"), "ccui.ScrollView")
    self.rankingList = rankingList

    self:showSelfSprite()

    local function rankingListCallback(EventCustom)
        self:showRankingList()
    end

    local listener = cc.EventListenerCustom:create("Ranking_List", rankingListCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);

    wd.TranscodingSend:getRankingList(1)

end


return LevelRankingLayer