local HelpLayer = class("HelpLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function HelpLayer.create(showType,tag)
    local layer = HelpLayer.new()
	layer:createLayerMenu(showType,tag)
    return layer
end

function HelpLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.titleFontSize = 35
	self.fontSize = 25
	self.gap = 25
end

function HelpLayer:createLayerMenu(showType,tag)
    local node = tolua.cast(cc.CSLoader:createNode("ui/setting/HelpScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
   
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	local contentScrollView = tolua.cast(mainPanel:getChildByName("Content_ScrollView"), "ccui.ScrollView")
	contentScrollView:removeAllChildren()
	if showType == wd.helpType.Sub then
		if tag then
			local config = wd.GlobalData:getInstance():getHelpSubConfig(tag)
			if config then
				local size = config:getContentListSize()
				contentScrollView:setInnerContainerSize(cc.size(contentScrollView:getContentSize().width,self.fontSize*size))
				local lastHeight,lastPosY,lastPosX
				for i = 0,size-1 do
					local str = config:getContentStrByTag(i)
					local label = cc.Label:create()
					label:setSystemFontSize(self.fontSize)
					label:setWidth(contentScrollView:getContentSize().width)
					label:setString(str)
					label:setAnchorPoint(cc.p(0,1))
					contentScrollView:addChild(label)
					if i == 0 then
						label:setPosition(cc.p(5,contentScrollView:getInnerContainerSize().height - self.gap))
					else
						label:setPosition(cc.p(5,lastPosY-lastHeight-self.gap))
					end
					lastPosX,lastPosY = label:getPosition()
					lastHeight = label:getContentSize().height
				end
				contentScrollView:jumpToTop()
			end
		end
	elseif showType == wd.helpType.Total then
		
		local listSize = wd.GlobalData:getInstance():getHelpConfigTotalListSize()
		local lastHeight,lastPosY,lastPosX
		local totalHeight = 0
		local layer = ccui.Widget:create()
		for j = 0,listSize -1 do
			local config = wd.GlobalData:getInstance():getHelpTotalConfig(j)
			if config then
				local size = config:getContentListSize()
				local title = cc.Label:create()
				title:setSystemFontSize(self.titleFontSize)
				title:setTextColor(cc.c4b(0,255,0,255))
				title:setWidth(contentScrollView:getContentSize().width)
				title:setString(config:getName())
				title:setAnchorPoint(cc.p(0,1))
				layer:addChild(title)
				if j == 1 then
					title:setPosition(cc.p(5,0))
				elseif j > 1 then
					title:setPosition(cc.p(5,lastPosY-lastHeight-self.gap))
				end
				totalHeight = totalHeight + self.titleFontSize + self.gap
				for i = 0,size-1 do
					local str = config:getContentStrByTag(i)
					local label = cc.Label:create()
					label:setSystemFontSize(self.fontSize)
					label:setWidth(contentScrollView:getContentSize().width)
					label:setString(str)
					label:setAnchorPoint(cc.p(0,1))
					layer:addChild(label)
					if i == 0 then
						lastPosX,lastPosY = title:getPosition()
						label:setPosition(cc.p(5,lastPosY - self.titleFontSize - self.gap))
					else
						label:setPosition(cc.p(5,lastPosY-lastHeight-self.gap))
					end
					lastPosX,lastPosY = label:getPosition()
					lastHeight = label:getContentSize().height
					totalHeight = totalHeight + lastHeight + self.gap
				end
			end
		end
		--totalHeight = totalHeight + 250
		contentScrollView:setInnerContainerSize(cc.size(contentScrollView:getContentSize().width,totalHeight))
		contentScrollView:addChild(layer)
		layer:setPosition(0,contentScrollView:getInnerContainerSize().height - self.gap)
		contentScrollView:jumpToTop()
	end
end


return HelpLayer