
local ShopArtifactLayer = class("ShopArtifactLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function ShopArtifactLayer.create()
    local layer = ShopArtifactLayer.new()
    layer:createLayerMenu()
    return layer
end

function ShopArtifactLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.itemNodeList = {}
	self.itemNodeSize = cc.size(770,128)
	self.gap = 30
	self.leftNodePosX = 44
	self.rightNodePosX = 44+314+54
	self.tickSchedule = nil
	self.dataHandler = wd.shopHandler
end

function ShopArtifactLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Refresh_Artifact")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_Equipment")
	if self.tickSchedule ~= nil then
		cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickSchedule)
		self.tickSchedule = nil
	end
	self:removeFromParent()
end

function ShopArtifactLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/shop/ShopArtifactScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
	ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
                self:clear()
            end
        end
    )

    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget")
    --mainPanel:setContentSize(cc.size(self.visibleSize.width, self.visibleSize.height - 88))

   
	
    local itemBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Item_Button"), "ccui.Button")
    itemBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
                local layerClass = require("src.game.shop.ShopItemLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:clear()
            end
        end
    )
	
	local refreshBtn = tolua.cast(mainPanel:getChildByName("Refresh_Button"), "ccui.Button")
    refreshBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.tips.TipsBoxLayer")
                local msgTable = {}
                local msg = {}
                local role = wd.GlobalData:getInstance():getRoleData()
                if role:getLeftEqShop() > 0  then
                    table.insert(msg,"是否花")
                    table.insert(msg,string.format("{y=[%d元宝]}",20))
                    table.insert(msg,"立刻刷新神器库？")
                    table.insert(msgTable,msg)
                    msg = {}
                    table.insert(msg,"当前")
                    table.insert(msg,string.format("{y=[Vip%d]}",role:getVip()))
                    table.insert(msg,"还可刷新")
                    table.insert(msg,string.format("{g=[%d次]}",role:getLeftEqShop()))

                else
                    table.insert(msg,"已达刷新次数上限")
                    if role:getVip() < wd.GlobalData:getInstance():getVipXmlCount()-1 then
                        table.insert(msg,",升级Vip可提升上限")
                    end
                end
                table.insert(msgTable,msg)

                local function sureCallback()
                    if wd.GlobalData:getInstance():getRoleGem() >= 20 then
                        self.dataHandler:requestRefreshArtifactList()
                    else
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                        self:removeFromParent()
                    end
                end
                self.tipsLayer = layerClass.create("shop_refresh_title.png", msgTable,sureCallback)
                self:addChild(self.tipsLayer)
            end
        end
    )
	
	local pointsLabel = tolua.cast(mainPanel:getChildByName("Number_Label"), "ccui.Text")
	pointsLabel:setString(wd.GlobalData:getInstance():getRoleArtifactPoints())
	
	local artifactScroll = tolua.cast(mainPanel:getChildByName("Artifact_Scroll"), "ccui.ScrollView")
	
	local tickTitle = tolua.cast(mainPanel:getChildByName("Time_Title"), "ccui.Text")
	local tickLabel = tolua.cast(mainPanel:getChildByName("Time_Label"), "ccui.Text")
	
	local curH,curM,curS = tonumber(os.date("%H")),tonumber(os.date("%M")),tonumber(os.date("%S"))
	local diffTime = 0
	local function campareTime()
		local nextHour = 12
		if curH >= 12 then
			nextHour = 18
			if curH >= 18 then
				nextHour = 24
			end
		end
		diffTime = nextHour*3600 - curH*3600-curM*60-curS
	end
	campareTime()
	
	local function setTime()
		local h = math.floor(diffTime/3600)
		local m = math.floor(math.abs(diffTime-3600*h)/60)
		local s = math.abs(diffTime-h*3600-m*60)
		tickLabel:setString(string.format("%02d:%02d:%02d",h,m,s))
	end
	setTime()
	local function timeTick()
		if diffTime == 0 then
			campareTime()
		else
			setTime()
			diffTime = diffTime - 1
		end
	end
	self.tickSchedule = cc.Director:getInstance():getScheduler():scheduleScriptFunc(timeTick, 1, false)
	
    local vipData = require("res.config.dict_shenqi")
	
	local function updateScroll()
		artifactScroll:removeAllChildren()
        local width = artifactScroll:getContentSize().width 
		local artifactCount = self.dataHandler:getShowArtifactCount()
		if artifactCount > 0 then
			
			local nodeCount = math.ceil(artifactCount/3)

			self.containerSize = cc.size(self.itemNodeSize.width,(self.itemNodeSize.height+self.gap*2)*nodeCount - self.gap)
			artifactScroll:setInnerContainerSize(self.containerSize)
			--[[for i = 1,nodeCount do
				local node = cc.Node:create()
				node:setContentSize(self.itemNodeSize)
				artifactScroll:addChild(node)
				--node:setPosition(0,self.gap+(nodeCount-i)*(self.itemNodeSize.height+self.gap))
				node:setPosition(0,artifactScroll:getInnerContainerSize().height - self.gap - i*(self.itemNodeSize.height+self.gap))
				self.itemNodeList[i] = node
			end--]]
			
			for i = 0,artifactCount-1 do
				
                local artifact = wd.GlobalData:getInstance():getArtifact(i)
				-- local showArtifactId = self.dataHandler:getShowArtifactId(i)
				-- local artifact = self.dataHandler:getArtifactById(showArtifactId)
				local price = artifact:getPrice()
                local priceType = artifact:getPriceType()
                local status = artifact:getArtifactStatus()
                local discount = artifact:getDiscount() / 1000
				local item = wd.GlobalData:getInstance():getEquipItemInXml(artifact:getArtifactId())
				
				if item then
					local function mallBtn(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
                            local layerClass = require("src.game.shop.ExchangeArtifactLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(artifact)
							self:addChild(layer)
						end
					end
					local btn = ccui.Button:create("package_subbox.png", "package_subbox.png", "", ccui.TextureResType.plistType)
					btn:setTag(i)
					btn:setAnchorPoint(cc.p(0,0))
                    local equipNode = tolua.cast(cc.CSLoader:createNode("ui/shop/MallItemNode.csb"),"ccui.Widget")
                    btn:addChild(equipNode)
                    
                    if wd.GlobalData:getInstance():getRoleVip() < vipData[i+1].vip then
                        local str = "VIP"..vipData[i+1].vip.."开启"
                        btn:addTouchEventListener(function(sender,eventType) 
                            if eventType == ccui.TouchEventType.ended then
                                wd.showRichTips(4,str) 
                            end
                        end)
                        local lockSprite = tolua.cast(equipNode:getChildByName("Lock_Sprite"), "cc.Sprite")
                        local openLabel = tolua.cast(lockSprite:getChildByName("Open_Label"), "ccui.Text")
                        lockSprite:setVisible(true)
                        openLabel:setString(str)
                    else
                        if status == 1 then
                            tolua.cast(equipNode:getChildByName("hadBuy"), "cc.Sprite"):setVisible(true)
                            btn:addTouchEventListener(function(sender,eventType) 
                                if eventType == ccui.TouchEventType.ended then
                                    wd.showRichTips(4,"该装备已购买") 
                                end
                            end)   
                        else
                            btn:addTouchEventListener(mallBtn)
                        end

                        local image = tolua.cast(equipNode:getChildByName("Tools_Sprite"), "cc.Sprite")
                        image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
                        wd.equipEffect(item, image)
                        
                        local colorNum = 5
                        
                        if item:getEquipId() > 1000 then
                            colorNum = 6
                        end
                        
                        local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
                        color:setSpriteFrame(string.format("%02d.png",colorNum))
                        
                        local title = tolua.cast(equipNode:getChildByName("Job_Title"), "cc.Sprite")
                        if item:getOccupation() <= 0 then
                            title:setVisible(false)
                        else
                            title:setVisible(true)
                            title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
                        end
                        
                        local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
                        local levelBox = tolua.cast(equipNode:getChildByName("Level_Box"), "cc.Sprite")
                        levelLabel:setString(string.format("Lv%d",item:getLevel()))
                        levelLabel:setVisible(true)
                        levelBox:setVisible(true)
                        
                        local nameLabel = tolua.cast(equipNode:getChildByName("Name_Label"), "ccui.Text")
                        nameLabel:setColor(wd.colorType(colorNum))
                        if item:getStrengthenLevel() >0 then
                            nameLabel:setString(string.format("%s+%d",item:getName(), item:getStrengthenLevel()))
                        else
                            nameLabel:setString(item:getName())
                        end
                        
                        local priceLabel = tolua.cast(equipNode:getChildByName("Number_Label"), "ccui.Text")
                        priceLabel:setString(string.format("%d",price))
                        
                        --修改货币图标
                        if priceType == 8 then --1是元宝，8是神点
                            local priceSprite = tolua.cast(equipNode:getChildByName("Price_Sprite"), "cc.Sprite")
                            priceSprite:setSpriteFrame("shop_artifact_points.png")
                        end
                        
                        local iconBtn = tolua.cast(equipNode:getChildByName("Item_Button"), "ccui.Button")
                        iconBtn:addTouchEventListener(
                            function(sender,eventType)
                                if eventType == ccui.TouchEventType.ended then
                                    local layerClass = require("src.game.shop.ArtifactTipsLayer")
                                    local layer = layerClass.create()
                                    layer:createLayerMenu(item,colorNum)
                                    self:addChild(layer)
                                end
                            end
                        )
                        
                        if discount < 10 then
                            local discountSprite = tolua.cast(equipNode:getChildByName("discount"), "cc.Sprite")
                            discountSprite:setVisible(true)
                            discountSprite:setSpriteFrame("ui/commonality/"..discount..".png")
                        end
                        
                    end

					artifactScroll:addChild(btn)
                    
                    btn:setPosition(width/3*(i%3) + (width/3 - btn:getContentSize().width)/2,artifactScroll:getInnerContainerSize().height - math.floor(i/3+1)*(self.itemNodeSize.height + self.gap) - math.floor(i/3)*self.gap)
		
				end
			end
		end
		artifactScroll:jumpToTop()
	end
	updateScroll()
	
	local function refreshArtifactCallBack()
		-- self.dataHandler:setArtifactShowList()
		updateScroll()
		wd.showRichTips(4,"刷新成功")
	end
	local listenerRefresh = cc.EventListenerCustom:create("Refresh_Artifact", refreshArtifactCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerRefresh, 1)
	
	local function buyEquip()
		-- self.dataHandler:setArtifactShowList()
		updateScroll()
		pointsLabel:setString(wd.GlobalData:getInstance():getRoleArtifactPoints())
		--wd.showSystemTips("兑换成功")
	end
	local listenerbuyEquip = cc.EventListenerCustom:create("Buy_Equipment", buyEquip)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerbuyEquip, 1)
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"兑换成功，获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		wd.showRichTips(wd.tipsType.Buy,msg)
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

return ShopArtifactLayer