
local SkillSettingsLayer = class("SkillSettingsLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SkillSettingsLayer.create()
    local layer = SkillSettingsLayer.new()
    layer:createLayerMenu()
    return layer
end

function SkillSettingsLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.dataHandler = wd.skillHandler
	self.skillIconList = {}
	self.skillNameList = {}
	self.skillOrderList = {}
	local orderList = self.dataHandler:getSkillOrderList()
	for i,v in ipairs(orderList) do
		self.skillOrderList[i] = v
	end
end

function SkillSettingsLayer:clear()
	self.dataHandler = nil
	self.skillIconList = {}
	self.skillNameList = {}
	self.skillOrderList = {}
end

function SkillSettingsLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/skill/SkillSettingsScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
	ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				self:clear()
                self:removeFromParent()
            end
        end
    )

    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Box"), "ccui.Widget")
    --mainPanel:setContentSize(cc.size(self.visibleSize.width, self.visibleSize.height - 88))

    local skillPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Skill"), "ccui.Widget")

    local upgradeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Upgrade_Button"), "ccui.Button")
	
	for i = 0,3 do
		local sprite = tolua.cast(skillPanel:getChildByName(string.format("Skill%d_Sprite",i)), "cc.Sprite")
		--sprite:setVisible(false)
		table.insert(self.skillIconList,sprite)
		local label =  tolua.cast(ccui.Helper:seekWidgetByName(node,string.format("Name%d_Label",i)),"ccui.Text")
		table.insert(self.skillNameList,label)
		--label:setVisible(false)
	end
	
    upgradeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.skill.SkillLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
				self:clear()
                self:removeFromParent()
            end
        end
    )
	
	
	
	local function updateOrderView()
		for i = 1,4 do
			if self.skillOrderList[i] then
				self.skillIconList[i]:setVisible(true)
				self.skillIconList[i]:setSpriteFrame(string.format("%d.png",self.skillOrderList[i]:getIconId()))
				self.skillNameList[i]:setVisible(true)
				local nameString
				if self.skillOrderList[i]:getLevel() == 11 then
					nameString = self.skillOrderList[i]:getName()
				else
					nameString = string.format("%sLv%d",self.skillOrderList[i]:getName(),self.skillOrderList[i]:getLevel())
				end
				self.skillNameList[i]:setString(nameString)
			else
				self.skillIconList[i]:setVisible(false)
				self.skillNameList[i]:setVisible(false)
			end
		end
	end
	-- 技能列表
	local skillList = tolua.cast(ccui.Helper:seekWidgetByName(node,"Skill_List"), "ccui.ListView")
	
	-- 技能列表点击
	local function setSkillInfo(sender,eventType)
		if eventType == ccui.TouchEventType.ended then
			local selectSkill = self.dataHandler:getMySkillItemByTag(sender:getTag())
			
			if #self.skillOrderList>= 4 then
				return
			else
				for i,v in ipairs(self.skillOrderList) do
					if v == selectSkill.skillItem then
						return
					end
				end
			end
			table.insert(self.skillOrderList,selectSkill.skillItem)
			updateOrderView()
		end
	end
	
	local skillInfoList = self.dataHandler:getMySkillList()
	for i,v in ipairs(skillInfoList) do
		if v and v.isLearned and v.skillItem:getType() == 1 then  -- 已学的主动技
			local skillNode = tolua.cast(cc.CSLoader:createNode("ui/skill/SkillNode.csb"),"ccui.Widget")
			local btn = ccui.Button:create("smelting_item_box.png", "smelting_item_box.png", "", ccui.TextureResType.plistType)
			btn:setAnchorPoint(cc.p(0,0))
			btn:setTag(i)
			btn:addTouchEventListener(setSkillInfo)
			btn:addChild(skillNode)

			-- 技能icon
			local image = tolua.cast(skillNode:getChildByName("Skill_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",v.skillItem:getIconId()))
			
			-- 技能名字
			local nameLabel = tolua.cast(skillNode:getChildByName("Name_Label"), "ccui.Text")
			nameLabel:setString(v.skillItem:getName())
			
			-- 技能等级
			local levelLabel = tolua.cast(skillNode:getChildByName("Region_Label"), "ccui.Text")
			local levelString 
			if v.skillItem:getLevel() == 11 then
				levelString = string.format("神级 法力:%d",v.skillItem:getUse_energy())
			else
				levelString = string.format("等级: %d 法力:%d",v.skillItem:getLevel(),v.skillItem:getUse_energy())
			end
			levelLabel:setString(levelString)
			skillList:pushBackCustomItem(btn)
		end
	end
	
	
	
	-- 重置按钮
	local resetBtn = ccui.Helper:seekWidgetByName(node,"Reset_Button")
	resetBtn:setPressedActionEnabled(true)
	resetBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.skillOrderList = {}
				updateOrderView()
            end
        end
    )
	
	-- 确定按钮
	local enterBtn = ccui.Helper:seekWidgetByName(node,"Enter_Button")
	enterBtn:setPressedActionEnabled(true)
	enterBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                -- todo
				self.dataHandler:requestSetSkillOrderList(self.skillOrderList)
            end
        end
    )
	
	local function updataOrderList(event)
		local skillOrderList = self.dataHandler:getSkillOrderList()
		if skillOrderList then
			for i,v in ipairs(skillOrderList) do
				self.skillOrderList[i] = v
			end
			updateOrderView()
		end
	end
	
	local listener = cc.EventListenerCustom:create("Update_OrderList", updataOrderList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	updateOrderView()
    ccui.Helper:doLayout(node)
	
	
end


return SkillSettingsLayer