
local SoulSwallowLayer = class("SoulSwallowLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SoulSwallowLayer.create()
    local layer = SoulSwallowLayer.new()
    return layer
end

function SoulSwallowLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
end

function SoulSwallowLayer:createLayerMenu(soulItem)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulSwallowLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_LevelUp")
            end
        end
    )

	local swallowBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Swallow_Button"), "ccui.Widget")
    swallowBtn:setPressedActionEnabled(true)
    swallowBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestSoulLevelUp(soulItem.serverId,true)
            end
        end
    )
	
	local autoSwallowBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Auto_Swallow_Button"), "ccui.Widget")
    autoSwallowBtn:setPressedActionEnabled(true)
    autoSwallowBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestSoulLevelUp(soulItem.serverId,false)
            end
        end
    )
	local soulNode = tolua.cast(mainPanel:getChildByName("Soul_Node"),"ccui.Widget")
	local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
	image:setSpriteFrame(string.format("%d.png",soulItem.id))
	wd.soulEffect(soulItem.quality,image)
	
	local color = soulItem.grade
	local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
	colorSprite:setSpriteFrame(string.format("%02d.png",color))

	local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
	gradeLabel:setString(soulItem.grade)

	local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
	levelLabel:setString(string.format("Lv%d",soulItem.level))	
	
	local nameLabel = tolua.cast(mainPanel:getChildByName("Name_Label"),"ccui.Text")
	nameLabel:setString(soulItem.name)
	nameLabel:setColor(wd.colorType(color))
	
	local curLevelLabel = tolua.cast(mainPanel:getChildByName("Level_Label"),"ccui.Text")
	curLevelLabel:setString(string.format("当前等级：%d级",soulItem.level))
	
	local gradeLabel = tolua.cast(mainPanel:getChildByName("Grade_Label"),"ccui.Text")
	gradeLabel:setString(string.format("引魂等级：%d",soulItem.soulGrade))
	
	local attrLabel = tolua.cast(mainPanel:getChildByName("Attr_Label"),"ccui.Text")
	attrLabel:setString(string.format("+%d%%",wd.GlobalData:getInstance():getPropertyPercentByLevel(soulItem.level)/100))
	
	local numberLabel = tolua.cast(mainPanel:getChildByName("Number_Label"),"ccui.Text")
	numberLabel:setString(string.format("%d个",wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SoulBlood)))
	local expBar = tolua.cast(mainPanel:getChildByName("Exp_Bar"),"ccui.LoadingBar")
	local expLabel = tolua.cast(mainPanel:getChildByName("Exp_Label"),"ccui.Text")
	local curExp,needExp
	if soulItem.level < 60 then
		curExp= soulItem.exp
		needExp = wd.GlobalData:getInstance():getLevelUpExpByLevel(soulItem.level+1)
		expLabel:setString(string.format("%d/%d",curExp,needExp))
		expBar:setPercent(curExp/needExp*100)
	else
		expLabel:setString("已满级")
		expBar:setPercent(100)
	end
	self.oldLevel = soulItem.level
	self.oldExp = soulItem.exp
	
	local function updataSoul()
		local newSoul = wd.GlobalData:getInstance():getLevelUpSoul()
		if newSoul then
			if newSoul:getLevel() ~= soulItem.level then
				levelLabel:setString(string.format("Lv%d",newSoul:getLevel()))
				curLevelLabel:setString(string.format("当前等级：%d级",newSoul:getLevel()))
				attrLabel:setString(string.format("+%d%%",wd.GlobalData:getInstance():getPropertyPercentByLevel(newSoul:getLevel())/100))
			end
			local needExp = wd.GlobalData:getInstance():getLevelUpExpByLevel(newSoul:getLevel()+1)
			expLabel:setString(string.format("%d/%d",newSoul:getExp(),needExp))
			expBar:setPercent(newSoul:getExp()/needExp*100)
			numberLabel:setString(string.format("%d个",wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SoulBlood)))
			
			if newSoul:getLevel() ~= self.oldLevel then
				wd.showRichTips(4,"等级提升")
			else
				if newSoul:getExp()-self.oldExp >0 then
					wd.showRichTips(4,string.format("获得经验：%d",newSoul:getExp()-self.oldExp))
				end
			end
			self.oldLevel = newSoul:getLevel()
			self.oldExp = newSoul:getExp()
		end
	end
    
    local listener = cc.EventListenerCustom:create("Soul_LevelUp", updataSoul)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
end


return SoulSwallowLayer