
local SoulTipsLayer = class("SoulTipsLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SoulTipsLayer.create()
    local layer = SoulTipsLayer.new()
    return layer
end

function SoulTipsLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.fontSize = 20
	self.colorTable = {
		Blue = cc.c3b(99,159,232),
		Purple = cc.c3b(180,99,232),
		Red = cc.c3b(255,32,32),
		White = cc.c3b(255,255,255),
		Green = cc.c3b(0x22,0x68,0x00),
		Yellow = cc.c3b(255,243,113),
		Orange = cc.c3b(0x89,0x51,0x01),
	}
end

function SoulTipsLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_Resolve")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_Restart_Property")
	self:removeFromParent()
end
function SoulTipsLayer:wear(soulItem,region)
	wd.soulHandler:requestSoulWear(soulItem.serverId,region)
	wd.GlobalData:getInstance():wearSoulForId(region, soulItem.serverId)
	self:getParent():wear(soulItem.serverId)  -- RoleLayer
end

function SoulTipsLayer:unwear(soulItem,region)
	wd.soulHandler:requestSoulUnWear(soulItem.serverId)
	self:getParent():unwear(region)
end

function SoulTipsLayer:createLayerMenu(soulItem,isOn,region)   -- isOn  0 = preview, 1 = weard , 2 = not weard , 3 = package , 4= others
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulTipsLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
    
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:clear()
            end
        end
    )
    
    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
    local leftBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Left_Button") , "ccui.Widget")
    local rightBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Right_Button"), "ccui.Widget")
	local rightUpBtn = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Right_Up_Button"), "ccui.Widget")
	local leftTitle = tolua.cast(leftBtn:getChildByName("LeftBtn_Title"), "cc.Sprite")
    local rightTitle = tolua.cast(rightBtn:getChildByName("RightBtn_Title"), "cc.Sprite")
    local rightUpTitle = tolua.cast(rightUpBtn:getChildByName("RightBtn_Title"), "cc.Sprite")
    local closeBtn = ccui.Helper:seekWidgetByName(mainPanel,"Close_Button") 
    leftBtn:setPressedActionEnabled(true)
    rightBtn:setPressedActionEnabled(true)
	rightUpBtn:setPressedActionEnabled(true)
    closeBtn:setPressedActionEnabled(true)
	
	if isOn == 0 then	-- preview
        leftBtn:setVisible(false)
        rightBtn:setVisible(false)
        closeBtn:setVisible(true)
        closeBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    self:clear()
                end
            end
        )
    elseif isOn == 1 then -- weard
		rightUpBtn:setVisible(true)
        leftTitle:setSpriteFrame("soul_btnsprite_unwear.png")
        rightTitle:setSpriteFrame("soul_btnsprite_upgrade.png")
        leftBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
					self:unwear(soulItem,region)
                    self:clear()
                end
            end
        )
        rightBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.soul.SoulUpgradeLayer")
					local layer = layerClass.create()
					layer:createLayerMenu(soulItem)
					self:getParent():addChild(layer)
					self:clear()
                end
            end
        )
		rightUpBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.soul.SoulSwallowLayer")
					local layer = layerClass.create()
					layer:createLayerMenu(soulItem)
					self:getParent():addChild(layer)
					self:clear()
                end
            end
        )
    elseif isOn == 2 then	-- unwear
        rightUpBtn:setVisible(true)
        leftTitle:setSpriteFrame("equip_wear_title.png")
        rightTitle:setSpriteFrame("soul_btnsprite_upgrade.png")
        leftBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    self:wear(soulItem,region)
					self:clear()
                end
            end
        )
        rightBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.soul.SoulUpgradeLayer")
					local layer = layerClass.create()
					layer:createLayerMenu(soulItem)
					self:getParent():addChild(layer)
					self:clear()
                end
            end
        )
		rightUpBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.soul.SoulSwallowLayer")
					local layer = layerClass.create()
					layer:createLayerMenu(soulItem)
					self:getParent():addChild(layer)
					self:clear()
                end
            end
        )
        
    elseif isOn == 3 then	-- package
		leftTitle:setSpriteFrame("soul_btnsprite_rebuild.png")
        rightTitle:setSpriteFrame("soul_btnsprite_resolve.png")
        rightUpTitle:setSpriteFrame("soul_upgrade_btn_title.png")
        rightUpBtn:setVisible(true)
        leftBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
					local layerClass = require("src.tips.TipsBoxLayer")
					local msgTable = {}
					local msg = {}
					table.insert(msg,"是否花")
					table.insert(msg,string.format("{g=[%d元宝]}",50))
					table.insert(msg,"重铸天魂")
					table.insert(msgTable,msg)
					
					msg = {}
					table.insert(msg,"(重铸后返还80%魂魄精血) ")
					table.insert(msgTable,msg)
					local function onSoulRebuild()
                        if wd.GlobalData:getInstance():getRoleGem() < 50 then
                            local layerClass = require("src.game.charge.ChargeTipsScene")
                            local layer = layerClass:create()
                            self:getParent():addChild(layer)
                        else
                            wd.soulHandler:requestSoulRebuild(soulItem.serverId)
                        end
					end
					self.tipsLayer = layerClass.create("soul_btnsprite_rebuild_title.png", msgTable,onSoulRebuild)
					self:addChild(self.tipsLayer)
                end
            end
        )
        rightBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    wd.soulHandler:requestSoulResolve(soulItem.serverId)
                end
            end
        )
        rightUpBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local soulData = require("res.config.dict_soul")
                    if soulData[soulItem.id].next_id ~= 0 then
                        local layerClass = require("src.game.soul.SoulDegreeRaising")
                        local layer = layerClass.create()
                        layer:createLayerMenu(soulItem)
                        self:getParent():addChild(layer)
                        self:clear()
                    else
                        wd.showRichTips(wd.tipsType.System,"该天魂已是最高阶")
                    end
                end
            end
        )
	elseif isOn == 4 then -- others
        leftBtn:setVisible(false)
        rightBtn:setVisible(false)
        closeBtn:setVisible(true)
        closeBtn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    self:clear()
                end
            end
        )
		
	end
	local image = tolua.cast(mainPanel:getChildByName("Equip_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",soulItem.id))
    
    wd.soulEffect(soulItem.grade,image)
    
    local colorSprite = tolua.cast(mainPanel:getChildByName("Color_Sprite"), "cc.Sprite")
    colorSprite:setSpriteFrame(string.format("%02d.png",soulItem.grade))
    
    local levelLabel = tolua.cast(mainPanel:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setString(string.format("Lv%d",soulItem.level))
    
    local nameLabel = tolua.cast(mainPanel:getChildByName("EquipName_Label"), "ccui.Text")
    if soulItem.soulGrade >0 then
		nameLabel:setString(string.format("%s+%d",soulItem.name, soulItem.soulGrade))
	else
		nameLabel:setString(soulItem.name)
	end
    nameLabel:setColor(wd.colorType(soulItem.grade))
    
    local regionLabel = tolua.cast(mainPanel:getChildByName("Region_Label"), "ccui.Text")
    --regionLabel:setString(string.format("位置：%s",wd.getRegionString(item:getRegion())))
	
	local jobLabel = tolua.cast(mainPanel:getChildByName("Job_Label"), "ccui.Text")
    jobLabel:setString(string.format("阶位：%s阶",soulItem.grade))
    
    local gradeLabel = tolua.cast(mainPanel:getChildByName("Grade_Label"), "ccui.Text")
    gradeLabel:setString(soulItem.grade)
	
    local attrScroll = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Attr_Scroll"), "ccui.ScrollView")
    self.scrollSize = attrScroll:getContentSize()
    local attrLayer = self:createDataLayer(soulItem,isOn,region)
    attrScroll:setInnerContainerSize(cc.size(self.scrollSize.width,self.innerHeight))
    attrScroll:addChild(attrLayer)
	attrLayer:setPosition(0,attrScroll:getInnerContainerSize().height)
	
	local function onSoulResolve(EventCustom)
        wd.showRichTips(4,"分解成功")
		self:clear()
    end
	
    local listener = cc.EventListenerCustom:create("Soul_Resolve", onSoulResolve)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	local function onSoulRestartProperty(EventCustom)
        wd.showRichTips(4,"重铸成功")
		self:clear()
    end
	
    local listener = cc.EventListenerCustom:create("Soul_Restart_Property", onSoulRestartProperty)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function SoulTipsLayer:createDataLayer(soulItem,isOn,region)
	local layer = cc.Layer:create()
	local x = 0
	local y = -30
	local offset = -30
	
	-- 铭刻
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString(string.format("灵魂铭刻：铭刻%d%%装备属性",soulItem.propertyPercent/100))
	label:setColor(self.colorTable.Orange)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	
	
	-- 等级，经验
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString(string.format("当前等级：%d/%d  经验值：%d%%",soulItem.level,soulItem.levelLimit,math.floor(soulItem.exp/wd.GlobalData:getInstance():getLevelUpExpByLevel(soulItem.level+1))))
	label:setColor(self.colorTable.Green)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	
	-- 等级加成
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString(string.format("等级加成：铭刻属性+%d%%",wd.GlobalData:getInstance():getPropertyPercentByLevel(soulItem.level)/100))
	label:setColor(self.colorTable.Green)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	
	-- 引魂加成
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString(string.format("引魂加成：通灵属性+%d%%",wd.GlobalData:getInstance():getSoulGradePropertyPercent(soulItem.grade,soulItem.soulGrade)/100))
	label:setColor(self.colorTable.Red)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	
	-- 基本属性
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString("【铭刻属性】")
	label:setColor(self.colorTable.Orange)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	
	-- isOn 0 = preview  1 = weard   2 = not weard  3 = package  4 = others
	if isOn == 1 or isOn == 4 then
		if region then
			local item 
			if isOn == 1 then
				item = wd.GlobalData:getInstance():getWearEquip(region)
			else
				item = wd.GlobalData:getInstance():getOtherWearEquip(region)
			end
			if item == nil then
				local label = cc.Label:create()
				label:setSystemFontSize(self.fontSize)
				label:setWidth(self.scrollSize.width-5)
				label:setAnchorPoint(cc.p(0,0))
				label:setString("未装备")
				label:setColor(self.colorTable.White)
				layer:addChild(label)
				label:setPosition(x,y)
				y = y + offset
			else
				local percent = (soulItem.propertyPercent+wd.GlobalData:getInstance():getPropertyPercentByLevel(soulItem.level))/10000
				if item:getHp()~= 0 then
					local label = wdui.BattleLabel:create()
					label:setBaseAttrString("生命：", tostring(math.ceil(item:getHp()*percent)))
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getMp()~= 0 then
					local label = wdui.BattleLabel:create()
					label:setBaseAttrString("法力：", tostring(math.ceil(item:getMp()*percent)))
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getPAttackMax()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getPAttackMin()*percent),math.ceil(item:getPAttackMax()*percent))
					label:setBaseAttrString("物理攻击：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getMAttackMax()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getMAttackMin()*percent),math.ceil(item:getMAttackMax()*percent))
					label:setBaseAttrString("魔法攻击：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getTAttackMax()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getTAttackMin()*percent),math.ceil(item:getTAttackMax()*percent))
					label:setBaseAttrString("道术攻击：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getPDefenceMin()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getPDefenceMin()*percent),math.ceil(item:getPDefenceMax()*percent))
					label:setBaseAttrString("物理防御：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getMDefenceMin()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getMDefenceMin()*percent),math.ceil(item:getMDefenceMax()*percent))
					label:setBaseAttrString("魔法防御：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
				if item:getTDefenceMin()~= 0 then
					local label = wdui.BattleLabel:create()
					local valueStr = string.format("%d-%d",math.ceil(item:getTDefenceMin()*percent),math.ceil(item:getTDefenceMax()*percent))
					label:setBaseAttrString("道术防御：", valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				end
			end
		end
	else
		local label = cc.Label:create()
		label:setSystemFontSize(self.fontSize)
		label:setWidth(self.scrollSize.width-5)
		label:setAnchorPoint(cc.p(0,0))
		label:setString("未装备")
		label:setColor(self.colorTable.White)
		layer:addChild(label)
		label:setPosition(x,y)
		y = y + offset 
	end
	
	-- 定魂属性
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString("【定魂属性】")
	label:setColor(self.colorTable.Blue)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	if isOn == 0 then
		local label = cc.Label:create()
		label:setSystemFontSize(self.fontSize)
		label:setWidth(self.scrollSize.width-5)
		label:setAnchorPoint(cc.p(0,0))
		label:setString("未知")
		label:setColor(self.colorTable.White)
		layer:addChild(label)
		label:setPosition(x,y)
		y = y + offset 
	else
		for i,pro in ipairs(soulItem.randProList) do
			if pro.value ~= -1 then
				local label = wdui.BattleLabel:create()
				local valueStr 
				if pro.isPercent then
					pro.value = pro.value/100
					valueStr = string.format("+%s%%",tostring(pro.value))
				else
					valueStr = string.format("+%s",tostring(pro.value))
				end
				label:setBestAttrString(pro.key,valueStr)
				layer:addChild(label)
				label:setPosition(x,y)
				y = y + offset
			end
		end
	end
	
	
	-- 通灵属性
	local label = cc.Label:create()
	label:setSystemFontSize(self.fontSize)
	label:setWidth(self.scrollSize.width-5)
	label:setAnchorPoint(cc.p(0,0))
	label:setString("【通灵属性】")
	label:setColor(self.colorTable.Green)
	layer:addChild(label)
	label:setPosition(x,y)
	y = y + offset 
	if isOn == 0 then
		local label = cc.Label:create()
		label:setSystemFontSize(self.fontSize)
		label:setWidth(self.scrollSize.width-5)
		label:setAnchorPoint(cc.p(0,0))
		label:setString("未知")
		label:setColor(self.colorTable.White)
		layer:addChild(label)
		label:setPosition(x,y)
		y = y + offset 
	else
		for i,pro in ipairs(soulItem.basicProList) do
			if pro.value ~= -1 then
				if soulItem.level >= i*10 then
					local label = wdui.BattleLabel:create()
					local valueStr 
					if pro.isPercent then
						pro.value = pro.value/100
						valueStr = string.format("+%s%%",tostring(pro.value))
					else
						valueStr = string.format("+%s",tostring(pro.value))
					end
					if wd.GlobalData:getInstance():getSoulGradePropertyPercent(soulItem.grade,soulItem.soulGrade)/10000 > 0 then
						local plusStr = string.format("(+%s%%)",tostring(pro.value*wd.GlobalData:getInstance():getSoulGradePropertyPercent(soulItem.grade,soulItem.soulGrade)/10000))
						valueStr = valueStr..plusStr
					end
					label:setBestAttrString(pro.key,valueStr)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset
				else
					local label = cc.Label:create()
					label:setSystemFontSize(self.fontSize)
					label:setWidth(self.scrollSize.width-5)
					label:setAnchorPoint(cc.p(0,0))
					label:setString(string.format("未领悟(lv.%d领悟)",i*10))
					label:setColor(self.colorTable.White)
					layer:addChild(label)
					label:setPosition(x,y)
					y = y + offset 
				end
			end
		end
	end
	
	self.innerHeight = -y
	return layer
end

return SoulTipsLayer