
local SoulUpgradeLayer = class("SoulUpgradeLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SoulUpgradeLayer.create()
    local layer = SoulUpgradeLayer.new()
    return layer
end

function SoulUpgradeLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
end

function SoulUpgradeLayer:createLayerMenu(soulItem)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulUpgradeLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if self.sequenceAction then
					self.sequenceAction:release()
					self.sequenceAction = nil
				end
                self:removeFromParent()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Soul_Upgrade")
            end
        end
    )

	-- before
	local beforeBox = tolua.cast(mainPanel:getChildByName("Before_Box"),"ccui.Widget")
	local beforeSoul = tolua.cast(beforeBox:getChildByName("Before_Soul"),"cc.Sprite")
	local soulNode = tolua.cast(beforeSoul:getChildByName("Soul_Node"),"ccui.Widget")
	local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
	image:setSpriteFrame(string.format("%d.png",soulItem.id))
	wd.soulEffect(soulItem.quality,image)
	local color = soulItem.grade
	local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
	colorSprite:setSpriteFrame(string.format("%02d.png",color))

	local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
	gradeLabel:setString(soulItem.grade)

	local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
	levelLabel:setString(string.format("Lv%d",soulItem.level))

	local nameLabel = tolua.cast(beforeSoul:getChildByName("Name_Label"),"ccui.Text")
	nameLabel:setString(soulItem.name)
	nameLabel:setColor(wd.colorType(color))
	
	local beforeLevelLabel = tolua.cast(beforeSoul:getChildByName("Level_Label"),"ccui.Text")
	beforeLevelLabel:setString(string.format("引魂等级：+%d",soulItem.soulGrade))
	local beforeDescLabel = tolua.cast(beforeBox:getChildByName("Desc_Label"),"ccui.Text")
	beforeDescLabel:setString(string.format("通灵属性威力：%s%%",tostring(wd.GlobalData:getInstance():getSoulGradePropertyPercent(soulItem.grade,soulItem.soulGrade)/100)))
	
	
	-- after
	local afterBox = tolua.cast(mainPanel:getChildByName("After_Box"),"ccui.Widget")
	local afterSoul = tolua.cast(afterBox:getChildByName("After_Soul"),"cc.Sprite")
	local soulNode = tolua.cast(afterSoul:getChildByName("Soul_Node"),"ccui.Widget")
	local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
	image:setSpriteFrame(string.format("%d.png",soulItem.id))
	wd.soulEffect(soulItem.quality,image)
	local color = soulItem.grade
	local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
	colorSprite:setSpriteFrame(string.format("%02d.png",color))

	local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
	gradeLabel:setString(soulItem.grade)

	local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
	levelLabel:setString(string.format("Lv%d",soulItem.level))
	local nameLabel = tolua.cast(afterSoul:getChildByName("Name_Label"),"ccui.Text")
	nameLabel:setString(soulItem.name)
	nameLabel:setColor(wd.colorType(color))
	local afterLevelLabel = tolua.cast(afterSoul:getChildByName("Level_Label"),"ccui.Text")
	
	local afterDescLabel = tolua.cast(afterBox:getChildByName("Desc_Label"),"ccui.Text")
	
	if soulItem.soulGrade == 10 then
		afterLevelLabel:setString("已满级")
		afterDescLabel:setString("已满级")
	else
		afterLevelLabel:setString(string.format("引魂等级：+%d",soulItem.soulGrade+1))
		afterDescLabel:setString(string.format("通灵属性威力：%s%%",tostring(wd.GlobalData:getInstance():getSoulGradePropertyPercent(soulItem.grade,soulItem.soulGrade+1)/100)))
	end
	
	local upgradeEffect =  tolua.cast(mainPanel:getChildByName("Upgrade_Effect"),"cc.Sprite")
	local function playAnimation()
		if self.sequenceAction and (not self.sequenceAction:isDone()) then
			return
		end
		if not upgradeEffect then
			return
		end
		upgradeEffect:setVisible(true)
		local animation = cc.Animation:create()
		for i = 1, 5 do
			animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("soulUpgrade_%02d.png", i)))
		end

		animation:setDelayPerUnit(0.15)
		animation:setLoops(1)
		local action = cc.Animate:create(animation)
		
		local function delayCallBackFunc(sender)
			upgradeEffect:setVisible(false)
		end

		local delayCallBack = cc.CallFunc:create(delayCallBackFunc)
		self.sequenceAction = cc.Sequence:create(action, delayCallBack)
		self.sequenceAction:retain()
		upgradeEffect:runAction(self.sequenceAction)
	end
	
	--bottom
	local bottomPanel = tolua.cast(mainPanel:getChildByName("Panel_Under"),"ccui.Widget")
	
	-- soulBox
	local subSoulBox = tolua.cast(bottomPanel:getChildByName("Sub_Soul_Box"),"ccui.Widget")
	local soulStr = wd.GlobalData:getInstance():getSoulUpgradeNeedSoulNumber(soulItem.grade,soulItem.soulGrade)
	local s,e,subSoulId,needSoulCount 
	if soulStr ~= "" then
		s,e,subSoulId,needSoulCount = string.find(soulStr,"(%d+)|(%d+)")
		if subSoulId then
			subSoulId = tonumber(subSoulId)
		end
		if needSoulCount then
			needSoulCount = tonumber(needSoulCount)
		end
	end
	local subSoulItem = wd.GlobalData:getInstance():getToolsItemInXml(subSoulId)
	if subSoulItem then
		local image = tolua.cast(subSoulBox:getChildByName("Tools_Sprite"), "cc.Sprite")
		image:setSpriteFrame(string.format("%d.png",subSoulItem:getToolsId()))
		
		local color = subSoulItem:getQuality()
		local colorSprite = tolua.cast(subSoulBox:getChildByName("Color_Sprite"), "cc.Sprite")
		colorSprite:setSpriteFrame(string.format("%02d.png",color))
		
	end
	local soulCountLabel = tolua.cast(subSoulBox:getChildByName("Count_Label"), "ccui.Text")
	local currentCount = wd.GlobalData:getInstance():getToolsItemCountForId(subSoulItem:getToolsId())
	soulCountLabel:setString(string.format("%d/%d",currentCount,needSoulCount))
	
	-- drugBox
	local soulDrugBox = tolua.cast(bottomPanel:getChildByName("Soul_Drug_Box"),"ccui.Widget")
	local drugItem = wd.GlobalData:getInstance():getToolsItemInXml(wd.ItemId.SoulDrug)
	if drugItem then
		local image = tolua.cast(soulDrugBox:getChildByName("Tools_Sprite"), "cc.Sprite")
		image:setSpriteFrame(string.format("%d.png",drugItem:getToolsId()))
		
		local color = drugItem:getQuality()
		local colorSprite = tolua.cast(soulDrugBox:getChildByName("Color_Sprite"), "cc.Sprite")
		colorSprite:setSpriteFrame(string.format("%02d.png",color))
		
	end
	currentCount = wd.GlobalData:getInstance():getToolsItemCountForId(drugItem:getToolsId())
	local needDrugCount = wd.GlobalData:getInstance():getSoulUpgradeNeedItemNumber(soulItem.grade,soulItem.soulGrade)
	local drugCountLabel = tolua.cast(soulDrugBox:getChildByName("Count_Label"), "ccui.Text")
	drugCountLabel:setString(string.format("%d/%d",currentCount,needDrugCount))
	
	-- money
	local moneyLabel = tolua.cast(bottomPanel:getChildByName("Money_Label"),"ccui.Text")
	moneyLabel:setString(wd.GlobalData:getInstance():getSoulUpgradeNeedMoney(soulItem.grade,soulItem.soulGrade))
	
	
	local upgradeButton = tolua.cast(bottomPanel:getChildByName("Upgrade_Button"),"ccui.Button")
	upgradeButton:setPressedActionEnabled(true)
    upgradeButton:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestSoulUpgrade(soulItem.serverId)
            end
        end
    )
	
	
	local function updataSoul()
		if cc.UserDefault:getInstance():getBoolForKey("Sound") then
			cc.SimpleAudioEngine:getInstance():playEffect(cc.FileUtils:getInstance():fullPathForFilename("res/music/soulEffect.mp3"), false)
		end
		playAnimation()
		local newSoul = wd.GlobalData:getInstance():getUpgradeSoul()
		if newSoul then
			beforeLevelLabel:setString(string.format("引魂等级：+%d",newSoul:getSoulGrade()))
			beforeDescLabel:setString(string.format("通灵属性威力：%s%%",tostring(wd.GlobalData:getInstance():getSoulGradePropertyPercent(newSoul:getGrade(),newSoul:getSoulGrade())/100)))
			local soulStr = wd.GlobalData:getInstance():getSoulUpgradeNeedSoulNumber(newSoul:getGrade(),newSoul:getSoulGrade())
			local s,e,subSoulId,needSoulCount 
			if soulStr ~= "" then
				s,e,subSoulId,needSoulCount = string.find(soulStr,"(%d+)|(%d+)")
				if subSoulId then
					subSoulId = tonumber(subSoulId)
				end
				if needSoulCount then
					needSoulCount = tonumber(needSoulCount)
				end
			end
			soulCountLabel:setString(string.format("%d/%d",wd.GlobalData:getInstance():getToolsItemCountForId(subSoulItem:getToolsId()),needSoulCount))
			local needDrugCount = wd.GlobalData:getInstance():getSoulUpgradeNeedItemNumber(newSoul:getGrade(),newSoul:getSoulGrade())
			drugCountLabel:setString(string.format("%d/%d",wd.GlobalData:getInstance():getToolsItemCountForId(drugItem:getToolsId()),needDrugCount))
			moneyLabel:setString(wd.GlobalData:getInstance():getSoulUpgradeNeedMoney(soulItem.grade,soulItem.soulGrade))
			if newSoul:getSoulGrade() == 10 then
				afterLevelLabel:setString("已满级")
				afterDescLabel:setString("已满级")
				moneyLabel:setString("已满级")
			else
				afterLevelLabel:setString(string.format("引魂等级：+%d",newSoul:getSoulGrade()+1))
				afterDescLabel:setString(string.format("通灵属性威力：%s%%",tostring(wd.GlobalData:getInstance():getSoulGradePropertyPercent(newSoul:getGrade(),newSoul:getSoulGrade()+1)/100)))
				moneyLabel:setString(wd.GlobalData:getInstance():getSoulUpgradeNeedMoney(newSoul:getGrade(),newSoul:getSoulGrade()))
			end
		end
	end
    
    local listener = cc.EventListenerCustom:create("Soul_Upgrade", updataSoul)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end


return SoulUpgradeLayer