
local MeltingLayer = class("MeltingLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function MeltingLayer.create()
    local layer = MeltingLayer.new()
    layer:createLayerMenu()
    return layer
end

function MeltingLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.equipNodeTable = {}
    self.effectPanel = nil
    self.effectTripod = nil

end

function MeltingLayer:addEquip()
    local count = 0
    local number = wd.GlobalData:getInstance():getEquipItemCount()-1
    local itemTable = {}
    
    for i = 0,number do
        local item = wd.GlobalData:getInstance():getEquipItem(number-i)
        if item ~= nil then
            if item:getLocked() == 0 and item:getQuality() ~= 2 then
                itemTable[count] = item
                count = count + 1
                if count >= 6 then
                    break
                end
            end
        end
    end
    
    
    for i = 0,5 do
    
        local item = itemTable[i]
        
        local colorSprite = tolua.cast(self.equipNodeTable[i]:getChildByName("Color_Sprite"), "cc.Sprite")
        local equipSprite = tolua.cast(self.equipNodeTable[i]:getChildByName("Equip_Sprite"), "cc.Sprite")        
        local levelLabel = tolua.cast(self.equipNodeTable[i]:getChildByName("Level_Label"), "ccui.TextBMFont")
        local title = tolua.cast(self.equipNodeTable[i]:getChildByName("Job_Title"), "cc.Sprite")
        local strengthenLabel = tolua.cast(self.equipNodeTable[i]:getChildByName("Strengthen_Label"), "ccui.Text")

        equipSprite:removeAllChildren()
        if item ~= nil then

            self.equipNodeTable[i]:setTag(item:getServerId())
            
            self.equipNodeTable[i]:setVisible(true)
    
            colorSprite:setSpriteFrame(string.format("%02d.png",item:getColor()))
            equipSprite:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
            
            if item:getOccupation() <= 0 then
                title:setVisible(false)
            else
                title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
            end
            
            if item:getStrengthenLevel() > 0 then
                strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
            else
                strengthenLabel:setString("")
            end
            
            wd.equipEffect(item, equipSprite)

        else
            self.equipNodeTable[i]:setTag(-1)
            self.equipNodeTable[i]:setVisible(false)
        end
    end
end

function MeltingLayer:clearEquip()
     for i = 0,5 do
        self.equipNodeTable[i]:setTag(-1)
        self.equipNodeTable[i]:setVisible(false)
     end
end

function MeltingLayer:effect()
    self.effectPanel:setVisible(true)
    self.effectTripod:setVisible(true)
    
    local function delayCallBackFunc(sender)
        self.effectPanel:setVisible(false)
        self.effectTripod:setVisible(false)
        self:addEquip()
    end

    local delayCallBack = cc.CallFunc:create(delayCallBackFunc)

    local animation = cc.Animation:create()
    for i = 1, 12 do
        animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("meltingTripod_%02d.png", i)))
    end

    animation:setDelayPerUnit(0.1)
    animation:setLoops(1)
    local action = cc.Animate:create(animation)
    local sequenceAction = cc.Sequence:create(action, delayCallBack)

    self.effectTripod:runAction(sequenceAction)
        
    for i = 0,5 do
        local node = self.equipNodeTable[i]
        if node:isVisible() then
            wd.meltingEquipEffect(node:getParent(), node:getPositionX(), node:getPositionY()+20)
        end
    end
end


function MeltingLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/tripod/MeltingScene.csb"), "ccui.Widget")
    self:addChild(node)
    
    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)

    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if self.clippingLayer then
                    local event = cc.EventCustom:new("guidance_closeBattleLayer")
                    cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                    self.clippingLayer:removeFromParent()
                    self.clippingLayer = nil
                end
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Update")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Melting_Upgrade")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_EquipList_Msg")
                self:removeFromParent()
            end
        end
    )
	
    local helpBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Help_Button"), "ccui.Widget")
    helpBtn:setPressedActionEnabled(true)
    helpBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.setting.HelpLayer")
				local layer = layerClass.create(wd.helpType.Sub,wd.helpTag.Tripod)
				self:addChild(layer)
            end
        end
    )
	
    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Box"), "ccui.Widget")
    
    local attrPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Attr"), "ccui.Widget")
    
    local levelPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Level"), "ccui.Widget")
    
    local effectPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Effect"), "ccui.Widget")
    effectPanel:setVisible(false)
    self.effectPanel = effectPanel
    
    local meltingPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Melting"), "ccui.Widget")
    
    local effectTripod = tolua.cast(meltingPanel:getChildByName("Tripod_Effect"), "cc.Sprite")
	local x,y = effectTripod:getPosition()
	local pos = effectTripod:getParent():convertToWorldSpace(cc.p(x,y))
    effectTripod:setVisible(false)
    self.effectTripod = effectTripod
    
    self.equipNodeTable[0] = tolua.cast(meltingPanel:getChildByName("Equip0_Node"), "cc.Node")
    self.equipNodeTable[1] = tolua.cast(meltingPanel:getChildByName("Equip1_Node"), "cc.Node")
    self.equipNodeTable[2] = tolua.cast(meltingPanel:getChildByName("Equip2_Node"), "cc.Node")
    self.equipNodeTable[3] = tolua.cast(meltingPanel:getChildByName("Equip3_Node"), "cc.Node")
    self.equipNodeTable[4] = tolua.cast(meltingPanel:getChildByName("Equip4_Node"), "cc.Node")
    self.equipNodeTable[5] = tolua.cast(meltingPanel:getChildByName("Equip5_Node"), "cc.Node")
    
    local function removeEquip (sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self.equipNodeTable[sender:getTag()]:setTag(-1)
            self.equipNodeTable[sender:getTag()]:setVisible(false)
        end
    end
    
    local equip0Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip0_Button"), "ccui.Button")
    local equip1Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip1_Button"), "ccui.Button")
    local equip2Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip2_Button"), "ccui.Button")
    local equip3Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip3_Button"), "ccui.Button")
    local equip4Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip4_Button"), "ccui.Button")
    local equip5Btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip5_Button"), "ccui.Button")
    equip0Btn:addTouchEventListener(removeEquip)
    equip1Btn:addTouchEventListener(removeEquip)
    equip2Btn:addTouchEventListener(removeEquip)
    equip3Btn:addTouchEventListener(removeEquip)
    equip4Btn:addTouchEventListener(removeEquip)
    equip5Btn:addTouchEventListener(removeEquip)

    -- local smeltingBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Smelting_Button"), "ccui.Button")
    -- smeltingBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
    --             cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Update")
    --             cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Melting_Upgrade")

    --             local layerClass = require("src.game.tripod.SmeltingLayer")
    --             local layer = layerClass.create()
    --             self:getParent():addChild(layer)
    --             self:removeFromParent()
    --         end
    --     end
    -- )
	
	local swallowBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Swallow_Button"), "ccui.Button")
    swallowBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Update")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Melting_Upgrade")

                local layerClass = require("src.game.tripod.SwallowLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
    -- local addEquipBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"AddEquip_Button"), "ccui.Button")
    -- addEquipBtn:setPressedActionEnabled(true)
    -- addEquipBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
    --             self:addEquip()
    --         end
    --     end
    -- )
    
    local doMeltingBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"DoMelting_Button"), "ccui.Button")
    doMeltingBtn:setPressedActionEnabled(true)
    
    ------------------------------新手引导----------------------------
    local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
    if clippingLayer then
        clippingLayer:setGuidance(doMeltingBtn,5,10,115,115)
        local msgTable = {}
        local msg = {}
        table.insert(msg,"来")
        table.insert(msg,"{r=[炼化]}")
        table.insert(msg,"一下，看你运气咋样！")
        table.insert(msgTable,msg)
        clippingLayer:setMsg(msgTable)
        self:addChild(clippingLayer)
    end
    ------------------------------------------------------------------
    
    doMeltingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if clippingLayer then
                    clippingLayer:removeFromParent()
                    clippingLayer = nil
                end
                if self.equipNodeTable[0]:getTag() >= 0 or self.equipNodeTable[1]:getTag() >= 0 or self.equipNodeTable[2]:getTag() >= 0 or self.equipNodeTable[3]:getTag() >= 0 or self.equipNodeTable[4]:getTag() >= 0 or self.equipNodeTable[5]:getTag() >= 0 then
                    self:effect()
                    wd.TranscodingSend:setTripodMelting(self.equipNodeTable[0]:getTag(),self.equipNodeTable[1]:getTag(),self.equipNodeTable[2]:getTag(),self.equipNodeTable[3]:getTag(),self.equipNodeTable[4]:getTag(),self.equipNodeTable[5]:getTag())
                else
                    wd.showRichTips(4,"请添加熔炼装备")
                end
            end
        end
    )
    
    --local attackTitle = tolua.cast(attrPanel:getChildByName("Attack_Title"), "cc.Sprite")
    local hpLabel = tolua.cast(attrPanel:getChildByName("HpCur_Label"), "ccui.Text")
    local mpLabel = tolua.cast(attrPanel:getChildByName("MpCur_Label"), "ccui.Text")
    local atkMinLabel = tolua.cast(attrPanel:getChildByName("MinAtkCur_Label"), "ccui.Text")
    local atkMaxLabel = tolua.cast(attrPanel:getChildByName("MaxAtkCur_Label"), "ccui.Text")
    local defMinLabel = tolua.cast(attrPanel:getChildByName("MinDefCur_Label"), "ccui.Text")
    local defMaxLabel = tolua.cast(attrPanel:getChildByName("MaxDefCur_Label"), "ccui.Text")
    
    
    local nextHpLabel = tolua.cast(attrPanel:getChildByName("HpNext_Label"), "ccui.Text")
    local nextMpLabel = tolua.cast(attrPanel:getChildByName("MpNext_Label"), "ccui.Text")
    local nextAtkMinLabel = tolua.cast(attrPanel:getChildByName("MinAtkNext_Label"), "ccui.Text")
    local nextAtkMaxLabel = tolua.cast(attrPanel:getChildByName("MaxAtkNext_Label"), "ccui.Text")
    local nextDefMinLabel = tolua.cast(attrPanel:getChildByName("MinDefNext_Label"), "ccui.Text")
    local nextDefMaxLabel = tolua.cast(attrPanel:getChildByName("MaxDefNext_Label"), "ccui.Text")
    
    local powerLabel = tolua.cast(attrPanel:getChildByName("Power_Label"), "ccui.TextAtlas")
    
	local upgradeEffect = tolua.cast(attrPanel:getChildByName("Upgrade_Effect"), "cc.Sprite")
	upgradeEffect:setScaleY(attrPanel:getContentSize().height/(upgradeEffect:getContentSize().height-100))
    upgradeEffect:setPosition(attrPanel:getContentSize().width/2,attrPanel:getContentSize().height/2+20)
	
    local levelLabel = levelPanel:getChildByName("Level_Label")
    
    local expBar = tolua.cast(ccui.Helper:seekWidgetByName(levelPanel,"Exp_Progress"), "ccui.LoadingBar")
    local expLabel = tolua.cast(ccui.Helper:seekWidgetByName(levelPanel,"Exp_Label"), "ccui.Text")
    local tripod = wd.GlobalData:getInstance():getTripodData()
	local curExp = tripod:getExp()


    local function updataData()
        local tripod = wd.GlobalData:getInstance():getTripodData()

        hpLabel:setString(string.format("%d", tripod:getHp()))
        mpLabel:setString(string.format("%d", tripod:getMp()))
        atkMinLabel:setString(string.format("%d", tripod:getAttack_min()))
        atkMaxLabel:setString(string.format("%d", tripod:getAttack_max()))
        defMinLabel:setString(string.format("%d", tripod:getDefence_min()))
        defMaxLabel:setString(string.format("%d", tripod:getDefence_max()))
		if tripod:getLeveL() == 80 then
			nextHpLabel:setString("满级")
			nextMpLabel:setString("满级")
			nextAtkMinLabel:setString("满级")
			nextAtkMaxLabel:setString("满级")
			nextDefMinLabel:setString("满级")
			nextDefMaxLabel:setString("满级")
		else
			nextHpLabel:setString(string.format("%d", tripod:getNextHp()))
			nextMpLabel:setString(string.format("%d", tripod:getNextMp()))
			nextAtkMinLabel:setString(string.format("%d", tripod:getNextAttack_min()))
			nextAtkMaxLabel:setString(string.format("%d", tripod:getNextAttack_max()))
			nextDefMinLabel:setString(string.format("%d", tripod:getNextDefence_min()))
			nextDefMaxLabel:setString(string.format("%d", tripod:getNextDefence_max()))
		end

        powerLabel:setString(string.format("%d", tripod:getPower()))
        
        
        levelLabel:setString(string.format("%d", tripod:getLeveL()))
        expBar:setPercent(tripod:getExp()/tripod:getMaxExp()*100)
		
		if curExp ~= tripod:getExp() and  tripod:getChangeExp() ~= 0 then
			--wd.showAttributeTips(string.format("熔炼值+%d",tripod:getChangeExp()),cc.c3b(0,255,0),35,pos)
            local expText = ccui.Text:create()
            expText:setString("+"..tripod:getChangeExp())
            expText:setFontSize(25)
            expText:setColor(cc.c3b(0,255,0))
            expText:setPosition(expLabel:getPosition())
            expLabel:getParent():addChild(expText)
            local moveBy      = cc.MoveBy:create(2,cc.p(0,40))
            local easeSineOut = cc.EaseSineOut:create(moveBy)
            local fadeOut     = cc.FadeOut:create(2)
            local spawn       = cc.Spawn:create(easeSineOut,fadeOut)
            local function removeExpText()
                expText:removeFromParent()
            end
            local callBack = cc.CallFunc:create(removeExpText)
		    local sequenceAction = cc.Sequence:create(spawn,callBack)
            expText:runAction(sequenceAction)
			-- wd.showRichTips(4,string.format("熔炼成功，熔炼值+%d",tripod:getChangeExp()))
		end

		expLabel:setString(string.format("%d/%d", tripod:getExp(), tripod:getMaxExp()))
        self:clearEquip()
    end

    updataData()
    
    local listener = cc.EventListenerCustom:create("Tripod_Update", updataData)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function meltingUpGradeCallBack()
		upgradeEffect:stopAllActions()
		upgradeEffect:setOpacity(225)
		upgradeEffect:setVisible(true)
		local fadeOut = cc.FadeOut:create(1)
		local function fadeOutCallBack()
            ------------------------------新手引导----------------------------
            local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
            if clippingLayer then
                clippingLayer:setGuidance(backBtn,30,50,115,115,nil,true)
                local msgTable = {}
                local msg = {}
                table.insert(msg,"哇，主人运气超棒，居然出")
                table.insert(msg,"{r=[高一阶品质的装备]}")
                table.insert(msg,"，good！")
                table.insert(msgTable,msg)
                clippingLayer:setMsg(msgTable)
                self:addChild(clippingLayer)
                self.clippingLayer = clippingLayer
            end
            ------------------------------------------------------------------
            
			upgradeEffect:setVisible(false)
		end
		local fadeOutCallBackFunc = cc.CallFunc:create(fadeOutCallBack)
		local sequenceAction = cc.Sequence:create(fadeOut,fadeOutCallBackFunc)
		upgradeEffect:runAction(sequenceAction)
		--[[local tripod = wd.GlobalData:getInstance():getTripodData()
		
		local roleAttributeClass = require("src.game.RoleAttribute"):getInstance()
		for i,v in pairs(roleAttributeClass.meltingAttribute) do
			local value = v.getFunc(tripod)
			
			--print("x=    "..pos.x.."    y = "..pos.y)
			x = x + meltingPanel:getContentSize().width/2
						y = y + meltingPanel:getContentSize().height/2
			--wd.showAttributeTips(string.format("%s +%d",v.name,value),cc.c3b(0,255,0),35,pos)
			wd.showRichTips(4,string.format("%s +%d",v.name,value),cc.c3b(0,255,0))
		end--]]
	end

	local listener_Melting_Upgrade = cc.EventListenerCustom:create("Melting_Upgrade", meltingUpGradeCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener_Melting_Upgrade, 1); 
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
    end
	
	local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    
    local function getEquipCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_EquipList_Msg")
		local itemInfo = wd.getEquipInfo(getData)
        for k,v in pairs(itemInfo) do
            local msg = {}
            table.insert(msg,"获得")
            table.insert(msg,string.format("{t=[%s],c=[%d]}",v.name,v.color))
            wd.showRichTips(wd.tipsType.Get,msg)
        end
    end
	
	local listenerEquip = cc.EventListenerCustom:create("Get_EquipList_Msg", getEquipCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerEquip, 1);
    
    --自动添加熔炼装备
    self:addEquip()
end


return MeltingLayer