
require "wdFilename"


local LoadingScene = class("LoadingScene",function()
    return cc.Scene:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function LoadingScene.create()
    local scene = LoadingScene.new()
    scene:createLayerMenu()
    scene:loadImage()
    return scene
end

function LoadingScene:ctor()
	package.loaded["wdSingleHandlerDefine"] = nil
	require "wdSingleHandlerDefine"
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    
    self.loadingBar = nil
    self.loadingLabel = nil
end


function LoadingScene:removeTexture()
    cc.SpriteFrameCache:getInstance():removeSpriteFramesFromFile("ui/login/login.plist")
    cc.SpriteFrameCache:getInstance():removeSpriteFramesFromFile("ui/create/create.plist")

    cc.Director:getInstance():getTextureCache():removeTextureForKey("ui/login/login.png")
    cc.Director:getInstance():getTextureCache():removeTextureForKey("ui/login/login_bg.jpg")
    
    cc.Director:getInstance():getTextureCache():removeTextureForKey("ui/create/create.png")
    cc.Director:getInstance():getTextureCache():removeTextureForKey("ui/create/create_bg.jpg")

end

function LoadingScene:loadDone()
    
    local scene = require("src.game.MainScene")
    local gameScene = scene.create()

    if cc.Director:getInstance():getRunningScene() then
        cc.Director:getInstance():replaceScene(gameScene)
    else
        cc.Director:getInstance():runWithScene(gameScene)
    end
    
    self:removeTexture()
end

function LoadingScene:loadProgress(percent)
    self.loadingBar:setPercent(percent)
    self.loadingLabel:setString(string.format("%0.0f%%", percent))
end


function LoadingScene:loadImage()
    local count = 1
    
    local asyncFunction = nil
    
    local size1 = #wd.fileNameJpg
    local size2 = #wd.fileNamePng
    local size3 = #wd.fileNameFont

    local function oneImageLoad()
        count = count + 1
        asyncFunction()
    end

    local function plisCallBack(texture)
        cc.SpriteFrameCache:getInstance():addSpriteFrames(wd.fileNamePng[count-size1]..".plist", texture)
        oneImageLoad()
    end

    local function addImageAsync()

        local fileName = nil
                
        self:loadProgress(count/(size1+size2+size3)*100)
        --cclog("count %d %d %d %d", count,size1, size2, size3)
        if count > size1+size2+size3 then -- done
            self:loadDone()
            return
        elseif count > size1+size2 then -- font
            cc.Director:getInstance():getTextureCache():addImageAsync(wd.fileNameFont[count-size1-size2]..".png", oneImageLoad)
        elseif count > size1 then  -- png plist
            cc.Director:getInstance():getTextureCache():addImageAsync(wd.fileNamePng[count-size1]..".png", plisCallBack)
        else  -- jpg
            cc.Director:getInstance():getTextureCache():addImageAsync(wd.fileNameJpg[count]..".jpg", oneImageLoad)
        end

    end
    
    asyncFunction = addImageAsync
    
    addImageAsync()
    
    self:setSettingSkillData()
end


function LoadingScene:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/loading/LoadingScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local loadingTitle = tolua.cast(ccui.Helper:seekWidgetByName(node,"Loading_Title"), "ccui.Text")
    loadingTitle:setString(string.format("加载资源中..."))

    local versionLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Version_Label"), "ccui.Text")
    versionLabel:setString(string.format("v %s", cc.UserDefault:getInstance():getStringForKey("version")))

    self.loadingBar = tolua.cast(ccui.Helper:seekWidgetByName(node,"Loading_Progress"), "ccui.LoadingBar")
    self.loadingLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Loading_Label"), "ccui.Text")

end

function LoadingScene:setSettingSkillData()
    wd.skillHandler:setAllSkillInfo()
    wd.TranscodingSend:getAllSkill()

    wd.skillHandler:setAllBuffInfo()
    wd.skillHandler:setSettingSkillData()
end

return LoadingScene