
local AccountLayer = class("AccountLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function AccountLayer.create()
    local layer = AccountLayer.new()
    layer:createLayerMenu()
    return layer
end

function AccountLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    

    self.username = ""
    self.password = ""
end


function AccountLayer:registerEventListener()

    local function successCallback(EventCustom)
        self:setAccountPassword()
    end

    local function failedCallback(EventCustom)
        --self:setAccountPassword()
        cclog("!! ERROR account login failed !!")
    end

    local listenerSuccess = cc.EventListenerCustom:create("Account_Success", successCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerSuccess, 1)
    local listenerFailed = cc.EventListenerCustom:create("Account_Failed", failedCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerFailed, 1)

end

function AccountLayer:unregisterEventListener()
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Account_Success")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Account_Failed")
end


function AccountLayer:setAccountPassword()
    if self.username:len() >= 4 and self.password:len() >= 6 then
        self:getParent():setAccountPassword( self.username, self.password)
        self:unregisterEventListener()
        self:removeFromParent()
    end
end



function AccountLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/login/AccountLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:unregisterEventListener()
                self:removeFromParent()
            end
        end
    )
    
    local username = cc.UserDefault:getInstance():getStringForKey("username")
    local password = cc.UserDefault:getInstance():getStringForKey("password")

    local accountField = tolua.cast(ccui.Helper:seekWidgetByName(node,"Account_TextField"), "ccui.TextField")

    local passwordField = tolua.cast(ccui.Helper:seekWidgetByName(node,"Password_TextField"), "ccui.TextField")
    
    
    if username:len() >= 4 and password:len() >= 6 then
        accountField:setString(username)
        passwordField:setString(password)
    end


    local loginBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Login_Button"), "ccui.Widget")
    loginBtn:setPressedActionEnabled(true)
    loginBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self.username = accountField:getString()
                self.password = passwordField:getString()
                if self.username:len() < 4 then
                    wd.showRichTips(4,"账号长度必须大于4位")
                    return
                end
                
                if self.password:len() < 6 then
                    wd.showRichTips(4,"密码长度必须大于6位")
                    return
                end
                
                wd.TranscodingSend:login(self.username, self.password)
            end
        end
    )
    
    local registerBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Register_Button"), "ccui.Widget")
    registerBtn:setPressedActionEnabled(true)
    registerBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:unregisterEventListener()

                local layerClass = require("src.login.RegisterLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
    self:registerEventListener()

end

return AccountLayer