
local RichTipsLayer = class("RichTipsLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function RichTipsLayer:create()
    self.instance = RichTipsLayer.new()
end

function RichTipsLayer:getInstance()
	if not self.instance then
		self:create()
	end
    return self.instance
end

function RichTipsLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.contentSize = cc.size(1152, 768)
	self.frontTag = 1
	self.fontSize = 24
	self.upHeight = self.fontSize
	self:setContentSize(self.contentSize)	
	self.isShow = false
	self.showMsgList = {}
end

function RichTipsLayer:adjustLayout()
	local child
	for i= self.frontTag-1,1,-1 do
		if self:getChildByTag(i) then
			child = self:getChildByTag(i)
            local action = cc.MoveBy:create(0.2, cc.p(0, child:getContentSize().height+5))
            child:runAction(action)
		end
	end
end


function RichTipsLayer:showTips(tipsType,msg,color)
	local box = ccui.Scale9Sprite:createWithSpriteFrameName(wd.tipsBoxSprite[tipsType])
	box:setScale9Enabled(true)
	box:setPreferredSize(wd.tipsBoxSize[tipsType])
	box:setCapInsets(cc.rect(5,5,wd.tipsBoxSize[tipsType].width-10,wd.tipsBoxSize[tipsType].height-10))
	self:addChild(box)
	box:setPosition(cc.p(self.contentSize.width/2,self.contentSize.height/2))
	box:setCascadeOpacityEnabled(true)
	--box:setCascadeColorEnabled(true)
	local richTextLabel = ccui.RichText:create()
	richTextLabel:setCascadeOpacityEnabled(true)
	if type(msg) == "table" then
		local startIndex,lastIndex,str,colorStr,richElement
		for i,v in ipairs(msg) do
			if (string.find(v,"{t") ~= nil) then
				startIndex,lastIndex,str,colorStr= string.find(v,"{t=%[(.-)%],c=%[(.-)%]}") 
				richElement = ccui.RichElementText:create(2,wd.colorTable[tonumber(colorStr)],255,str,"Helvetica",self.fontSize)
			elseif (string.find(v,"{e") ~= nil) then
				startIndex,lastIndex,str,colorStr= string.find(v,"{e=%[(.-)%],c=%[(.-)%]}") 
				richElement = ccui.RichElementText:create(2,wd.colorTable[tonumber(colorStr)],255,str,"Helvetica",self.fontSize)
            elseif (string.find(v,"{u") ~= nil) then
                local c1,c2,c3,c4
				startIndex,lastIndex,str,c1,c2,c3,c4= string.find(v,"{u=%[(.-)%],c1=%[(.-)%],c2=%[(.-)%],c3=%[(.-)%],c4=%[(.-)%]}") 
				richElement = ccui.RichElementText:create(2,cc.c3b(tonumber(c1),tonumber(c2),tonumber(c3)),tonumber(c4),str,"Helvetica",self.fontSize)
			elseif (string.find(v,"{o") ~= nil) then
				startIndex,lastIndex,str = string.find(v,"{o=%[(.-)%]}") 
				richElement = ccui.RichElementText:create(2,cc.c3b(225,0,0),255,str,"Helvetica",self.fontSize)
			else
				richElement = ccui.RichElementText:create(2,cc.c3b(255,255,255),255,v,"Helvetica",self.fontSize) 
			end
			richTextLabel:pushBackElement(richElement)
		end
		
	elseif type(msg) == "string" then
		if not color then
			color = cc.c3b(255,255,255)
		end
		local richElement = ccui.RichElementText:create(2,color,255,msg,"Helvetica",self.fontSize) 
		richTextLabel:pushBackElement(richElement)
	end
	richTextLabel:formatText()
	local textSize = richTextLabel:getContentSize()
	if textSize.width > wd.tipsBoxSize[tipsType].width-25 then
		self.upHeight = math.ceil(textSize.width / wd.tipsBoxSize[tipsType].width) * textSize.height
		textSize.width = wd.tipsBoxSize[tipsType].width
	else
		self.upHeight = wd.tipsBoxSize[tipsType].height
	end
	richTextLabel:ignoreContentAdaptWithSize(false)
	richTextLabel:setContentSize(textSize.width,self.upHeight)
	
	richTextLabel:setAnchorPoint(cc.p(0.5,0.5))
	box:addChild(richTextLabel)
	
	local richH 
	if tipsType == 3 then
		richH = richTextLabel:getContentSize().height/2+4
	else
		richH = richTextLabel:getContentSize().height/4+5
	end
	richTextLabel:setPosition((wd.tipsBoxSize[tipsType].width - textSize.width)/2+textSize.width/2,richH)
	box:setTag(self.frontTag)
	box:setVisible(false)
	table.insert(self.showMsgList,box)
	
	local function checkShow()
		if #self.showMsgList > 0 then
			self.showMsgList[1]:setVisible(true)
			local fadeOut = cc.FadeOut:create(0.3)
			local delayTime = cc.DelayTime:create(0.4)
			local moveByFront = cc.MoveBy:create(0.15,cc.p(0,30))
			local function moveByCallBackFunc()
				if self.showMsgList[2] then
					self.showMsgList[2]:setVisible(true)
				end
			end
			local moveByReal =  cc.MoveBy:create(0.15,cc.p(0,30))
			local spawn = cc.Spawn:create(moveByReal,fadeOut)
			local function delayCallBackFunc()
				self.rearTag = self.showMsgList[1]:getTag()
				self.showMsgList[1]:removeFromParent()
				table.remove(self.showMsgList,1)
				checkShow()
			end
			local moveByCallBack =  cc.CallFunc:create(moveByCallBackFunc)
			local delayCallBack = cc.CallFunc:create(delayCallBackFunc)
			local sequence = cc.Sequence:create(delayTime,moveByFront,moveByCallBack,spawn,delayCallBack)
			self.showMsgList[1]:runAction(sequence)
			
			--self:adjustLayout()
			self.frontTag = self.frontTag+1
		else
			self.isShow  = false
		end
	end
	
	
	
	if not self.isShow then
		self.isShow = true
		checkShow()
	end
end


return RichTipsLayer