
local TipsBoxLayer = class("TipsBoxLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function TipsBoxLayer.create(titleSpriteName,msg,callbackFunc)
    local layer = TipsBoxLayer.new()
    layer:createLayerMenu(titleSpriteName,msg,callbackFunc)
    return layer
end

function TipsBoxLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.dataHandler = wd.familyHandler 
end

function TipsBoxLayer:createLayerMenu(titleSpriteName, msgTable,callbackFunc)
    local node = tolua.cast(cc.CSLoader:createNode("ui/family/Family_Tips_Layer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)

    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
    local titleSprite =  tolua.cast(mainPanel:getChildByName("Title_Sprite"), "cc.Sprite")
    titleSprite:setSpriteFrame(titleSpriteName)

    local msgPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Msg_Panel"), "ccui.Widget")
    local size = msgPanel:getContentSize()
    
    if type(msgTable) == "string" then
        local text = ccui.Text:create()
        text:ignoreContentAdaptWithSize(false)
        text:setTextAreaSize(cc.size(size.width-30,size.height))
        text:setFontSize(25)
        text:setString(msg)
        msgPanel:addChild(text)
        text:setPosition(size.width/2,size.height/2)
    
    elseif type(msgTable) == "table" then
        local count = #msgTable
        
        local height = -12

        local layer = cc.Layer:create()
        
        for j,msg in ipairs(msgTable) do
            if type(msg) == "table" then
                local richTextLabel = ccui.RichText:create()
                local startIndex,lastIndex,str,richElement
                for i,v in ipairs(msg) do
                    if (string.find(v,"{r") ~= nil) then
                        startIndex,lastIndex,str = string.find(v,"{r=%[(.-)%]}") 
                        richElement = ccui.RichElementText:create(2,cc.c3b(255,0,0),255,str,"Helvetica",25)
                    elseif (string.find(v,"{y") ~= nil) then
                        startIndex,lastIndex,str = string.find(v,"{y=%[(.-)%]}") 
                        richElement = ccui.RichElementText:create(2,cc.c3b(220,220,0),255,str,"Helvetica",25)
                    elseif (string.find(v,"{g") ~= nil) then
                        startIndex,lastIndex,str = string.find(v,"{g=%[(.-)%]}") 
                        richElement = ccui.RichElementText:create(2,cc.c3b(0,220,0),255,str,"Helvetica",25)
                    else
                        richElement = ccui.RichElementText:create(2,cc.c3b(255,255,255),255,v,"Helvetica",25) 
                    end
                    richTextLabel:pushBackElement(richElement)
                end
                richTextLabel:formatText()
                local textSize = richTextLabel:getContentSize()
                if textSize.width > size.width-25 then
                    self.upHeight = math.ceil(textSize.width / size.width) * textSize.height
                    richTextLabel:setContentSize(size.width,self.upHeight)
                else
                    self.upHeight = 25
                end
                
                richTextLabel:ignoreContentAdaptWithSize(false)
                richTextLabel:setPosition(size.width/2, height)
                richTextLabel:setAnchorPoint(cc.p(0.5,0.5))
                layer:addChild(richTextLabel)
                height = height - self.upHeight
            end
        end
        
        height = math.abs(height)
        
        layer:setPosition(0, (size.height-height)/2 + height)
        msgPanel:addChild(layer)
    end

    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )


    local enterBtn = ccui.Helper:seekWidgetByName(node,"Enter_Button")
    enterBtn:setPressedActionEnabled(true)
    enterBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                callbackFunc()
                self:removeFromParent()
            end
        end
    )

    local cancelBtn = ccui.Helper:seekWidgetByName(node,"Cancel_Button")
    cancelBtn:setPressedActionEnabled(true)
    cancelBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )


end

return TipsBoxLayer
