
require "cocos.extension.ExtensionConstants"

local UpdateLayer = class("UpdateLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function UpdateLayer.create()
    local layer = UpdateLayer.new()
    return layer
end


function UpdateLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.pathToSave = createDownloadDir()  -- 保存路径
    self.assetsManager = nil -- 资源管理器对象
    self.version = cc.UserDefault:getInstance():getStringForKey("version")
end

function UpdateLayer:getContentLength()
    local length = self.assetsManager:getContentLength()

    if length >= 1024*1024 then
        length = string.format("%0.1fMB", length/1024/1024)
    elseif length >= 1024 then
        length = string.format("%0.1fKB", length/1024)
    elseif length > 0 then
        length = string.format("%dB", length)
    else
        length = "0B"
    end
    
    return length
end


function UpdateLayer:getAssetsManager()

    if nil == self.assetsManager then
        -- self.assetsManager = cc.AssetsManager:new(string.format("http://ttlx.oss-cn-hangzhou.aliyuncs.com/wending%%2Ftiantianliexue%%2F%s%%2Fupdate.zip",self.version) ,
        --     string.format("http://ttlx.oss-cn-hangzhou.aliyuncs.com/wending%%2Ftiantianliexue%%2F%s%%2Fversion",self.version),
        --     self.pathToSave)
        local url = "http://ttlx.oss-cn-hangzhou.aliyuncs.com/tianzheng%2Fliehuoguaji%2Fupdate%2F"
        self.assetsManager = cc.AssetsManager:new(url..self.version.."%2Fupdate.zip",url..self.version.."%2Fversion",self.pathToSave)
            
        self:addChild(self.assetsManager)

        self.assetsManager:setConnectionTimeout(3)
    end

    return self.assetsManager
end



function UpdateLayer:checkUpdate()

    local function onError(errorCode)
        if errorCode == cc.ASSETSMANAGER_NO_NEW_VERSION then
        elseif errorCode == cc.ASSETSMANAGER_NETWORK then
            --wd.showSystemTips("网络错误，请检查网络")
        end
    end

    local function onSuccess()
        self:getParent():checkUpdate()
        self:removeFromParent()
    end
    
    self:getAssetsManager():setDelegate(onSuccess, cc.ASSETSMANAGER_PROTOCOL_SUCCESS)
    self:getAssetsManager():setDelegate(onError, cc.ASSETSMANAGER_PROTOCOL_ERROR)

    if self:getAssetsManager():checkUpdate() == true then
        self:createLayerMenu()
        return true
    else
        return false
    end

end

function UpdateLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/update/UpdateScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
    
    local downloadBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Download_Button"), "ccui.Widget")
    downloadBtn:setPressedActionEnabled(true)
    downloadBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:getAssetsManager():update()
            end
        end
    )
    
    local downloadTitle = tolua.cast(ccui.Helper:seekWidgetByName(node,"Download_Title"), "ccui.Text")
    downloadTitle:setString(string.format("有更新版本%s (%s)，点击确定下载",self:getAssetsManager():getDownloadVersion(), self:getContentLength()))
    
    local versionLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Version_Label"), "ccui.Text")
    versionLabel:setString(string.format("v %s", self.version))
    
    local downloadBar = tolua.cast(ccui.Helper:seekWidgetByName(node,"Download_Progress"), "ccui.LoadingBar")
    local downloadLabel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Download_Label"), "ccui.Text")
    
    local function onProgress(percent)
        downloadBar:setPercent(percent)
        downloadLabel:setString(string.format("%0.1f%%", percent))
    end
    
    self:getAssetsManager():setDelegate(onProgress, cc.ASSETSMANAGER_PROTOCOL_PROGRESS)
end

return UpdateLayer